/*
 *  Classified Tydeman Consulting Proprietary
 *  Copyright (C) 1994, 2009 Tydeman Consulting.  All rights reserved.
 *
 *  Fred Tydeman	tydeman@tybor.com
 *
 * - -- --- ---- ----- -------------------------------------------------
 *
 *    We wish to acknowledge Taligent, Inc., for their support of this
 *	   test suite.  Taligent was early to recognize
 *	   the value and need for a comprehensive test suite of the
 *	   floating point support in C compilers.  Taligent funded the
 *	   original version of this test suite, and has graciously
 *	   released it to us to allow continued extensions and to
 *	   promote wider compliance with the ANSI C Floating-Point
 *	   C Extensions (FPCE).
 *
 *    This code is copyrighted.  Under the copyright laws, this code may
 *         not be copied, in whole or part, without prior written
 *         consent of Tydeman Consulting.
 *
 *    RESTRICTED RIGHTS LEGEND: Use, duplication, or disclosure by the
 *         government is subject to restrictions as set forth in
 *         subparagraph (c)(1)(ii) of the Rights in Technical Data and
 *         Computer Software clause at DFARS 252.227-7013 and
 *         FAR 52.227-19.
 *
 *    TRADEMARKS: Taligent and the Taligent Design Mark are registered
 *         trademarks of Taligent, Inc.
 *
 * - -- --- ---- ----- -------------------------------------------------
 * $Revision: 2.1 $
 ***********************************************************************
 *  FILE: mydefs.h
 *
 *  Description:	  Define macro symbols used in rest of test suite.
 *
 *  It is assumed that mydefs.h is the first #include file, so it can
 *  define anything needed by the other #include files.  This header
 *  should NOT include any other header (except for the configuration /
 *  bug bypass definition header).  Otherwise, the tests of standard
 *  headers will be misleading.
 *
 *  All of the following defines should be put into a separate file that
 *  is then included by this file.  That way, you can hide your compiler's
 *  bugs and this file (shipped to everyone) does not need to be modified
 *  as you fix those bugs or release different versions of your compiler.
 *
 *  To add a new system (hardware and software combination), add another
 *	#elif (defined hardware) && (defined software)
 *		#include hardsoft.bug
 *  section.  'hardsoft.bug' is a name you make up that should indicate
 *  the hardware platform, operating system, and compiler being tested.
 *  If there are different versions of the compiler being tested, the
 *  determination of which bugs exist in which version should be done in
 *  the hardsoft.bug file (not here).  The hardsoft.bug file could include
 *  a separate bug file for each version of the compiler or for each
 *  language (C or C++) being tested.
 *
 *  There are sample*.bug files that you may use as a starting point for
 *  your own use.
 *
 *  The following symbols may be defined by the compiler itself, compiler
 *  command line options, or the 'make' facility.
 *
 *	FPCE_TEST_LVL	  What level of FPCE is being tested.  Default
 *			  is the most current level.
 *
 *	hardware symbolic See myfloat.h for the list.  No default.
 *
 *	software symbolic See myfloat.h for the list.  No default.
 *
 *	FPCE_SAMPLE	  Compiling sample FPCE tests with support functions.
 *			  Default is separate compiles along with linkedit
 *			  for the production tests and combined compile of
 *			  test and support functions for sample tests.
 *
 *	FENV_MISSING	  Compiling FPCE tests with a compiler that has never
 *			  heard of <fenv.h>.  This causes a dummy fenv.h to
 *			  be used that defines all required C99 FPCE items to
 *			  be "reasonable" or nothing via macros.
 *
 *	__cplusplus	  Define for C++, Undef for C testing.
 *			  Compiler may set based upon file extension.
 *
 *	__STDC_IEC_559__  Should be predefined by compiler (Annex X)
 *
 *	WANT_CLEAN	  Used to allow FIX_* and NEED_* macros to be
 *			  defined so that the tests compile and run without
 *			  error. That is the intent.  More test cases may
 *			  need to be tailored with more FIX_* or NEED_*
 *			  macros for that to happen if more implementation
 *			  bugs are found.  Default is do all tests and let
 *			  errors happen.
 *
 *	DEBUG		  Enable debugging printf statements in tests.
 *			  Default is no debugging prints.
 *
 *  The preceding symbols may be defined by the compiler itself, compiler
 *  command line options, or the 'make' facility.
 *
 *
 *  The following symbols may be #define'ed or #undef'ed in the bug file
 *  included by this file.
 *
 *  A place to #define if doing standalone main() C/C++ testing.
 *
 *	STANDALONE_TEST	  Define to be 1 for standalone main() C/C++ testing.
 *			  Undef for integrated C++ member function testing.
 *			  Was Taligent_LEAF for their C++ test environment.
 *
 *  A place to #define if test case output goes to console or file.
 *
 *	REDIRECT	  If you want the test programs to redirect stdout
 *			  to __FILE__ SUFFIX, then define REDIRECT.  If the
 *			  test program driver, e.g., make, can do the
 *			  redirection, then undefine REDIRECT (this is best).
 *
 *  A place to #define non-standard file modes.
 *
 *	*MODE		  If your compiler's file open mode is different
 *			  than the standard 'r', 'w', 'a'; such as needing
 *			  a 't' for text, eg, 'rt', 'wt', 'at'.
 *
 *  A place to #define additional setup declarations or statements needed.
 *
 *	SETUP1		  Any file scope variables or internal functions
 *			  needed.  Declares the file pointer (if needed)
 *			  to redirect stdout. SETUP1 will be used before
 *			  main() and any other functions.
 *
 *	SETUP2		  Any variables or setup code needed by main().
 *			  Includes the code (if needed) to do the redirection
 *			  of stdout. Includes the code (if needed) to clear
 *			  exception flags, disable traps, set rounding, and/or
 *			  set precision control modes. SETUP2 will be used in
 *			  main() after all declarations and before any
 *			  executable statements.
 *
 *	FPU_*		  Startup code needed to change the FPU to match the
 *			  expected FPCE environment.  Most common problem is
 *			  traps are enabled, so need to be disabled.
 *
 *  A place to #define if testing optional features.
 *
 *	TEST_*		  If these symbols are defined, then optional tests
 *			  will be run.  These tests are for things beyond the
 *			  scope of Standard C or FPCE.
 *
 *  A place to #define implementation defined behavior choices.
 *
 *	IMPL_*		  A few places in the FPCE or C99 specifications,
 *			  an implementation is allowed choices on the
 *			  behavior.  These macros allow you to define
 *			  which behavior was chosen.
 *
 *  A place to #define if bypassing implementation limitations (bugs).
 *
 *			  If you discover other bugs not bypassed,
 *			  please feed them back to Fred Tydeman.
 *
 *	FIX_*		  Bypass tests of certain features so that the tests
 *			  run clean.  This is a way around compiler bugs.
 *			  In general, this removes code from test cases.
 *			  This idea came from Tom Plum of Plum-Hall.
 *
 *	NEED_*		  If these symbols are defined, then optional code,
 *			  to bypass compiler bugs, will be enabled.
 *			  In general, this adds code to test cases.
 *			  FIX_MISSING_* would be another way to encode
 *			  this macro symbol.
 *
 *	REMAP_*		  Change meaning of LDBL or DBL, FP literals, and
 *			  function names.  Described later.
 *
 *  A place to #define the overrides of the math library test vectors.
 *
 *	t????00?	  Name of file to include that has assignment
 *			  statements to override the argument and expected
 *			  results values of the math library test vectors.
 *			  This is needed if the compiler's decimal to binary
 *			  conversion is so bad that it interferes with the
 *			  testing of the math library.  This assumes that
 *			  you have some function that can correctly convert
 *			  from a decimal string to the internal representation.
 *			  These symbols end up being mapped to OVERRIDE_TV
 *			  in the g*.h files.
 *
 *  A place to #define (if not defined in proper place):
 *
 *    From 1996/02/26 version of FPCE for C99:
 *
 *	__STDC_IEC_559__  Should be predefined by compiler (Annex X)
 *
 *	FLT_EVAL_METHOD	  Should be in <float.h> (5.2.4.2.2)
 *
 *    From 1994/06/30 version of FPCE for Technical Report:
 *
 *	__FPCE__	  Should be predefined by compiler (3.6)
 *
 *	__FPCE_IEEE__	  Should be predefined by compiler (3.6)
 *
 *	_MIN_EVAL_FORMAT  Should be in <float.h> (2.3.1)
 *
 *	_WIDEST_NEED_EVAL Should be in <float.h> (2.3.1)
 *
 *  plus any other #defines needed.
 *
 *  MODIFICATION HISTORY:
 *
 * 1994/09/07 - Create from myfloat.h
 * 1994/10/01 - Add HP PA: C (first pass)
 * 1994/10/01 - Add IBM RS/6000: xlc: IBM C
 * 1994/10/02 - Add IBM RS/6000: xlC: IBM C/C++ in C mode
 * 1994/10/03 - Add IBM RS/6000: xlC: IBM C/C++ in C++ mode
 * 1994/10/04 - Add x86 PC: IBM C (first pass)
 * 1994/10/04 - Add x86 PC: IBM C/C++ (first pass)
 * 1995/01/17 - Add x86 PC: Symantec C/C++ 7.0 in C mode
 * 1995/02/02 - Add WANT_CLEAN
 * 1995/02/19 - Add x86 PC: Borland C/C++ 4 (first pass)
 * 1995/02/19 - Move #define FIX_* to their own includes
 * 1995/02/24 - Separate xlc from xlC.
 * 1995/12/08 - Changed copyright from Taligent to Tydeman.
 * 1996/01/13 - Start adding FIXes for library testing
 * 1996/01/15 - Change FIX_MISSING_* to FIX_FUNCS_*
 * 1996/02/24 - Add several symbols for dec2bin conversion bugs
 * 1996/03/14 - Allow for Signaling NaNs to be an extension.
 * 1996/05/27 - Add DO_106_113 so can lint/compile other hardware.
 * 1996/06/03 - Add GNU C/C++ 2.5.7 + emx 0.8h for OS/2 in C mode.
 * 1996/07/15 - Add FPCE_TEST_LVL.
 * 1996/07/15 - Move #pragmas to here and myfloat.h; made optional.
 * 1996/07/15 - Add FP_H for either <math.h> or <fp.h>.
 * 1996/07/15 - Move #undef/#define of REDIRECT from myfloat.h
 * 1996/07/15 - Upgrade to C9X proposal WG14/N546.
 * 1996/07/21 - Added _CRAYIEEE for Cray Research.
 * 1996/08/19 - Changed *_NAN_COMPARE_* to *_NAN_COMP_*.
 * 1996/08/21 - Added INTTYPES_H to map to <inttypes.h>.
 * 1996/11/09 - Update acknowledge words as per Taligent VP & CTO.
 * 1996/11/12 - Added TEST_* concept of optional tests.
 * 1996/11/13 - Added proposed new form of Standard C pragmas.
 * 1996/11/15 - Hide each compiler's bugs in its own include file.
 * 1996/11/15 - Add NEED_EXIT_SYMS.
 * 1996/11/16 - Add FIX_FUNC_* and FIX_FUNCS_*.
 * 1996/11/17 - Moved definitions of SUFFIX, MODE from myfloat.h
 * 1996/11/17 - Moved definitions of NEED_FP_H_4_* from myfloat.h
 * 1996/11/17 - Moved definitions of SETUP1, SETUP2 from myfloat.h
 * 1996/11/17 - Add FPU_* to SETUP2.
 * 1996/11/19 - Add get prototypes for startup FPU fixup code.
 * 1996/11/21 - Moved definitions of REMAP_* from myfloat.h
 * 1997/01/16 - Improve documentation / configuration.
 * 1997/01/17 - Remove #undef FPCE_SAMPLE and #define WANT_CLEAN.
 * 1997/01/21 - __MyDefs_H -> MYDEFS_H_ (out of C's namespace).
 * 1997/01/21 - Added TEST_WIDE_*.
 * 1997/01/26 - <fenv.h> -> FENV_H (so can use one in local directory).
 * 1997/01/31 - *_MAX reserved by POSIX.2 => Rename local macro symbols.
 * 1997/02/23 - Added TG_MATH_H for <tgmath.h> -- Type Generic Math Functions.
 * 1997/09/05 - Added IMPL_* description and first macro.
 * 1997/09/05 - FIX_INEXACT_feraiseexcept -> IMPL_OVERUNDER_ALSO_INEXACT.
 * 1997/09/18 - 97/06/27 meeting changes.
 * 1997/10/03 - IMPL_INEXACT_*.
 * 1997/10/04 - FIX_DEN_UNDER -> IMPL_UNDERFLOW_DEN_LOSS.
 * 1998/04/07 - Add FIX_NORMAL_RETURN_hypot.
 * 1998/06/06 - Add OVERRIDE_TV and v????00? symbols.
 * 1998/07/10 - Move location of PC-Lint override files.
 * 1998/07/11 - Add FIX_MATH_PI (due to gcc 2.7.2 on Linux).
 * 1998/07/11 - Add FIX_FE_FLAGS.
 * 1998/07/20 - Add FIX_FENV_FUNCTIONS.
 * 1998/07/21 - Add FENV_MISSING as a "hardware/software" symbolic.
 * 1998/07/22 - Add FIX_RND_fesetround and FIX_FE_RND.
 * 1998/07/22 - Add FIX_NAN_FLOAT.
 * 1998/07/24 - Add FIX_CHANGE_STDC_IEC_559.
 * 1998/07/24 - Add _MSC_VER for Microsoft C/C++.
 * 1998/07/28 - Split BIGGER_THAN_FPMAX into constants and expressions.
 * 1998/07/28 - Split SMALLER_THAN_FPMAX into constants and expressions.
 * 1998/07/30 - Add FIX_NEG_FLIP_SIGN.
 * 1998/08/04 - Add FIX_RANDOM_SIGNED_ZERO.
 * 1998/08/05 - Add FIX_SCAN/PRINT_INF/NAN.
 * 1998/08/05 - Add IMPL_GETEXCEPT_TOO_MANY.
 * 1998/08/07 - Add FIX_TRI_OP_OF_FLOATS.
 * 1998/08/08 - Add FIX_NOISY_HUGE_VAL.
 * 1998/09/03 - Add __DCC__ for Diab Data.
 * 1998/09/10 - Add FIX_NAN_IN_ARRAY and FIX_INF_IN_ARRAY.
 * 1998/09/10 - Add IMPL_mNAN_IS_POS.
 * 1998/09/13 - Add FIX_STATIC_VECTORS.
 * 1998/09/30 - Add IMPL_IGNORE_EXTRA_DIGITS.
 * 1998/10/23 - Add FIX_strto_EQ_scanf, FIX_scanf_ROUNDS.
 * 1998/10/25 - Add FIX_DEC2BIN_ZERO, _LARGE, _INF.
 * 1998/11/09 - Add __MWERKS__ for MetroWerks CodeWarrior.
 * 1998/11/12 - Add FIX_BY_0.
 * 1998/11/15 - Add FIX_BAD_NAN_COMP_FLAG_VARCON.
 * 1998/11/15 - Add FIX_OPT_DIV_TO_MUL.
 * 1998/11/15 - Add FIX_OPT_0_MINUS_Y_TO_mY.
 * 1998/11/15 - Add FIX_STRTO_INF, FIX_STRTO_NAN.
 * 1998/11/18 - Add FIX_CONST_VAR_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_0_OVER_0_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_1_OVER_0_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_MAX_TIMES_MAX_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_MIN_TIMES_MIN_EXP_AT_TRANS.
 * 1998/11/21 - Add FIX_1_OVER_3_EXP_AT_TRANS.
 * 1998/12/12 - Add isinf().
 * 1998/12/12 - Bump FPCE_TEST_LVL to 19971024uL.
 * 1998/12/18 - Add FIX_LINK_NAME_SPACE.  Add signbit().
 * 1998/12/19 - Bump FPCE_TEST_LVL to 19980626uL.
 * 1999/02/23 - Add FIX_1_OVER_mINF.
 * 1999/03/03 - Add LARGE_ARG_* and ULP_LARGE_ARG_* for 3 trig functions.
 * 1999/03/18 - Add __TANDEM for Compaq-Tandem.
 * 1999/03/29 - Bump FPCE_TEST_LVL to 19990202uL.
 * 1999/03/30 - Add *_SCAN2BIN_* based upon *_DEC2BIN_*; runtime vs compile time.
 * 1999/04/02 - Remove sample.bug setup from here; replaced with include yourfile.bug.
 * 1999/04/09 - Add FIX_WRONG_*_DIG.
 * 1999/04/17 - nextafterx -> nexttoward.
 * 1999/04/30 - FIX ACCEPT_BAD_BIT_FIELD_SIZE -> IMPL_...
 * 1999/04/30 - FIX ACCEPT_BAD_ENUM_VAL -> IMPL_...
 * 1999/04/30 - FIX ACCEPT_BAD_ARRAY_BOUND -> IMPL_...
 * 1999/04/30 - FIX ACCEPT_BAD_CASE_VAL -> IMPL_...
 * 1999/04/30 - FIX EXTRA_DIGITS -> IMPL_IGNORE_EXTRA_DIGITS
 * 1999/05/03 - Add __WATCOMC__ for Watcom C/C++.
 * 1999/05/04 - Add FIX_INIT_SHORT_WITH_FP.
 * 1999/05/04 - Add FIX_INIT_CHAR_WITH_FP.
 * 1999/05/05 - Add __IBMC__ for IBM VisualAge for C/C++.
 * 1999/05/06 - Add FIX_EVAL_CONST_AT_LEAST_MIN.
 * 1999/05/06 - Add FIX_ULLI_FROM_POS.
 * 1999/05/06 - Add FIX_FMA_NEG_ZERO.
 * 1999/05/06 - Add FIX_INF2_type_SET_INVALID.
 * 1999/05/09 - Add IMPL_COMP_FE_DFL_ENV.
 * 1999/05/10 - Add IMPL_OK_fesetprec.
 * 1999/05/12 - FIX LDBL_GT_DBL -> IMPL_LDBL_EQ_DBL
 * 1999/05/13 - Add FIX_OPT_0_DIV_Y_TO_0.
 * 1999/05/17 - Add FIX_NAN_GOT_*.
 * 1999/05/20 - Add FIX_ZERO_GOT_*.
 * 1999/05/20 - Add FIX_INF_GOT_*.
 * 1999/05/27 - Add FIX_PRINT_mZERO, FIX_SCAN_mZERO.
 * 1999/05/29 - Add FIX_HUGE_VAL*_IS_INF.
 * 1999/06/05 - Add FIX_BIN2DEC2BIN_TWICE.
 * 1999/06/05 - Add *_BIN2DEC2BIN_ULPS (* = LD, D, and F).
 * 1999/06/08 - Add FIX_QUOT_remquo.
 * 1999/06/08 - Add FIX_MODES_*.
 * 1999/06/10 - Add more FIX_WRONG_*.
 * 1999/06/10 - Add FIX_CLOSE_*.
 * 1999/07/06 - Add FIX_PRINT_JUNK.
 * 1999/07/08 - Add FIX_OPT_INF_SUB_INF_TO_0.
 * 1999/07/09 - Add FIX_2LARGE_IS_FINITE.
 * 1999/07/10 - Add FIX_VERY_BIG_EXPONENTS.
 * 1999/07/12 - Add FIX_OPT_0_TIMES_m1_TO_p0, FIX_OPT_0_DIV_m1_TO_p0.
 * 1999/07/18 - Add FIX_ULL_2_DBL.
 * 1999/07/18 - Add FIX_LL_PP_CONSTANTS.
 * 1999/07/19 - Add LONGONG and ULONGLONG (you can define in your *.bug file).
 * 1999/07/19 - Add SLL_C and ULL_C (you can define in your *.bug file).
 * 1999/07/20 - Add FIX_POSITIVE_LLONG_MIN.
 * 1999/07/20 - Add FIX_VALID_FP_2_ULLONG.
 * 1999/08/29 - Add many FIX_PRINTF_* symbols.
 * 1999/09/19 - Add FIX_strto_RND_THEN_NEG.
 * 1999/11/02 - FIX_FUNCS_nan_0_BY_0 -> IMPL_INCONSISTENT_nan
 * 1999/11/02 - Add MODE, A_MODE, R_MODE, W_MODE.
 * 1999/12/01 - Add IMPL_MAX_*_RADIX, FIX_SMALL_PRINTF_ENV_LIMIT.
 * 2000/03/01 - Make classification explicit in each file.
 * 2000/03/01 - Remove confidential so can post to public ftp site.
 * 2000/03/14 - Add IBM S/390 MVS symbols.
 * 2000/06/16 - Add IMPL_(UCE/SCE/USE/SSE/UIE/SIE)_IS_(UCHAR/SCHAR/USHORT/SSHORT/UINT/SINT).
 * 2000/06/16 - Del FIX_ENUM_IS_INT; replaced by above line.
 * 2000/07/24 - Add FIX_NAMESPACE_STD.
 * 2000/12/03 - Add FIX_CLASS_UNNORMALS, FIX_CLASS_MIN_NORMALS.
 * 2000/12/03 - Add FIX_CLASS_PSEUDO_INF, FIX_CLASS_PSEUDO_NAN.
 * 2000/12/03 - Add FIX_HEX_FP_PRAGMA, FIX_FE_MACROS.
 * 2000/12/10 - Add Sun Sparc/x86/ia64 to elif chain.
 * 2001/01/16 - Add another HP to elif chain.
 * 2001/03/06 - Add IMPL_MZERO_EXP.
 * 2001/03/07 - Add IMPL_ODD_UP, IMPL_EVEN_UP.
 * 2001/03/07 - Add FIX_PRINTF_SHARP_RND.
 * 2001/03/11 - Redo location of PC-Lint.
 * 2001/03/14 - Add FIX_PRINTF_e_RND.
 * 2001/06/23 - Add x86 PC: Digital Mars C/C++ 8 in C mode.
 * 2001/06/23 - Add FIX_FP_IN_MATH_H.
 * 2001/06/24 - Add FIX_ARG_GOT_*.
 * 2001/06/26 - Del #undef FIX_SYM_* after #include user.bug file.
 * 2001/12/27 - Mod FPCE_TEST_LVL to C99 TC1 date.
 * 2001/12/29 - Add (void) to some uses of feclearexcept in t2*.fjt.
 * 2002/01/07 - Add FIX_USABLE_FE_DFL_ENV to here (added to code in '96).
 * 2002/01/13 - Add FIX_CONST_IN_TYPEDEF_STRUCT.
 * 2002/01/15 - Add FIX_HEX_PI.
 * 2002/01/15 - Add FIX_MYFLOAT_*.
 * 2002/01/17 - Add FIX_MINUS_EQUAL, FIX_MINUS_MINUS.
 * 2002/01/23 - Add FIX_DIG_LET_PP_NUMBER.
 * 2002/01/24 - Add FIX_ULI_FROM_FLT, FIX_ULLI_FROM_FLT.
 * 2002/01/24 - Add FIX_ENUM_TO_ANDAND, FIX_ENUM_TO_OROR.
 * 2002/01/28 - Add FIX_type_FROM_FP, where type is one of ULI, SLI, UI, SI, ...
 * 2002/01/28 - Add FIX_ULLI_op_EQ_FP, where op is PLUS, MINUS, STAR, DIV.
 * 2002/01/28 - Add FIX_SLLI_op_EQ_FP, where op is PLUS, MINUS, STAR, DIV.
 * 2002/01/29 - FIX_MINUS_EQUAL -> FIX_FP_MINUS_EQ_FP.
 * 2002/01/29 - FIX_MINUS_MINUS -> FIX_FP_MINUS_MINUS.
 * 2002/01/29 - FIX_ULL_2_DBL -> FIX_DBL_FROM_ULLI, and FIX_FP_FROM_ULLI.
 * 2002/01/29 - Add FIX_LDBL_MINUS_EQ_FP, FIX_LDBL_MINUS_EQ_INT.
 * 2002/02/10 - Add LCC to elif chain.
 * 2002/04/24 - Add FIX_FP_PLUS_PLUS.
 * 2002/05/07 - Add FIX_DEC2BIN_NAN.
 * 2002/05/21 - Add filename to SETUP 1.
 * 2002/05/21 - Setup for Perennial.
 * 2002/05/29 - Add FIX_*_RANDOM_INVALID.
 * 2002/06/26 - Add FIX_SCANF_LDBL.
 * 2002/11/26 - Add FIX_SCAN_F and FIX_PRINT_F.
 * 2002/11/26 - Add FIX_SCAN_aA and FIX_PRINT_aA.
 * 2002/12/01 - Add FIX_PRINTF_aA_HAS_EXPONENT.
 * 2002/12/01 - Add FIX_PRINTF_aA_HEX_DOT.
 * 2002/12/07 - Add IMPL_RAISE_WITH_IMPLIED_INEXACT.
 * 2002/12/12 - Add FIX_PRINTF_aA_HAS_EXP_SIGN.
 * 2003/01/16 - Add WG14/N782 to list of FPCE_TEST_LVL changes.
 * 2003/01/16 - Add FIX_AGG_INIT_IS_STATIC.
 * 2003/01/23 - Add Intel's ICC to elif chain.
 * 2003/01/26 - Add FIX_BAD_HEX_SMALL.
 * 2003/01/29 - Add another FIX_NAN_GOT_*.
 * 2003/01/29 - Add another FIX_INF_GOT_*.
 * 2003/02/03 - Add FIX_SIZEOF_BIT_FIELD.
 * 2003/02/05 - Add another FIX_NORMAL_RETURN_*.
 * 2003/02/05 - Add FIX_OVERLOAD_* (where * is each math function).
 * 2003/02/07 - Add FIX_PP_EXP.
 * 2003/02/07 - Add FIX_INT_ANDAND_FLT.
 * 2003/02/07 - Add FIX_BROKEN_PP.
 * 2003/02/07 - Add FIX_BAD_COMP_VAR_CON.
 * 2003/02/07 - Add FIX_BAD_COMP_VAR_VAR.
 * 2003/02/07 - Add FIX_BAD_COMP_CON_VAR.
 * 2003/02/08 - Add FIX_SIZEOF_* (* is one of classification macros).
 * 2003/02/09 - Add FIX_CLASS_SIGNAL_NAN.
 * 2003/02/15 - Add FIX_0F_OVER_0F_IS_NAN.
 * 2003/02/15 - Add FIX_0D_OVER_0D_IS_NAN.
 * 2003/02/16 - Add Comeau Computing and Edison Design Group to elif chain.
 * 2003/02/17 - Add FIX_CLOSE_MAXm1_LDBL.
 * 2003/02/19 - Add FIX_IMPLICIT_FLUSH.
 * 2003/02/27 - Add FIX_OPT_COMMON_FACTOR.
 * 2003/03/01 - Add FIX_LONGLONG_WITH_FP_CONSTS.
 * 2003/03/01 - Add FIX_MATH_FUNC_OF_INTEGER.
 * 2003/03/08 - Add FIX_printf_ROUNDS.
 * 2003/03/10 - Add IMPL_MAX_E_DIGITS.
 * 2003/03/23 - Add FIX_MINUS_DBL_signbit.
 * 2003/03/23 - Add FIX_MINUS_LDBL_signbit.
 * 2003/04/17 - Add FIX_BIN2DEC_LARGE.
 * 2003/05/11 - FIX_NEG_NAN -> IMPL_pNAN_IS_NEG.
 * 2003/05/11 - FIX_mNAN_IS_POS -> IMPL_mNAN_IS_POS.
 * 2003/05/11 - Add IMPL_mNAN_EQ_pNAN.
 * 2003/05/11 - Add IMPL_BAD_ROUNDTRIP_OF_NAN.
 * 2003/06/24 - Add description of ULP_*_sum.
 * 2003/07/01 - Fix several spelling errors.
 * 2003/07/10 - Add FIX_INVALID_OCTAL.
 * 2003/07/11 - Add FIX_FPZERO_OROR_VAR.
 * 2003/07/11 - Add FIX_INT_PLUS_EQ_FP.
 * 2003/07/11 - Add FIX_INT_MINUS_EQ_FP.
 * 2003/07/11 - Add FIX_INT_STAR_EQ_FP.
 * 2003/07/11 - Add FIX_INT_DIV_EQ_FP.
 * 2003/07/11 - Add FIX_signbit_NON_VAR.
 * 2003/07/16 - Add FIX_SEMIBROKEN_PP.
 * 2003/08/08 - Only do pragma fp_wide_* if user does TEST_WIDE_*.
 * 2003/08/21 - Mention feholdexcept() as another way to disable traps.
 * 2003/08/30 - Redo FIX_*_IS_A_MACRO to use true case of name.
 * 2003/11/17 - Add FIX_SCAN_LOOKAHEAD, FIX_STRTO_LOOKAHEAD.
 * 2003/11/17 - Add FIX_SCAN_PERCENT_n.
 * 2003/12/01 - Add ULP_strto*.
 * 2003/12/01 - Add FIX_BAD_EXPONENT, FIX_BAD_BIN_EXPONENT.
 * 2003/12/01 - Add FIX_BAD_0X, FIX_BAD_INF, FIX_BAD_NAN.
 * 2003/12/01 - Add FIX_STRTO_ZERO_PTR_DIFF, FIX_BAD_SIGNS.
 * 2003/12/02 - Add FIX_SCAN_JUNK, FIX_SCAN_NODIGITS.
 * 2003/12/02 - Add FIX_C99_freopen, FIX_TEST_fscanf, FIX_TEST_ftell.
 * 2003/12/03 - Add FIX_SCAN_NODOT_E, FIX_SCANF_FLT.
 * 2003/12/03 - Add FIX_SCAN_FP_WS.
 * 2003/12/28 - Add FIX_STDBOOL.
 * 2003/12/30 - Add FIX_BOOL.
 * 2003/12/30 - Add FIX_BOOL, FIX_TRUE_BOOL.
 * 2003/12/30 - Add FIX_aA_LEADING_ZEROS.
 * 2003/12/30 - Add FIX_PRINTF_RC.
 * 2004/01/02 - Add FIX_IMPLICIT_CHAR_PTR.
 * 2004/01/03 - Add FIX_SCAN_EOF.
 * 2004/01/03 - Add FIX_INT_MINUS_EQ_FPCONST.
 * 2004/01/04 - Add FIX_ASSIGN_TO_BOOL.
 * 2004/01/04 - Add FIX_OP_BOOL_BIT_FIELD.
 * 2004/01/05 - Add FIX_BIN2HEX2BIN_TWICE.
 * 2004/01/06 - Add *_BIN2HEX_A_ULPS.
 * 2004/01/06 - Add FIX_BAD_BITFIELD_PROMOTION.
 * 2004/01/06 - Add FIX_BAD_BOOLBITFIELD_PROMOTION.
 * 2004/01/06 - Add FIX_QUIET_ASSIGN_TO_BOOL.
 * 2004/01/06 - Add FIX_BOOL_FROM_PTR.
 * 2004/01/06 - Add FIX_BOOL_FROM_FLT.
 * 2004/01/06 - Add FIX_BOOL_FROM_DBL.
 * 2004/01/06 - Add FIX_BOOL_FROM_LDBL.
 * 2004/01/06 - Add FIX_EQUALEQUAL_BOOL_PLUSEQUAL.
 * 2004/01/07 - Change FIX_INTTYPES -> FIX_INTTYPES_H.
 * 2004/01/07 - Change FIX_ISO646 -> FIX_ISO646_H.
 * 2004/01/07 - Change FIX_LOCALE_HEADER -> FIX_LOCALE_H.
 * 2004/01/07 - Change FIX_STDBOOL -> FIX_STDBOOL_H.
 * 2004/01/07 - Add FIX_COMPLEX_H, STDINT_H, WCHAR_H, WCTYPE_H.
 * 2004/01/07 - Add FIX_REG_VARS.
 * 2004/01/09 - Add FIX_BIG_BITFIELD.
 * 2004/01/09 - Add FIX_BAD_INTEGER_PROMOTION.
 * 2004/01/10 - Add IMPL_MIX_BOOL_AND_INT.
 * 2004/01/10 - Add FIX_ZERO_WIDTH_BOOL.
 * 2004/01/10 - Add FIX_OFFSETOF.
 * 2004/01/11 - Add FIX_ACC_BAD_BOOL_BITFIELD_WIDTH.
 * 2004/01/11 - Add FIX_ACC_BAD_BOOL_BITFIELD_DECL.
 * 2004/01/14 - Add FIX_BOOL_FROM_FRACTION.
 * 2004/01/14 - Add FIX_BOOL_BITFIELD.
 * 2004/01/24 - Add FIX_BAD_RET_fesetround.
 * 2004/01/24 - Add FIX_BAD_RET_feupdateenv.
 * 2004/01/28 - Add FIX_PRINT_aA_SMALL_PREC.
 * 2004/01/29 - FIX_PRINTF_p_RND -> FIX_PRINTF_aA_RND
 * 2004/04/23 - Add uses of CLEAR_ALL and RAISE_ALL.
 * 2004/05/01 - Add IMPL_FLT_EVAL_CONST, IMPL_FLT_EVAL_CONST_EXP, IMPL_FLT_EVAL_OP
 * 2004/05/08 - Add IMPL_FLT_EVAL_STRTO.
 * 2004/05/10 - Add FIX_WRONG_FLT_EPS.
 * 2004/05/27 - Add FIX_OPT_MAX_x_MAX, FIX_OPT_MIN_x_MIN.
 * 2004/05/28 - Add FIX_FLAG_hypot_EVENODD.
 * 2004/05/28 - Add IMPL_FLT_EVAL_OP_ANON.
 * 2004/05/30 - Add FIX_PLUS_EQ_FP_FUNC.
 * 2004/05/30 - Add FIX_FP_PTR_PLUS_EQ_BOOL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_PLUSEQUAL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_MINUSEQUAL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_STAREQUAL.
 * 2004/05/30 - Add FIX_EQUALEQUAL_FP_DIVEQUAL.
 * 2004/06/03 - Add IMPL_MAX_SCAN_BEFORE_RADIX, IMPL_MAX_SCAN_AFTER_RADIX.
 * 2004/06/03 - Add IMPL_MAX_PRINT_S.
 * 2004/06/11 - Add FIX_VLA, FIX_VLA_CONST_EXP, FIX_TRUE_VLA.
 * 2004/06/12 - Add FIX_TYPEDEF_VLA_ONCE.
 * 2004/06/13 - Add FIX_ACC_*VLA*.
 * 2004/06/13 - Add FIX_COMPOUND_LIT.
 * 2004/07/11 - Add FIX_FLEX_ARRAY.
 * 2004/07/13 - Add FIX_OFFSET_FLEX.
 * 2004/07/13 - Add FIX_ACC_*FLEX_ARRAY*.
 * 2004/07/17 - ULP_strtold -> LD_STRTOBIN_ULPS.
 * 2004/07/17 - ULP_strtod -> D_STRTOBIN_ULPS.
 * 2004/07/17 - ULP_strtof -> F_STRTOBIN_ULPS.
 * 2004/07/19 - Add IMPL_FLT_EVAL_INT2FLT.
 * 2004/07/24 - Add IMPL_pNAN_IS_MIXED, IMPL_mNAN_IS_MIXED.
 * 2004/07/24 - Add FIX_BAD_NAN_EQEQ_FLAG.
 * 2004/07/30 - Add FIX_NEGATIVE_LLONG_MAX.
 * 2004/08/02 - Add __LMPCC__ to elif chain.
 * 2004/08/05 - Add FIX_ZERO_HEX.
 * 2004/08/07 - Add FIX_pEXPf_HEX.
 * 2004/08/07 - Reformat #if's.
 * 2004/08/26 - Add FIX_TOO_HARD_TOO_COMPILE.
 * 2004/09/02 - Add TEST_RND_UP_DECADE.
 * 2004/11/28 - Add FIX_CONCAT_WIDE_AND_NARROW.
 * 2004/11/28 - Add many FIX_WPRINT_*.
 * 2004/11/28 - Add many FIX_WSCAN_*.
 * 2005/01/07 - Add Apple Mac OS X on PowerPC.
 * 2005/01/10 - Add FIX_SYM_*_ENUM.
 * 2005/02/05 - Add list of DRs in TC2 that affect math; bump FPCE_TEST_LVL.
 * 2005/02/13 - Add words about IMPL_INF_FLAGS to FIX_QUIET_INF.
 * 2005/02/24 - Add IMPL_aA_PREC, IMPL_LaA_PREC.
 * 2005/02/25 - Add FIX_[W]PRINTF_NEGATIVE_RC.
 * 2005/02/27 - Add IMPL_aA_BITS, IMPL_LaA_BITS.
 * 2005/03/22 - Add FIX_*PRINTF_aA_HAS_B*_HEX_DIG.
 * 2005/04/07 - Add FIX_NEED_FINAL_NEW_LINE.
 * 2005/05/06 - Add FIX_FILE_SCOPE_FP_INIT, FIX_FP_EXP_IN_INIT.
 * 2005/05/06 - Add FIX_EVAL_CONST_EXP_AT_LEAST_MIN.
 * 2005/05/08 - Add fenvon.h and fpconoff.h.
 * 2005/05/22 - Add FIX_INLINE, FIX_BAD_INLINE_CALL.
 * 2005/05/23 - Add FIX_IGNORE_CAST.
 * 2006/03/16 - Add IEEE-754R Decimal FP related items.
 * 2006/03/20 - Indent #if's.
 * 2006/03/23 - Add FMT_*_SCAN.
 * 2006/03/26 - Add FIX_SCAN_EARLY_EOF.
 * 2006/03/30 - Rename WANT DEC FP macro.
 * 2006/04/07 - Rename FIX_*_RND to IMPL_NO_*_RND.
 * 2006/04/08 - Add FIX_SCAN_LATE_EOF.
 * 2006/05/17 - Move NEED_EXIT_SYMS to myfloat.h (after include std headers).
 * 2006/07/11 - Add FIX_BOTTOM_N_BITS, FIX_BOTTOM_N_DIGS.
 * 2006/07/15 - Add many more IMPL_* symbols.
 * 2006/08/17 - Add Decimal FP complex and imaginary (long term planning).
 * 2006/09/29 - Add IMPL_fopen_wb, IMPL_freopen_wb, and IMPL_freopen_rb.
 * 2007/06/13 - Add ARM.
 * 2008/02/02 - Add many symbols due new code in last 9 months.
 * 2008/02/11 - Change RND_*d64 to RND10_*.
 * 2008/06/18 - Add FIX_CONST_SCALAR_PARM, FIX_CONST_REGISTER.
 * 2008/06/20 - Indent #if's.
 * 2008/07/14 - Shorten marco symbols to less than 32 chars.
 * 2008/08/11 - Add MIN_FLAGS and MIN_FLAGS_OPT.
 * 2008/08/11 - Add IMPL_FLT_EVAL_OP_CONTRACT.
 * 2008/08/24 - Move FP_F(), FP_D(), FP_LD(), FP_F10(), FP_D10(), FP_LD10() from flt.
 * 2008/08/25 - Add IMPL_SPURIOUS_ERRNO.
 * 2008/08/25 - Add IMPL_COHORT_*.
 * 2008/08/26 - Change IMPL_nan*_INCONSISTENT.
 * 2008/08/27 - Add RX, RXm1, RXp1 since needed so many places.
 * 2008/09/10 - Add IMPL_SAME_NAN, IMPL_SAME_2NAN.
 * 2008/09/17 - FIX_* to IMPL_* for real-floating.
 * 2008/09/26 - Add many symbols added for decimal FP testing.
 * 2008/10/04 - Add FIX_SLL_FROM_PTR, FIX_ULL_FROM_PTR.
 * 2008/10/07 - Add FIX_PTR_FROM_SLL, FIX_PTR_FROM_ULL.
 * 2008/11/06 - Add FIX_DEC2DFP_ZERO, *10_DFP2BFP_ULPS.
 * 2008/11/19 - Add FIX_DEC2BIN_SIGN and related symbols.
 * 2008/12/15 - Add DFP_TEST_LVL.
 * 2009/01/14 - Add FIX_PRAGMA_DBL_CONST_DFP64 and related.
 * 2009/01/16 - Fix FP_D() to work with #pragma STDC FLOAT_CONST_DECIMAL64 ON.
 * 2009/02/07 - Add IMPL_FLT_EVAL_RET, IMPL_FLT_EVAL_IN_RET.
 * 2009/04/02 - Add Rf, Rd, Rld.
 * 2009/04/26 - _EVAL_FLOAT -> _EVAL_FLT.
 * 2009/04/26 - _EVAL10_FLOAT -> _EVAL10_F10.
 * 2009/06/19 - _WRONG_F10_ ->  _WRONG_DEC32_; same for _CLOSE_
 * 2009/06/19 - _WRONG_D10_ ->  _WRONG_DEC64_; same for _CLOSE_
 * 2009/06/19 - _WRONG_LD10_ ->  _WRONG_DEC128_; same for _CLOSE_
 * 2009/06/23 - Changed definition of BOOL_CAST().
 * 2009/08/14 - FIX BAD TRANS TIME PREC -> FIX_EVAL_CONST_EXP_AT_LEAST_MIN.
 * 2009/08/20 - Add FIX_DBL_PLUS_DBL_TIMES_DBL.
 * 2009/08/20 - Major reorganization of symbols; try to group similar together.
 * 2009/08/20 - Add FIX_UNKNOWN_LCC.
 * 2009/08/26 - Add FIX_NEED_PARENS_*.
 *
 ***********************************************************************/

#ifndef MYDEFS_H_			/* not in C's namespace */
  #define MYDEFS_H_

/*
 * The Floating-Point C Extensions (FPCE) has evolved over the years.
 * First it was proposals to Numerical C Extensions Group (NCEG), then to
 * a subgroup of ANSI C (X3J11.1), then to ANSI C (X3J11), and finally to
 * ISO C (WG14).  It has gone into a Technical Report for X3J11, into
 * the draft revision of C (C9X) for WG14, and the final C99 of WG14.
 * It has since been corrected by Defect Report (DR) 202 (part of TC1)
 * and many DRs in TC2 (Technical Corrigendum).
 * This macro defines the level of FPCE that is being tested:
 *	20080811uL = WG14/N1336 C1x = C99 + initial changes
 *	20070909uL = WG14/N1256 = C99+TC1+TC2+TC3
 *	200?????uL = C99 TC3 (Technical Corrigendum 3)
 *					DR 319: printf("%a",1.0) and trailing zeros
 *					DR 318: (double)0.1f w/ FLT_EVAL_METHOD==2
 *					DR 301: Meaning of FE_* macros
 *					DR 300: Translation time exp. eval.
 *					DR 299: Is cabs() type-generic
 *					DR 297: FE_* macros
 *					DR 296: exp(INF)
 *					DR 293: complex
 *					DR 291: inexact
 *					DR 290: FP precision
 *					DR 287: FP flags
 *	20050505uL = WG14/N1124 = C99+TC1+TC2
 *	20041115uL = C99 TC2 (Technical Corrigendum 2)
 *					DR 285: imaginary
 *					DR 275: FE_ALL_EXCEPT
 *					DR 244: tgamma()
 *					DR 243: many math functions
 *					DR 242: logb()
 *					DR 241: pow()
 *					DR 240: ilogb(), *lrint(), *lround()
 *					DR 239: nexttoward()
 *					DR 238: fma()
 *					DR 233: printf using %g
 *					DR 225: strto* of INF, NAN
 *					DR 224: fpclassify
 *					DR 223: FP_FAST_FMA*
 *					DR 218: sign of zero, inf, NaN
 *					DR 211: accuracy of I/O conversions
 *					DR 207: imaginary
 *	20010731uL = WG14/N949 = C99+TC1
 *	20010901uL = C99 TC1 (Technical Corrigendum 1)
 *					DR 210: fprintf %a, %A; strtod of hex
 *					DR 202: fenv.h functions return int
 *	19991216uL + C99, Published by ISO
 *	19990202uL = WG14/N873, J11/99-003, 99/02/02 Disposition of Comments: FCD
 *					pow(+,NAN) = +1  (Post meeting email)
 *					pow(+/-1,+/-INF) = +1
 *					tgamma(+/-0) = +/-INF + divbyzero
 *					lgamma(1) = +0
 *					lgamma(2) = +0
 *					log2(1) = +0
 *	19981010uL = WG14/N845, J11/98-058, 98/10/10 Minutes
 *					nextafterx -> nexttoward
 *					strtod("-number",NULL) and rounding
 *					strtod("0x12",NULL) now valid (no . or p)
 *	19980626uL = WG14/N841, J11/98-040, 98/08/03 Disposition of Comments:
 *					fesetround & feholdexcept return values
 *					DECIMAL_DIG now in <float.h>
 *	"	   = WG14/N829, J11/98-028, 98/05/26 FP & math accuracy
 *	"	   = WG14/N826, J11/98-025, 98/05/29 gamma -> tgamma
 *	"	   = WG14/N782, J11/98-1461, 97/10/20 auto aggregate initialization
 *	19971024uL = WG14/N757, X3J11/97-120, 97/09/15 FP Cleanup items:
 *					remove scalb
 *					combinations of FE_* macros are distinct
 *	19970627uL = WG14/N734, X3J11/97-097, 97/06/25 FP Cleanup items:
 *					lgamma(-inf) now returns +inf
 *	"          = WG14/N728, X3J11/97-091, 97/06/25 scalbn/scalbln
 *	"          = WG14/N694, X3J11/97-057, 97/05/23 Enhancements:
 *					INFINITY, NAN to type float
 *					fma()
 *	"          = WG14/N693, X3J11/97-056, 97/05/23 Type-Generic Math
 *	19970207uL = WG14/N674, X3J11/97-037, 97/02/28 C9X Draft 9: has(?) following:
 *	"          = WG14/N657, X3J11/97-020, 97/02/07 Enhancements:
 *					scalb -> scalb/scalbn
 *					logb -> logb/ilogb
 *					(rint/round)tol* -> l*(rint/round)
 *					cbrt
 *	"          = WG14/N638, X3J11/97-001, 97/01/03 Enhancements:
 *					feraise over/under => may do inexact
 *					isinf() macro
 *					x/x is not 1.0 for IEC 559
 *	"          = WG14/N631, X3J11/96-095, 96/11/11 Standard pragmas
 *	19970103uL + WG14/N643, X3J11/97-006, 97/01/03 C9X Draft 8 (on public site)
 *	19960912uL = WG14/N595, X3J11/96-059, 96/09/12 Base FPCE in C9X
 *					(rint/round)toll
 *	19960226uL = WG14/N546, X3J11/96-010, 96/02/26 <fp.h> -> <math.h>
 *	19950417uL + WG14/N403, X3J11/95-004, 95/04/17 NCEG Tech Report
 *	19940630uL = WG14/N364, X3J11/94-049, 94/06/30 Taligent basis; FPCE draft 3
 *	19910417uL =             NCEG/91-015, 91/04/17 Early draft
 *
 * In the above list, '+' means that level is not referenced anywhere.
 */
  #ifndef   FPCE_TEST_LVL
    #define FPCE_TEST_LVL 20041115uL
  #endif

/*
 * The Decimal Floating-Point (DFP) proposal has evolved over the years.
 * This macro defines the level of DFP that is being tested:
 *      20080516uL = WG14/N1312: FLOAT_CONST_DECIMAL64 pragma added,
 *				 TTDT dropped
 *      20080313uL = WG14/N1290
 *      20070527uL = WG14/N1241
 *      20061128uL = WG14/N1201: DEC*_DEN -> DEC*_SUBNORMAL_MIN
 *				 DEC*_MIN_EXP corrected.
 *				 DEC*_MAX_EXP corrected.
 *      20060523uL = WG14/N1176: DFP_MAX_PRECISION pragma dropped; gcc 4.3.2
 *      20060227uL = WG14/N1154: Explains 'd' and 'D' suffix.
 *      20051026uL = WG14/N1150 (Tech Report 24732); TTDT added,
 *				'd' and 'D' suffix added (but not explained)
 *      20050307uL = WG14/N1107
 *                        N1092 TTDT proposal
 *      20040927uL = WG14/N1077
 *      20040303uL = WG14/N1057
 *      20030901uL = WG14/N1016 (Decimal Floating-Point)
 */
  #ifndef   DFP_TEST_LVL
    #define DFP_TEST_LVL 20080516uL
  #endif

/*
 * All the t1xx*003 tests need SRC_PATH to know where to read the test
 * vectors from.
 * Two examples are:
 *	"E:\\fpcets\\real\\"
 *	"../real/"
 */
  #undef SRC_PATH		/* t1xx*0003 */

/*
 * If m0100211 or m0210199 need to be run on your system, then, you
 * will need to tailor RES?_PATH, SRC?_PATH, PROG_SUFFIX symbols.
 * They define the path to the source directory and the suffix to add
 * to file names (as strings).
 * Two examples are:
 *	"E:\\fpcets\\manual\\"	".fjt"
 *	"../manual/" 		".c"
 */
  #undef RES2_PATH		/* m0100211 */
  #undef SRC2_PATH		/* m0100211 */
  #undef RES3_PATH		/* m0210199 */
  #undef SRC3_PATH		/* m0210199 */
  #undef PROG_SUFFIX		/* m0100211, m0210199 */

/*
 * Pick one of the next two to allow errors to show up or be bypassed.
 * The #undef/#define for this symbol should be done in either the *.bug
 * file included by this file, or in the make or compiler options.
 */
  #if 0
    #undef	WANT_CLEAN	/* Allow errors to show up */
    #define	WANT_CLEAN 1	/* Bypass FIX_* implementation errors */
  #endif

/*
 * If you are compiling each test case along with the support files together
 * in one compile (instead of separate compiles followed by link edit),
 * then this symbol needs to be defined.  Mainly used for sample tests
 * t0120200.c, t1150000.c, t1150001.c; so can NOT be #undef'ed here.
 */
  #if 0
    #define FPCE_SAMPLE	/* Compile test and support code together */
    #undef  FPCE_SAMPLE	/* Separate compiles, followed by link edit */
  #endif

/*
 * Mode used when freopen stdout to write text to a file (if REDIRECTing).
 * Standard C is "w", but some compilers want "wt" to indicate text.
 * In C89, the "t" in "wt" is valid by footnote 115.
 * In C99, the "t" in "wt" is undefined behavior, but footnote 228 allows it.
 */
  #undef MODE

/*
 * Mode used when fopen a file to read text from a file.  This is used in
 * the m0210199.fjt and m0100211.fjt (normally, not run by you).
 * The default is "r".  See MODE above for comments on "t".
 */
  #undef R_MODE

/*
 * Mode used when fopen a file to write text to a file.  This is used in
 * the m0210199.fjt and m0100211.fjt (normally, not run by you).
 * The default is "w".  See MODE above for comments on "t".
 */
  #undef W_MODE

/*
 * Mode used when fopen stdout to append text to a file.  This is used in
 * the DOS program arg2file.fjt which is used as part of the build process.
 * The default is "a".  See MODE above for comments on "t".
 */
  #undef A_MODE

/*
 * Mode used when fopen or freopen a temp binary file in t304* for writing
 * and reading.
 */
  #undef IMPL_fopen_wb
  #undef IMPL_freopen_wb
  #undef IMPL_freopen_rb

/*
 * Test rounding up past a decade boundary in tbin2dec.
 */
  #undef  TEST_RND_UP_DECADE

/*
 * Test optional flags in g1errno.h
 */
  #undef  TEST_OPT_FLAGS

/*
 * Hardware and software support setting the precision dynamically at runtime.
 * This is NOT required by FPCE.  It is used on an Intel 80*87 test case
 * development system to attempt to test running test cases on other hardware.
 * Was FIX_STATIC_PRECISION.  Assumes:
 * Functions
 *	int fegetprec( void );
 *	int fesetprec( int precision );
 * Macros
 *	FE_FLTPREC
 *	FE_DBLPREC
 *	FE_LDBLPREC
 */
  #undef TEST_DYNAMIC_PRECISION

/*
 * Hardware and software support enable and disable of trapping dynamically
 * at runtime. This is NOT required by FPCE.  Assumes:
 * Functions
 *	int fetesttrap( int traps );
 *	int feenabletrap( int traps );
 *	int fedisabletrap( int traps );
 *	void fegettrapflag( fetrap_t *flagp, int traps );
 *	void fesettrapflag( const fetrap_t *flagp, int traps );
 * Macros
 *	FE_TRAP_INVALID
 *	FE_TRAP_DIVBYZERO
 *	FE_TRAP_OVERFLOW
 *	FE_TRAP_UNDERFLOW
 *	FE_TRAP_INEXACT
 *	FE_TRAP_ALL
 * Typedef
 *	fetrap_t
 */
  #undef TEST_TRAPPING

/*
 * If Signaling NaNs ever get supported, this symbol will be defined which
 * should then activate additional code in the test suite.  Until then,
 * Signaling NaNs are replaced with Quiet NaNs.  Was SNAN_ SUPPORTED once.
 */
  #undef TEST_SNAN

/*
 * As FPCE has evolved, there continue to be more proposals to change it.
 * This enables testing those proposals still outstanding.  This mainly
 * affects m0210199.fjt and m0210201.h which are used to generate the
 * e021*.fjt tests of symbols in the correct headers.
 */
  #undef TEST_PROPOSALS

/*
 * The FILE structure members of the form _x (instead of __x or _X) are a
 * possible violation of the user's name space.  But, _x could also be a
 * valid file scope variable or function (which is part of the implementator's
 * name space).  Was FIX_FILE_MEMBERS.
 */
  #undef TEST_FILE_MEMBERS

/*
 * Several functions take pointer arguments.  It is not defined what will
 * happen if those functions are called with NULL pointers.  It is assumed
 * that 6.3.3.2 Address and indirection operators -- dereferencing a NULL
 * pointer is undefined behavior applies.  Also, 7.1.7 Use of library
 * functions -- NULL pointer argument is undefined behavior.  Defining this
 * symbol enables the tests of invoking those functions with NULL pointers.
 */
  #undef TEST_NULL_PTR

/*
 * FPCE for the Technical Report had #pragmas for allowing variables,
 * parameters to functions, and return result from functions to be stored
 * using more precision than was required for the type.  When FPCE got
 * voted into C99, these were dropped.  So, the tests of these features
 * are now optional.
 */
  #undef TEST_WIDE_VARS		/* #pragma fp_wide_variables */
  #undef TEST_WIDE_PARMS	/* #pragma fp_wide_function_parameters */
  #undef TEST_WIDE_RETURNS	/* #pragma fp_wide_function_returns */

/*
 * Precision of LDBL should be greater then DBL.  If long double is fully
 * supported, but its size and representation are the same as double, then
 * this symbol needs to be defined.  Contrast this with REMAP_LDBL.
 * IMPL_LD10_EQ_D10 is for Decimal FP.
 * Implementations that need this:
 *   x86/x87 Win  Microsoft
 *   x86/x87 DOS  Symantec 7
 *   x86/x87 OS/2 Watcom
 */
  #undef IMPL_LDBL_EQ_DBL
  #undef IMPL_LD10_EQ_D10

/*
 * What is the success return code from the optional fesetprec() function?
 * At one time it was 1, now it is 0 to match the UK CD comments.
 */
  #undef IMPL_OK_fesetprec

/*
 * Is *FE_DFL_ENV comparable (bit for bit) to the result of fegetenv
 * of the default environment (the one at startup).  With this defined,
 * the compare will not be done.
 */
  #undef IMPL_COMP_FE_DFL_ENV

/*
 * Is FPU environment, as returned by fegetenv, comparable (bit for bit)
 * to the environment from feholdexcept or another fegetenv.
 * With this defined, the compare will not be done.
 */
  #undef IMPL_COMP_FE_GET_ENV

/*
 * Does fegetexceptflag get just the exceptions requested (via the 2nd
 * argument), or does it get more?
 */
  #undef IMPL_GETEXCEPT_TOO_MANY

/*
 * Do feraiseexcept(FE_OVERFLOW) and feraiseexcept(FE_UNDERFLOW) also
 * raise inexact?
 */
  #undef IMPL_OVERUNDER_ALSO_INEXACT	/* both raise inexact */
  #undef IMPL_OVER_ALSO_INEXACT		/* just overflow raises inexact */
  #undef IMPL_UNDER_ALSO_INEXACT	/* just underflow raises inexact */

/*
 * Do feraiseexcept(FE_OVERFLOW) and feraiseexcept(FE_UNDERFLOW) also
 * raise inexact and return zero, as if, feraise*(over/under+inexact)?
 * This only works if IMPL_OVERUNDER_ALSO_INEXACT also defined.
 * Affects test t2121000.
 */
  #undef IMPL_RAISE_WITH_IMPLIED_INEXACT

/*
 * Do trig, hyperbolic, base-e exp, base-e log, error, and lgamma functions
 * always or sometimes raise inexact when value is inexact?  Choices:
 *   #define IMPL_INEXACT_xxx FE_INEXACT -- always (default)
 *   #define IMPL_INEXACT_xxx 0 -- sometimes
 * These are the required setting of inexact.  Inexact will always be optional
 * (except for cbrt for exact cases, where it is optional).
 */
  #undef IMPL_INEXACT_cos
  #undef IMPL_INEXACT_sin
  #undef IMPL_INEXACT_tan
  #undef IMPL_INEXACT_acos
  #undef IMPL_INEXACT_asin
  #undef IMPL_INEXACT_atan
  #undef IMPL_INEXACT_atan2
  #undef IMPL_INEXACT_cosh
  #undef IMPL_INEXACT_sinh
  #undef IMPL_INEXACT_tanh
  #undef IMPL_INEXACT_acosh
  #undef IMPL_INEXACT_asinh
  #undef IMPL_INEXACT_atanh
  #undef IMPL_INEXACT_exp
  #undef IMPL_INEXACT_expm1
  #undef IMPL_INEXACT_log
  #undef IMPL_INEXACT_log1p
  #undef IMPL_INEXACT_erf
  #undef IMPL_INEXACT_erfc
  #undef IMPL_INEXACT_lgamma
  #undef IMPL_OPT_INEXACT_cbrt
  #undef IMPL_INEXACT10_cos
  #undef IMPL_INEXACT10_sin
  #undef IMPL_INEXACT10_tan
  #undef IMPL_INEXACT10_acos
  #undef IMPL_INEXACT10_asin
  #undef IMPL_INEXACT10_atan
  #undef IMPL_INEXACT10_atan2
  #undef IMPL_INEXACT10_cosh
  #undef IMPL_INEXACT10_sinh
  #undef IMPL_INEXACT10_tanh
  #undef IMPL_INEXACT10_acosh
  #undef IMPL_INEXACT10_asinh
  #undef IMPL_INEXACT10_atanh
  #undef IMPL_INEXACT10_exp
  #undef IMPL_INEXACT10_expm1
  #undef IMPL_INEXACT10_log
  #undef IMPL_INEXACT10_log1p
  #undef IMPL_INEXACT10_erf
  #undef IMPL_INEXACT10_erfc
  #undef IMPL_INEXACT10_lgamma

/*
 * This matters for func(den).
 * Underflow depends upon tininess and loss of accuracy.
 * Loss of accuracy is either denormalization loss or inexact.
 * There are three choices for the math functions actions when
 * the result is denormal:
 * 1) Tiny and inexact always is underflow:  #undef IMPL_UNDERFLOW_DEN_LOSS
 * 2) Tiny and denorm. loss always is underflow, tiny and inexact is never
 *    underflow:                             #define IMPL_UNDERFLOW_DEN_LOSS 1
 * 3) Tiny and inexact or denorm. loss sometimes is underflow:
 *                                           #define IMPL_UNDERFLOW_DEN_LOSS -1
 * This symbol sets DEN_FLAGS and DEN_FLAGS_OPT in myfloat.h
 */
  #undef IMPL_UNDERFLOW_DEN_LOSS

/*
 * This matters for func(min).
 * Underflow depends upon tininess and loss of accuracy.
 * Tininess is detected either before or after rounding.
 * There are three choices for the math functions actions when
 * the result is denormal:
 * 1) Tiny detected before rounding:  #undef IMPL_UNDERFLOW_MIN_LOSS (or 0)
 * 2) Tiny detected after rounding:  #define IMPL_UNDERFLOW_MIN_LOSS 1
 * 3) Tiny detection inconsistent:   #define IMPL_UNDERFLOW_MIN_LOSS -1
 * This symbol sets MIN_FLAGS and MIN_FLAGS_OPT in myfloat.h
 * The IMPL_* symbol applies to binary FP.
 * The FIX_* symbol applies to decimal FP (which is supposed to be before rnd).
 */
  #undef IMPL_UNDERFLOW_MIN_LOSS
  #undef FIX_DFP_UNDERFLOW_MIN_LOSS

/*
 * When the compiler converts from decimal (external) to binary (internal)
 * does it look at all the digits in the decimal string, or does it look at
 * just the first DECIMAL_DIG significant digits.  If the extra digits are
 * not used, then define this macro symbol.  This only matters if the symbols
 * *_DEC2BIN_ULPS and *_SCAN2BIN_ULPS are 0, eg, correctly rounded conversions.
 */
  #undef IMPL_IGNORE_EXTRA_DIGITS

/*
 * When printf converts and rounds a number just smaller than 1.0 using %e,
 * does the exponent end up as e-00 (instead of the "expected" e+00)?
 * Some implementations go out of their way to indicate that the number
 * with no limit on precision would have had 9.9e-01, but due to rounding,
 * the number ended up as 1e-00 (this is used by t30701?? tests).
 */
  #undef IMPL_MZERO_EXP

/*
 * When printf converts using %a and %La, is the precision used the mimimum
 * to get an exact representation for this value (in effect, remove trailing
 * zeros; which is how I read C99), or does the implementation use a fixed
 * precision?  If the latter, then used these symbols to defined the number
 * of hex digits after the radix point.  Affects t30703*, t34704*.
 */
  #undef IMPL_aA_PREC	/* float and double */
  #undef IMPL_LaA_PREC	/* long double */

/*
 * When printf converts using %.0a and %.0La, is the first hex digit always
 * 4-7 (3 bits), 2-3 (2 bits), 1 (1 bit)?  If so, then the result may suffer
 * an underserved rounding error when there are other representations that
 * have no rounding error; the first hex digit is 8-f (4 bits).  If these
 * symbols are undefined, the tests assume that the first hex digit is 8-f.
 * Affects t30703*, t34703*, t0240509, t0450900.
 */
  #undef IMPL_aA_BITS	/* float and double */
  #undef IMPL_LaA_BITS	/* long double */

/*
 * When printf converts and rounds a number that is at the midpoint
 * (so it either rounds up or rounds down), what happens?  Some systems
 * use the digit before the round point to determine how to round.
 * Systems that follow IEEE-754 and round to nearest even would have:
 *   #define IMPL_ODD_UP
 *   #undef  IMPL_EVEN_UP
 * Systems that add 0.5 and truncate would have:
 *   #define IMPL_ODD_UP
 *   #define IMPL_EVEN_UP
 * This may need to be expanded if we find that the sign of the number
 * is also used to determine rounding.
 * These are used by t30701??, t30702?? and t305* tests.
 */
  #define IMPL_ODD_UP	/* assume IEEE-754 round to nearest as default */
  #undef IMPL_EVEN_UP

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * struct b { int b: (INT)(10.0/3.0); } b;
 */
  #undef IMPL_ACC_BAD_BIT_FIELD_SIZE

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * enum b { b = (INT)(10.0/3.0) } b;
 */
  #undef IMPL_ACC_BAD_ENUM_VAL

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * int b[ (INT)(10.0/3.0) ];
 */
  #undef IMPL_ACC_BAD_ARRAY_BOUND

/*
 * "Invalid" ISO/ANSI C code is accepted as valid. The code in question is:
 * switch i { case (INT)(10.0/3.0):; }
 */
  #undef IMPL_ACC_BAD_CASE_VAL

/*
 * nan("") should be same as 0.0/0.0 (and INF/INF, INF-INF, 0.0*INF).
 * There is no such requirement in either IEEE-754 or C99, but it
 * makes for a more consistent system.  Same for nand64("").
 */
  #undef IMPL_INCONSISTENT_nan
  #undef IMPL_INCONSISTENT10_nan

/*
 * +NAN, +NAN_FLT, +NAN_DBL, +NAN_LDBL are negative.  This causes the
 * expected value of fabs(NAN) to be wrong.  With this defined, the
 * NAN bit patterns are cleaned up first.  This also affects copysign.
 * Symbol was FIX_NEG_NAN.
 */
  #undef IMPL_pNAN_IS_NEG

/*
 * +NAN, +NAN_FLT, +NAN_DBL, +NAN_LDBL are a mixture of positive and
 * negative.  This causes the expected value of fabs(NAN) to be wrong.
 * With this defined, the NAN bit patterns are cleaned up first.  This
 * also affects copysign.
 */
  #undef IMPL_pNAN_IS_MIXED

/*
 * -NAN, -NAN_FLT, -NAN_DBL, -NAN_LDBL are positive.  This causes the
 * expected value of copysign(-NAN) to be wrong.  With this defined,
 * the NAN bit patterns are cleaned up first.  Symbol was
 * FIX_mNAN_IS_POS.
 */
  #undef IMPL_mNAN_IS_POS

/*
 * -NAN, -NAN_FLT, -NAN_DBL, -NAN_LDBL are a mixture of positive and
 * negative.  This causes the expected value of copysign(-NAN) to be
 * wrong.  With this defined, the NAN bit patterns are cleaned up
 * first.
 */
  #undef IMPL_mNAN_IS_MIXED

/*
 * -NAN is same as +NAN.
 */
  #undef IMPL_mNAN_EQ_pNAN

/*
 * NAN, converted from smaller precision to larger precision and back
 * to original precision should have the same bit pattern.  This is not
 * required by any standard, but makes for consistent FP operations.
 * It is mentioned in IEEE-854 in 6.2.  This affects nexttoward.
 */
  #undef IMPL_BAD_ROUNDTRIP_OF_NAN

/*
 * The maximum number of characters that can be printed with %s.
 * If not defined, 4095 is used.  Needed in t30410000.
 */
  #undef IMPL_MAX_PRINT_S
  #undef IMPL_MAX_WPRINT_S

/*
 * The maximum number of digits before and after the radix point
 * allowed by printf using %f format.  If not defined, 32766 is used.
 * This shows up in test t0250800/t3041000.  As long as they are about
 * LDBL_MAX_10_EXP and DECIMAL_DIG-LDBL_MIN_10_EXP, there will be no
 * problems.
 */
  #undef IMPL_MAX_BEFORE_RADIX
  #undef IMPL_MAX_AFTER_RADIX

/*
 * The maximum number of digits before and after the radix point
 * allowed by scanf using %f format.  If not defined, 32766 is used.
 * This shows up in tests t0250800/t3041000.  As long as they are
 * about LDBL_MAX_10_EXP and DECIMAL_DIG-LDBL_MIN_10_EXP, there will
 * be no problems.
 */
  #undef IMPL_MAX_SCAN_BEFORE_RADIX
  #undef IMPL_MAX_WSCAN_BEFORE_RADIX
  #undef IMPL_MAX_SCAN_AFTER_RADIX
  #undef IMPL_MAX_WSCAN_AFTER_RADIX

/*
 * The maximum number of significant digits correctly rounded by
 * printf using %e format.  If not defined, DECIMAL_DIG is used.  This
 * shows up in test t305*.  This is for testing more than DECIMAL_DIG.
 */
  #undef IMPL_MAX_E_DIGITS

/*
 * The mapping of enum types to integer types is implementation defined.
 * If all enum's map to int, then you do not need any of these.
 * There are 6 different enums tested (each has a different range of values).
 * They can map to one of several kinds of integer types.
 * For both the enum type and the int type, the first letter (U or S)
 * means Unsigned or Signed.  For the enum type the second letter (C, S, I)
 * means Char, Short, or Int and indicates the minimum type needed to
 * represent its values. The int type mapped to should be obvious.
 * In ISO/ANSI C, enum is a synonym for some int type; but each enum
 * constant is of type int (so, at one point, these tests assumed that enums
 * mapped to int).  In C++ enums may be smaller than an int.
 * These next symbols replace FIX_ENUM_IS_INT.
 */
  #undef IMPL_UCE_IS_UCHAR
  #undef IMPL_UCE_IS_SCHAR
  #undef IMPL_UCE_IS_USHORT
  #undef IMPL_UCE_IS_SSHORT
  #undef IMPL_UCE_IS_UINT
  #undef IMPL_UCE_IS_SINT

  #undef IMPL_SCE_IS_SCHAR
  #undef IMPL_SCE_IS_SSHORT

  #undef IMPL_USE_IS_USHORT
  #undef IMPL_USE_IS_SSHORT
  #undef IMPL_USE_IS_UINT
  #undef IMPL_USE_IS_SINT

  #undef IMPL_SSE_IS_SSHORT
  #undef IMPL_SSE_IS_SINT

  #undef IMPL_UIE_IS_UINT
  #undef IMPL_UIE_IS_SINT

  #undef IMPL_SIE_IS_SINT

/*
 * Does overflow produce an infinity (as required by IEEE-754), or some
 * finite number (such as IBM S/360 which wraps the exponent).
 * So far, only used in t0000000/t6000000.
 */
  #undef IMPL_DBL_OVER_IS_NOT_INF
  #undef IMPL_D10_OVER_IS_NOT_INF
  #undef IMPL_LDBL_OVER_IS_NOT_INF
  #undef IMPL_LD10_OVER_IS_NOT_INF

/*
 * Can bool and int bit-fields be mixed in the same storage unit?
 * Or, does mixing them allocate more storage than just bool?
 * Define this if they cannot.
 */
  #undef IMPL_NOMIX_BOOL_AND_INT

/*
 * If FLT_EVAL_METHOD < 0 (meaning inconsistent or unknown),
 * If DEC_EVAL_METHOD < 0 (meaning inconsistent or unknown),
 * then allow the implementation to define how it evaluates:
 *   compile time FP constants
 *   compile time FP constant expressions
 *   runtime FP operators
 *   runtime FP operators (contracted)
 *   runtime anonymous (w/o a store) FP operators, eg, FLT_MAX*FLT_MAX;
 *   runtime conversion from integer type to floating type
 *   runtime conversion from "decimal" string to "binary" FP via strto*, *scanf
 *   runtime return stmt.
 *   runtime inline return stmt.
 * Each of these symbols needs to be defined to a value like 0, 1, 2, or 3.
 * 0, 1, and 2 have same meaining as FLT_EVAL_METHOD.
 * 3 => precision is greater than long double [Microsoft, Symantec...]
 * and LD_REG_PREC is used to indicate that precision.
 * REG_WIDER_EXP is used for range is greater than LDBL.
 * REG10_WIDER_EXP is used for range is greater than LD10.
 * For example:
 * #define IMPL_FLT_EVAL_CONST       0 // to type
 * #define IMPL_FLT_EVAL_CONST_EXP   2 // to long double
 * #define IMPL_FLT_EVAL_OP          2 // to long double
 * #define IMPL_FLT_EVAL_OP_CONTRACT 2 // to long double
 * #define IMPL_FLT_EVAL_OP_ANON     2 // to long double
 * #define IMPL_FLT_EVAL_INT2FLT     2 // to long double
 * #define IMPL_FLT_EVAL_STRTO       0 // to type
 * #define IMPL_FLT_EVAL_RET         2 // to long double
 * #define IMPL_FLT_EVAL_IN_RET      2 // to long double
 *
 * #define IMPL_DEC_EVAL_CONST10     0 // to type
 * #define IMPL_DEC_EVAL_CONST_EXP10 2 // to long double
 * #define IMPL_DEC_EVAL_OP10        2 // to Dec128
 * #define IMPL_DEC_EVAL_STRTO10     0 // to type
 * #define IMPL_DEC_EVAL_RET10       2 // to Dec128
 * #define IMPL_DEC_EVAL_IN_RET10    2 // to Dec128
 */
  #undef IMPL_FLT_EVAL_CONST
  #undef IMPL_FLT_EVAL_CONST_EXP
  #undef IMPL_FLT_EVAL_OP
  #undef IMPL_FLT_EVAL_OP_CONTRACT
  #undef IMPL_FLT_EVAL_OP_ANON	/* t0280000 */
  #undef IMPL_FLT_EVAL_INT2FLT
  #undef IMPL_FLT_EVAL_STRTO
  #undef IMPL_FLT_EVAL_RET
  #undef IMPL_FLT_EVAL_IN_RET

  #undef IMPL_DEC_EVAL_CONST10
  #undef IMPL_DEC_EVAL_CONST_EXP10
  #undef IMPL_DEC_EVAL_OP10
  #undef IMPL_DEC_EVAL_STRTO10
  #undef IMPL_DEC_EVAL_RET10
  #undef IMPL_DEC_EVAL_IN_RET10

/*
 * If denorms are flushed at runtime, what flags are raised?
 */
  #undef IMPL_FLUSHED_FLAGS

/*
 * Does pragma FENV_ACCESS OFF cause the compiler to fold
 * some expressions (and thereby, not raise FP exceptions
 * at runtime)?
 */
  #undef IMPL_FENV_OFF_FOLDS

/*
 * Allow or suppress the printout of the maximum ULP error found in t1..*003 tests.
 */
  #undef IMPL_SUPPRESS_MAX_ULP_acos
/* ... */
  #undef IMPL_SUPPRESS_MAX_ULP_tgamma
  #undef IMPL_SUPPRESS_MAX_ULP10_acos
/* ... */
  #undef IMPL_SUPPRESS_MAX_ULP10_tgamma

/*
 * Function result should be dependent upon current rounding direction.
 * Difference between f(UP) and f(DOWN) should be exactly 1 ulp.
 * Should have: f(DOWN) < f(UP)
 */
  #undef IMPL_NO_STRONG_RND_acos
/* ... */
  #undef IMPL_NO_STRONG_RND_trunc
  #undef IMPL_NO_STRONG_RND10_acos
/* ... */
  #undef IMPL_NO_STRONG_RND10_trunc

/*
 * Function result should be dependent upon current rounding direction.
 * Should have: f(DOWN) <= f(UP)
 */
  #undef IMPL_NO_WEAK_RND_acos
/* ... */
  #undef IMPL_NO_WEAK_RND_trunc
  #undef IMPL_NO_WEAK_RND10_acos
/* ... */
  #undef IMPL_NO_WEAK_RND10_trunc

/*
 * If (math_errhandling & MATH_ERRNO) is zero (meaning FP exceptions
 * are done with flags), is errno (sometimes) also altered (rather
 * than being left alone)?  With this defined, the spurious errno
 * value is checked to make sure it is consistent with the flags.
 */
  #undef IMPL_SPURIOUS_ERRNO

/*
 * errno should be consistent with FP exception flags when
 * directed rounding is used, eg, other than default rounding mode.
 */
  #undef IMPL_NO_ERRNO_RND_acos
/* ... */
  #undef IMPL_NO_ERRNO_RND_trunc
  #undef IMPL_NO_ERRNO_RND10_acos
/* ... */
  #undef IMPL_NO_ERRNO_RND10_trunc

/*
 * If these symbols are macros, but they are not usable in #if, #elif,
 * then define these symbol.
 */
  #undef IMPL_POOR_math_errhandling
  #undef IMPL_POOR_FP_ILOGB0
  #undef IMPL_POOR_FP_ILOGBNAN

/*
 * When checking consistentcy between errno and the FP exception flags,
 * do not use the actual flags (use expected flags).
 * See g1errno.h
 */
  #undef IMPL_NO_TEST_ACTUAL_FLAGS

/*
 * When checking consistentcy between errno and the FP exception flags,
 * do not use the actual critical flags (use expected flags).
 * See g1errno.h
 */
  #undef IMPL_NO_TEST_CRIT_FLAGS

/*
 * If ERANGE is not raised for underflow, then define this symbol for the
 * appropriate function.
 */
  #undef IMPL_UF_WIERD_acos
/* ... */
  #undef IMPL_UF_WIERD_trunc
  #undef IMPL_UF_WIERD10_acos
/* ... */
  #undef IMPL_UF_WIERD10_trunc

/*
 * Complex is optional to freestanding implementations.
 * Imaginary is optional to all implementations.
 * Decimal FP Tech Report currently has no DFP complex or DFP imaginary,
 * but if DFP gets added to Standard C, they must be added also.
 */
  #undef IMPL_MISSING_COMPLEX
  #undef IMPL_MISSING_IMAG
  #undef IMPL_MISSING_DFP_COMPLEX
  #undef IMPL_MISSING_DFP_IMAG

/*
 * Should a decimal function be allowed to return the same value, but
 * with a different quantum (exponent) in the same cohort?
 */
  #undef IMPL_COHORT_frexp
  #undef IMPL_COHORT_ldexp
  #undef IMPL_COHORT_logb
  #undef IMPL_COHORT_scalbn
  #undef IMPL_COHORT_scalbln

/* Should a decimal function be allowed to return any representation
 * of zero (there are lots), or the expected bit pattern?  Same idea
 * for non-zero results (mainly, one).
 *   sin(+/-0.) is +/-0.
 *   cos(+/-0.) is +1.
 * IEEE-754 2008 says, in 9.1, that it is language defined as to the
 * preferred quantum (exponent).
 */
  #undef IMPL_COHORT_ZERO
  #undef IMPL_COHORT_NONZERO

/*
 * What relationship exists between the size of enums and size of int?
 * And size of wchar_t and size of int?  Used in t0160322.
 */
  #undef sizeof_enum_color_LT_sizeof_int
  #undef sizeof_wchar_t_LT_sizeof_int

/*
 * The error in the unit in the last place of the various math functions
 * is defined (if not already defined) in myfloat.h.  It could be given
 * a value in the *.bug files if it is bigger than the default value in
 * myfloat.h.
 */
  #undef ULP_acos
/* ... thru ... */
  #undef ULP_trunc
  #undef ULP10_acos
/* ... thru ... */
  #undef ULP10_trunc

/*
 * The error in the unit in the last place of the various math functions
 * is defined (if not already defined) in myfloat.h.  It could be given
 * a value in the *.bug files if it is bigger than the default value in
 * myfloat.h.  This is for special "identities".
 */
  #undef ULP_acos_sum	/* f(x) + f(-x) vs pi */
  #undef ULP_atan_sum	/* f(x) + f(1/x) vs pi/2 */
  #undef ULP_erfc_sum	/* 2-f(-x) vs f(x) */
  #undef ULP_exp_sum	/* 1/f(-x) vs f(x) */
  #undef ULP_exp2_sum	/* 1/f(-x) vs f(x) */
  #undef ULP_expm1_sum	/* f(-x) vs f(x) and 1/(f(-x)-1) vs f(x) */
  #undef ULP_log_sum	/* -f(1/x) vs f(x) */
  #undef ULP_log10_sum	/* -f(1/x) vs f(x) */
  #undef ULP_log1p_sum	/* -f(-x) vs f(x) and -f(1/(x+1)-1) vs f(x) */
  #undef ULP_log2_sum	/* -f(1/x) vs f(x) */
  #undef ULP_pow_sum	/* 1/f(x,-y) vs f(x,y) and f(1/x,-y) vs f(x,y) and 1/f(1/x,y) vs f(x,y) */
  #undef ULP_sqrt_sum	/* 1/f(1/x) vs f(x) */

/*
 * The error in the unit in the last place of the three trig math functions
 * for large arguments is defined (if not already defined) in myfloat.h.
 * It could be given a value in the *.bug files if it is bigger than the
 * default value in myfloat.h.
 */
  #undef ULP_LARGE_ARG10_cos
  #undef ULP_LARGE_ARG10_sin
  #undef ULP_LARGE_ARG10_tan
  #undef ULP_LARGE_ARG_cos
  #undef ULP_LARGE_ARG_sin
  #undef ULP_LARGE_ARG_tan

/*****************
 * These show up as translation time errors that ends compile, or maybe
 * missing function implementation that ends link edit.
 * First are the old (ISO/ANSI) C89/C90/C95 violations.
 * Second are Standard C99 violations.
 * Third are Decimal Floating-Point (DFP) Tech Report violations.
 ****************/

/*** Translate time: C89/C90/C95 ***/

/*
 * <locale.h> header is part of ISO/ANSI C.
 */
  #undef FIX_LOCALE_H

/*
 * <iso646.h> is a required ISO/ANSI C header.
 */
  #undef FIX_ISO646_H

/*
 * Wide chars, L'c', are part of ISO/ANSI C.
 */
  #undef FIX_WIDE_CHAR

/*
 * index[array] is same as array[index], eg, 1[a] == a[1]; This is ISO/ANSI C.
 */
  #undef FIX_INT_BRACKET_ARRAY

/*
 * static unsigned long int uli = 1.0; is valid ISO/ANSI C code.
 */
  #undef FIX_ULI_EQ_FP

/*
 * Prototypes in headers should not violate the user's name space by ISO/ANSI C.
 */
  #undef FIX_NAME_SPACE

/*
 * Compiler's libraries should not violate the user's name space by ISO/ANSI C.
 */
  #undef FIX_LINK_NAME_SPACE

/*
 * Either math.h or float.h defines math related values such as PI or PI2.
 * That violates the user's name space (and interferes with my definitions
 * of those values done in myfloat.h).
 */
  #undef FIX_MATH_PI

/*
 * macro(d++) should be legal by ISO/ANSI C.
 */
  #undef FIX_BAD_MACROS

/*
 * offsetof() macro missing
 */
  #undef FIX_OFFSETOF

/*
 * sizeof(1/0), sizeof(0/0) are legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_DIV_BY_ZERO

/*
 * sizeof(1.0/0.0), sizeof(0.0/0.0) are legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_DIV_BY_0

/*
 * int ary[(int)2.0]; is valid ISO/ANSI C.
 */
  #undef FIX_ARRAY_BOUND_INT_CAST

/*
 * struct bits { int b : (int)2.0; } bb; is valid ISO/ANSI C.
 */
  #undef FIX_BIT_FIELD_SIZE_INT_CAST

/*
 * enum c { red = (int)0.0 } cc ; is valid ISO/ANSI C.
 */
  #undef FIX_ENUM_VAL_INT_CAST

/*
 * switch (i){ case (int)2.0:; } is valid ISO/ANSI C.
 */
  #undef FIX_CASE_INT_CAST

/*
 * long double is a valid ISO/ANSI C type.  This changes LDBL to double
 * for a few specific tests.  REMAP_LDBL is more general.
 * LD10 is the Decimal FP version of LDBL (should not be used).
 */
  #undef FIX_LDBL
  #undef FIX_LD10

/*
 * Change LDBL to be double, do not append "L" to floating-point literals,
 * and change name of function called (do not append "l").  This is useful
 * if compiler is missing long double functions or does not like long double
 * literals or type.  More information is available later in this file
 * (look for REMAP_).  Contrast this with IMPL_LDBL_EQ_DBL.
 * REMAP_LD10 is for decimal FP.
 */
  #undef REMAP_LDBL
  #undef REMAP_LD10

/*
 * Change DBL to be long double, do append "L" to floating-point 'double'
 * literals, and change name of 'double' function called (do append "l").
 * This has not been tested yet (idea was added when added REMAP_LDBL).
 * Would only be useful if system has double and float being the same.
 * REMAP_D10 is for decimal FP.
 */
  #undef REMAP_DBL
  #undef REMAP_D10

/*
 * volatile is a valid ISO/ANSI C qualifier.
 */
  #undef FIX_VOLATILE

/*
 * 1e-10##f and #1e-10 in macro usage are valid ISO/ANSI C.
 * Something to do with minus sign in exponent causes problems.
 */
  #undef FIX_MINUS_EXP

/*
 * PP expression causes problems to at least one compiler.
 *  #elif( PC_PREC == SC_PREC )
 */
  #undef FIX_PP_EXP

/*
 * PP macros with actual arguments having imbedded commas
 * are done wrong.  For tflt2int and tint2flt.
 */
  #undef FIX_BROKEN_PP
  #undef FIX_SEMIBROKEN_PP

/*
 * PP-number used as a PP-token in token pasting to create an
 * identifier causes problems to at least one compiler.
 * The specific case is:  mac(pp,3_aut); where mac(a,b) does a ## b
 */
  #undef FIX_DIG_LET_PP_NUMBER

/*
 * 08.5, 09.f, 09e0L are valid ISO/ANSI C floating-point constants,
 * yet some lints and compilers think they are invalid octal integers.
 */
  #undef FIX_OCTAL_FLOATS

/*
 * 000e96 is a valid FP constant, yet some compilers think it is invalid.
 */
  #undef  FIX_NODOT_E

/*
 * mac(08) and mac(09) are considered invalid octal constants in a
 * macro expansion.
 */
  #undef FIX_INVALID_OCTAL

/*
 * Implicit promotion of float to double in [w]printf is valid
 * ISO/ANSI C, yet it causes some compilers problems.
 * For F10, it is NOT promoted (unless there is a bug in the compiler).
 */
  #undef FIX_IMPLICIT_FLT2DBL_IN_PRINTF
  #undef FIX_IMPLICIT_FLT2DBL_IN_WPRINTF
  #undef FIX_IMPLICIT_F102D10_IN_PRINTF

/*
 * Explicit cast (char *) needed to convert const char array.
 */
  #undef FIX_IMPLICIT_CHAR_PTR

/*
 * Pointer && floating-point should be valid.
 */
  #undef FIX_PTR_ANDAND_FP
  #undef FIX_PTR_ANDAND_FP10

/*
 * Pointer || floating-point should be valid.
 */
  #undef FIX_PTR_OROR_FP
  #undef FIX_PTR_OROR_FP10

/*
 * DBL + DBL * DBL should be valid, eg, 1.0 + ulp * 4.0
 */
  #undef FIX_DBL_PLUS_DBL_TIMES_DBL

/*
 * int func();  ....; int func(int) should be accepted.
 */
  #undef  FIX_OLD_STYLE_NO_PARMS

/*
 * static const double d[] = { 1.0 - ULP_DBL/2.0 } is valid ISO/ANSI C,
 * yet it causes some systems to core dump at runtime or give syntax
 * errors at compile time.  This removes the static and/or const.
 */
  #undef FIX_STATIC_CONST

/*
 * static double d[] = { 0.0/0.0, 1.0/0.0 } is valid C99 w/ IEEE-754,
 * yet it causes some systems to core dump at runtime or give syntax
 * errors at compile time.  This removes the static in the math library
 * test vector array declaration.  Mainly needed for NAN_* and INF_*.
 */
  #undef FIX_STATIC_VECTORS

/*
 * static double d = 3.1416/2; is valid C99, yet it causes some
 * systems to core dump at runtime or give syntax errors at compile
 * time.  This removes the static.
 */
  #undef FIX_STATIC_SCALAR

/*
 * File scope static float d[] = { FLT_MIN*FLT_MIN/FLT_MIN } is valid
 * ISO/ANSI C, yet it causes some systems to give syntax errors at
 * compile time.  Seems to happen only if expression has over/underflow.
 * This removes the var and tests of that var.
 */
  #undef FIX_FILE_SCOPE_FP_INIT

/*
 * File scope static double d[] = { 1.0 - ULP_DBL/2.0 } is valid
 * ISO/ANSI C, yet it causes some systems to give syntax errors at
 * compile time.  This adds compiler specific pragmas around dcl.
 */
  #undef FIX_FP_EXP_IN_INIT

/*
 * double d[] = { 1.0 - ULP_DBL/2.0 } is valid ISO/ANSI C, yet it causes
 * some systems to complain at translate time about invalid initializer.
 */
  #undef FIX_CONST_EXP_IN_INIT

/*
 * struct bits{ int a:3; } = { 1 } is valid ISO/ANSI C, yet it causes
 * some systems to complain at translate time about invalid initializer.
 */
  #undef FIX_STRUCT_INIT

/*
 * Having a const member of a struct that is a typedef kills some C++
 * compilers (even though that typedef will be used in a POD --
 * Plain Old Data, eg, an array).
 */
  #undef FIX_CONST_IN_TYPEDEF_STRUCT

/*
 * static short si = 1.0; is valid ISO/ANSI C, yet it causes some
 * systems to complain at translate time about invalid initializer.
 */
  #undef FIX_INIT_SHORT_WITH_FP

/*
 * static char c = 1.0; is valid ISO/ANSI C, yet it causes some
 * systems to complain at translate time about invalid initializer.
 */
  #undef FIX_INIT_CHAR_WITH_FP

/*
 * xglue and glue macros are valid ISO/ANSI C code.
 */
  #undef FIX_XGLUE

/*
 * xstr and str macros are valid ISO/ANSI C code.
 * Symantec core dumps with t0080000.
 */
  #undef FIX_XSTR

/*
 * Macro invocation of +x or -x ends up with + x or - x, ie, an extra
 * blank is added.  That is bad.
 */
  #undef FIX_EXTRA_BLANK

/*
 * '#' is a valid preprocessor statement, yet it kills some compilers.
 * Just having the above '#' without the "'" chars in this comment
 * kills some compilers.
 */
  #undef FIX_EMPTY_PP

/*
 * Preprocessor macro symbols greater than 31 characters cause random
 * behaviour with some compilers (sometimes honor, sometimes ignore,
 * #ifdef, #ifndef, #if defined, #if !defined).
 */
  #undef FIX_LONG_SYMBOLS

/*
 * #elif( 1 ) is a valid preprocessor statement, yet it kills some compilers.
 * They think function f( 1 ) is being invoked.  #elif ( 1 ) works OK.
 */
  #undef FIX_ELIF_AS_FUNCTION

/*
 * t030* have some multi-line macro definitions.
 * Some compilers (DigMars) die when they try to expand those macros.
 */
  #undef FIX_2_HARD_4_PP

/*
 * Macro definition like #define DBL_MIN_10_EXP -307
 * followed by usage like i = -DBL_MIN_10_EXP;
 * causes some compilers to think the expansion i = --307; is an attempt
 * to apply the prefix decrement operator '--' to something other than
 * a modifiable lvalue.  But, there is no '--' operator.  There are two
 * '-' operators, each coming from separate pp-tokens.  The fix for that
 * compiler is to do #define DBL_MIN_10_EXP (-307)
 */
  #undef FIX_NEG_NEG

/*
 * Some macro symbols in the headers are missing or have such poor
 * definitions that they are unusable to t035*.
 */
  #undef FIX_SYM_BUFSIZ
  #undef FIX_SYM_CLOCKS_PER_SEC
  #undef FIX_SYM_EILSEQ
  #undef FIX_SYM_EOF
  #undef FIX_SYM_EXIT_FAILURE
  #undef FIX_SYM_EXIT_SUCCESS
  #undef FIX_SYM_LLONG_MAX
  #undef FIX_SYM_LLONG_MIN
  #undef FIX_SYM_L_tmpnam
  #undef FIX_SYM_NULL
  #undef FIX_SYM_ULLONG_MAX
  #undef FIX_SYM_WCHAR_MAX
  #undef FIX_SYM_WCHAR_MIN
  #undef FIX_SYM_WEOF

/*
 * Some C++ compilers disallow using enums to && and || operators.
 */
  #undef FIX_ENUM_TO_ANDAND
  #undef FIX_ENUM_TO_OROR

/*
 * 0.0 || var done wrong.
 */
  #undef FIX_FPZERO_OROR_VAR

/*
 * Expressions with (integer && floating) done wrong.
 */
  #undef FIX_INT_ANDAND_FLT

/*
 * FP function and compare used together fail w/ several compilers.
 */
  #undef FIX_FPFUNC_AND_COMP

/*
 * Integer arguments passed to math library functions is valid, eg, exp(3uL)
 */
  #undef FIX_MATH_FUNC_OF_INTEGER

/*
 * Floating-point numbers with 509 digits are valid ISO/ANSI C.
 */
  #undef FIX_509_CHARS

/*
 * EXIT_FAILURE and EXIT_SUCCESS missing from <stdlib.h>, so define some
 * value so the code can compile and run.  0 is the same as success.
 * There is no standard value for failure.
 */
  #undef NEED_EXIT_SYMS

/*
 * Too much data.  x86 PC's are limited to 64K total data per segment.
 * Standard C limit is 32K per object for hosted environment
 * (operating system + compiler/interpreter).
 * There appears to be no limit on freestanding environments.
 */
  #undef FIX_64K_DATA

/*
 * Too big to compile. ISO/ANSI C requires that must compile
 * as long as do not violate translation limits.
 */
  #undef FIX_TOO_BIG_TOO_COMPILE

/*
 * Too complicated to compile. ISO/ANSI C requires that must compile
 * as long as do not violate translation limits.
 */
  #undef FIX_TOO_HARD_TOO_COMPILE

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * #if (INT)1  or  #if (INT)1.0  or  #if (INT)(1.0/1.0)
 */
  #undef FIX_ACC_BAD_IF_VAL

/*
 * (& * var) is accepted and var is not a pointer.  e01627*.fjt
 */
  #undef FIX_ADDR_OR_INDIR_ACC_NON_PTR

/*
 * struc.bits.uibf is correct and struc.uibf is accepted.  e01628*.fjt
 */
  #undef FIX_DOT_ACC_NON_MEMBER

/*
 * p0 -> bits.uibf is correct and p0 -> uibf is accepted.  e01629*.fjt
 */
  #undef FIX_ARROW_ACC_NON_MEMBER

/*
 * array[floating] is accepted.  e01630*.fjt
 */
  #undef FIX_ARRAY_ACC_FLOAT

/*
 * array[ptr] is accepted.  e01630*.fjt
 */
  #undef FIX_ARRAY_SUBSCRIPT_ACC_PTR

/*
 * sizeof( bit-field member ) is accepted.
 */
  #undef FIX_SIZEOF_ACC_BIT_FIELD_MEMBER

/*
 * ~flt, ~ptr, +ptr, -ptr accepted.
 */
  #undef FIX_UNI_BIT_COMP_ACC_FLOAT
  #undef FIX_UNI_BIT_COMP_ACC_PTR
  #undef FIX_UNI_POS_OR_NEG_ACC_PTR

/*
 * Binary operators accept non-integer operands.
 */
  #undef FIX_BIN_BIT_AND_ACC_FLOAT
  #undef FIX_BIN_BIT_AND_ACC_PTR
  #undef FIX_BIN_BIT_AND_EQ_ACC_FLOAT
  #undef FIX_BIN_BIT_AND_EQ_ACC_PTR
  #undef FIX_BIN_BIT_OR_ACC_FLOAT
  #undef FIX_BIN_BIT_OR_ACC_PTR
  #undef FIX_BIN_BIT_OR_EQ_ACC_FLOAT
  #undef FIX_BIN_BIT_OR_EQ_ACC_PTR
  #undef FIX_BIN_BIT_XOR_ACC_FLOAT
  #undef FIX_BIN_BIT_XOR_ACC_PTR
  #undef FIX_BIN_BIT_XOR_EQ_ACC_FLOAT
  #undef FIX_BIN_BIT_XOR_EQ_ACC_PTR
  #undef FIX_BIN_LEFT_SHFT_ACC_FLOAT
  #undef FIX_BIN_LEFT_SHFT_ACC_PTR
  #undef FIX_BIN_LEFT_SHFT_EQ_ACC_FLOAT
  #undef FIX_BIN_LEFT_SHFT_EQ_ACC_PTR
  #undef FIX_BIN_RIGHT_SHFT_ACC_FLOAT
  #undef FIX_BIN_RIGHT_SHFT_ACC_PTR
  #undef FIX_BIN_RIGHT_SHFT_EQ_ACC_FLOAT
  #undef FIX_BIN_RIGHT_SHFT_EQ_ACC_PTR
  #undef FIX_BIN_REM_ACC_FLOAT
  #undef FIX_BIN_REM_ACC_PTR
  #undef FIX_BIN_REM_EQ_ACC_FLOAT
  #undef FIX_BIN_REM_EQ_ACC_PTR

/*
 * FLT_ROUNDS is dynamic => need to call external routine which might
 * not be found by linker.  Try adding math library (-lm).
 */
  #undef FIX_FLT_RND

/*
 * wchar_t is supposed to be in <stddef.h>, <stdlib.h>, <wchar.h>
 * If it is missing, this symbol will have me define a value for it.
 */
  #undef FIX_wchar_t

/*
 * strtof, strtold should not be declared if <stdlib.h> has not been
 * included.
 */
  #undef FIX_strtof_HEADER
  #undef FIX_strtold_HEADER

/*
 * sizeof( + bitfield ) is valid in that the '+' promotes the bitfield to an int.
 * Many compilers ignore the '+' and complain about sizeof a bitfield.
 */
  #undef FIX_IGNORE_UNARY_PLUS

/*
 * Conversion from ptr to/from a small/large int should be accepted.
 */
  #undef FIX_SMALL_INT_FROM_PTR
  #undef FIX_SLL_FROM_PTR
  #undef FIX_ULL_FROM_PTR
  #undef FIX_PTR_FROM_SLL
  #undef FIX_PTR_FROM_ULL

/*
 * Integer division by zero (1/0 and 0/0).
 */
  #undef FIX_DIV_BY_ZERO

/*
 * 0.0 / 0.0 is a valid expression which should raise invalid.
 */
  #undef FIX_0_BY_0

/*
 * 1.0 / 0.0 is a valid expression which should raise divide by zero.
 */
  #undef FIX_1_BY_0

/*
 * x /= 0.0 is a valid expression which should raise divide by zero or invalid.
 */
  #undef FIX_BY_0

/*
 * Are floating-point constants bigger than *_MAX converted to finite values?
 * So far, only needed for certain long double values.
 */
  #undef FIX_2LARGE_IS_FINITE

/*
 * Are floating-point constants very much bigger than *_MAX allowed,
 * eg, 1.0e99999999 or 0x1.0p999999999?
 * They are supposed to be allowed and should be INFINITY.
 * Only affects t0080100 and t3080100, t0100200.
 */
  #undef FIX_VERY_BIG_EXPONENTS

/*
 * Are floating-point constants bigger than *_MAX allowed,
 * eg, 1.0e99999 or 0x1.0p99999?
 * They are supposed to be allowed and should be INFINITY.
 * (Was FIX_BIGGER_THAN_MAX -- POSIX.2 reserves *_MAX)
 */
  #undef FIX_BIGGER_THAN_FPMAX

/*
 * Are floating-point constant expressions bigger than *_MAX allowed,
 * eg, MAX_FLT * MAX_FLT or MAX_FLT / MIN_FLT.
 * They are supposed to be allowed and should be INFINITY.
 */
  #undef FIX_EXP_BIGGER_THAN_FPMAX

/*
 * Are floating-point constants smaller than *_MIN allowed,
 * eg, 1.0e-99999999 or 0x1.0p-999999999?
 * They are supposed to be allowed and should be zero.
 * (Was FIX_SMALLER_THAN_MIN)
 */
  #undef FIX_SMALLER_THAN_FPMIN

/*
 * Are floating-point constant expressions smaller than *_MIN allowed,
 * eg, MIN_FLT * MIN_FLT or MIN_FLT / MAX_FLT.
 * They are supposed to be allowed and should be zero.
 */
  #undef FIX_EXP_SMALLER_THAN_FPMIN

/*
 * If the long double functions are missing and the double versions are
 * used instead, then need to limit the domain to valid double numbers.
 */
  #undef LIMIT_DOMAIN

/*
 * The overloaded functions are undefined for enum's as arguments.
 */
  #undef FIX_ENUM_2_OVERLOAD

/*
 * Cause a #error to be done so can check translator listing for warnings.
 */
  #undef FIX_FORCE_WARNING_AS_ERROR

/*
 * __FILE__, __LINE__, __DATE__, __TIME__, __STDC__ can't be
 * #undef nor #define by ISO/ANSI C.
 */
  #undef FIX_CHANGE_ANSI

/*
 * Parameters are declared const (because function only reads them)
 * causes problems for some compilers.  With these defined, 'const'
 * is removed from the prototype/definition.
 */
  #undef FIX_CONST_ARRAY_PARM
  #undef FIX_CONST_VLA_PARM
  #undef FIX_CONST_SCALAR_PARM

/*
 * Registers which are declared const causes problems for some compilers.
 * With these defined, 'const' is removed.
 */
  #undef FIX_CONST_REGISTER

/*
 * signgam is in user's name space, not something special to lgamma.
 * But, the use of lgamma is outside of ISO/ANSI C.
 */
  #undef FIX_SIGNGAM

/*** Translate time: C99 ***/

/*
 * If startup code (SETUP2) runs fenv.h functions to set the FPU into the
 * expected state, then need <fenv.h> for function prototypes.
 */
  #undef NEED_STARTUP_FENV_H

/*
 * If startup code (SETUP2) runs float.h functions to set the FPU into the
 * expected state, then need <float.h> for function prototypes.  This is
 * useful on DOS, Windows, OS/2 systems that use _control87().
 */
  #undef NEED_STARTUP_FLOAT_H

/*
 * If NAN_FLT, NAN_DBL, or NAN_LDBL (all in myfloat.h) must be defined in
 * terms of NAN, then this symbol needs to be defined.
 */
  #undef NEED_FP_H_4_NAN

/*
 * If INF_FLT, INF_DBL, or INF_LDBL (all in myfloat.h) must be defined in
 * terms of INFINITY, then this symbol needs to be defined.
 */
  #undef NEED_FP_H_4_INFINITY

/*
 * <complex.h> is a header new with C99.
 * <inttypes.h> is a header new with C99.
 * <stdbool.h> is a header new with C99.
 * <stdint.h> is a header new with C99.
 * <wchar.h> is a header new with C95.
 * <wctype.h> is a header new with C95.
 */
  #undef FIX_COMPLEX_H
  #undef FIX_INTTYPES_H
  #undef FIX_STDBOOL_H
  #undef FIX_STDINT_H
  #undef FIX_WCHAR_H
  #undef FIX_WCTYPE_H
  #undef FIX_CHAR_H		/* g008/g308 synch */

/*
 * NCEG added many new math functions above and beyond C89.  For a while,
 * they had their own header <fp.h>.  Later, when NCEG got absorbed into
 * C99, that header became part of <math.h>.  For compilers that have BOTH
 * <fp.h> and <math.h>, you need to define this symbol.
 */
  #undef FIX_FP_IN_MATH_H

/*
 * <fp.h> is missing or not compatible with C.
 */
  #undef FIX_FP_H

/*
 * <math.h> is not compatible with fp.h.
 */
  #undef FIX_MATH_H

/*
 * The math functions are supposed to come in three flavors: float,
 * double, and long double via overloaded functions (type generic
 * functions).  This disables using all of them.  This applies to
 * the header <tgmath.h>.  This should have been FIX_TGMATH_H.
 */

  #undef FIX_OVERLOAD
  #undef FIX_OVERLOAD10

/*
 * The math functions are supposed to come in three flavors: float,
 * double, and long double via overloaded functions.  This disables
 * just the ones you chose.  One problem found with overloaded
 * functions is: pow(long double,double) complains about ambiguous
 * overload.
 */
  #undef FIX_OVERLOAD_acos
/* ... thru ... */
  #undef FIX_OVERLOAD_trunc
  #undef FIX_OVERLOAD10_acos
/* ... thru ... */
  #undef FIX_OVERLOAD10_trunc

/*
 * The float versions of the math functions are supposed to exist.
 */
  #undef FIX_FLT_OVERLOADS

/*
 * The double versions of the math functions are supposed to exist.
 */
  #undef FIX_DBL_OVERLOADS

/*
 * The overloaded functions are undefined for long double's as arguments.
 */
  #undef FIX_LDBL_OVERLOADS

/*
 * The two argument type generic overloaded math functions should work
 * with mixed types, e.g., a float and an int argument.
 */
  #undef FIX_MIXED_2_OVERLOAD

/*
 * Prototypes need to have the correct types for parameters.
 * Matters most for assignment to function pointer.
 * (Only list the bad ones found so far).
 */
  #undef FIX_BAD_PROTO_feholdexcept
  #undef FIX_BAD_PROTO_fesetexceptflag
  #undef FIX_BAD_PROTO_feupdateenv

/*
 * Invalid FPCE C code is accepted as valid. The code in question is:
 * Missing symbols defined in FP_H or FENV_H.  When upgraded the FPCE
 * tests for C99, these were expanded (since have sin(), sinf(), sinl(), eg,
 * must now have all three floating types for each math function).
 * At one time these symbols were the name of the file (e0210234 would
 * become FIX_ACC_e0210234) being tested.  This is now split into
 * two sections:  functions and others (macros and typedefs) and each
 * section has its own form.  The examples of each form are elsewhere in
 * this header.
 *
 * Functions are done as: FIX_TRUE_name, where name is the exact
 * spelling of the function that is missing.  These symbols are used in
 * the e021* tests.  In the rest of the test suite, use *_FUNCS_gname,
 * where gname is the generic name (without trailing f or l).
 *
 * The others are done as: FIX_name, where name is the exact spelling
 * of the macro or typedef that is missing. These symbols are used in both
 * the e021* tests and the rest of the test suite (to disable using something
 * that is missing).
 *
 * These missing symbols may show up at compiler time, link edit time, or
 * run time, depending upon the test and the usage of the symbol.
 */

/*
 * If all versions (float, double, long double, masking macro, overload)
 * of individual functions are missing, then define these symbols to bypass
 * using or testing them.  These cover multiple functions with one symbol.
 * FUNCS > FUNC > TRUE; or TRUE is subset of FUNC is subset of FUNCS.
 *
 * These symbols cover overloaded functions.
 *  acos(0.5f),    acos(0.5),   acos(0.5l), == overload
 *  acosf(0.5f),                acosl(0.5l), == masking macro
 * (acosf)(0.5f), (acos)(0.5), (acosl)(0.5l), == true function
 * are usages covered by these symbols.
 */
  #undef FIX_FUNCS_acos		/* acosf, acos, acosl */
/* ... thru ... */
  #undef FIX_FUNCS_trunc
  #undef FIX_FUNCS10_acos	/* acosd32, acosd64, acosd128 */
/* ... thru ... */
  #undef FIX_FUNCS10_trunc
  #undef FIX_FUNCS_strtod	/* strtof, strtod, strtold */
  #undef FIX_FUNCS10_strtod	/* strtod32, strtod64, strtod128 */

/*
 * The float versions of the FPCE functions are supposed to exist.
 * If all of them are missing, then define FIX_FUNCS_F (was
 * FIX_MISSING_F).  If just some of them are missing, then do
 * not define FIX_FUNCS_F, but, define the individual ones for
 * each missing function: FIX_FUNC_name, where name is the
 * exact spelling of the missing function (lower case with trailing f).
 * Was FIX_FUNCS_F_* (without trailing f) for the individual ones.
 *
 * These symbols cover masking macros and true functions.
 * acosf(0.5f), (acosf)(0.5f), strtof() are usages covered by these symbols.
 */
  #undef FIX_FUNCS_F
  #undef FIX_FUNCS10_F

  #undef FIX_FUNC_acosf
/* ... thru ... */
  #undef FIX_FUNC_truncf
  #undef FIX_FUNC_acosd32
/* ... thru ... */
  #undef FIX_FUNC_truncd32
  #undef FIX_FUNC_strtof

/*
 * There are several macros/functions in FP_H that are not overloaded
 * that take/return double.  They should exist.  Was FIX_MISSING_D.
 * These symbols cover masking macros and true functions.
 * nan(""), (nan)(""), strtod() are usages covered by these symbols.
 * Also applies to [non]overloaded double versions of the Decimal FP TR functions.
 */
  #undef FIX_FUNCS_D
  #undef FIX_FUNCS10_D

  #undef FIX_FUNC_modf
  #undef FIX_FUNC_nan
  #undef FIX_FUNC_nextafterd

  #undef FIX_FUNC_acosd64
/* ... thru ... */
  #undef FIX_FUNC_truncd64
  #undef FIX_FUNC_strtod

/*
 * The long double versions of the FPCE functions are supposed to exist.
 * If all of them are missing, then define FIX_FUNCS_L (was
 * FIX_MISSING_L).  If just some of them are missing, then do
 * not define FIX_FUNCS_L, but, define the individual ones for
 * each missing function: FIX_FUNC_name, where name is the
 * exact spelling of the missing function (lower case with trailing l).
 * Was FIX_FUNCS_L_* (without trailing l) for the individual ones.
 *
 * These symbols cover masking macros and true functions.
 * acosl(0.5l), (acosl)(0.5l), strtold() are usages covered by these symbols.
 */
  #undef FIX_FUNCS_L
  #undef FIX_FUNCS10_L

  #undef FIX_FUNC_acosl
/* ... thru ... */
  #undef FIX_FUNC_truncl
  #undef FIX_FUNC_acosd128
/* ... thru ... */
  #undef FIX_FUNC_truncd128
  #undef FIX_FUNC_strtold

/*
 * The headers may have masking/mapping macros from the user's expected
 * function name to an implementor's name of the true function.
 * Is there a true function by the expected name?
 * (acos)(0.5), (acosf)(0.5f), (acosl)(0.5l) are usages covered.
 */
  #undef FIX_TRUE_acos
  #undef FIX_TRUE_acosf
  #undef FIX_TRUE_acosl
/* ... thru ... */
  #undef FIX_TRUE_trunc
  #undef FIX_TRUE_truncf
  #undef FIX_TRUE_truncl

  #undef FIX_TRUE_acosd64
  #undef FIX_TRUE_acosd32
  #undef FIX_TRUE_acosd128
/* ... thru ... */
  #undef FIX_TRUE_truncd64
  #undef FIX_TRUE_truncd32
  #undef FIX_TRUE_truncd128

/*
 * FPCE added many new <math.h> functions above and beyond C89.  Most of
 * them are supposed to be overloaded.  This disables checking all of them.
 * You can disable checking certain ones by using the above methods
 * (one or more of FIX_ FUNCS / FUNC / TRUE _name).
 */
  #undef FIX_FPCE_FUNCTIONS

/*
 * sizeof(macro()) should be legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_fpclassify
  #undef FIX_SIZEOF_signbit
  #undef FIX_SIZEOF_isfinite
  #undef FIX_SIZEOF_isnormal
  #undef FIX_SIZEOF_isnan
  #undef FIX_SIZEOF_isinf
  #undef FIX_SIZEOF_isgreater
  #undef FIX_SIZEOF_isgreaterequal
  #undef FIX_SIZEOF_isless
  #undef FIX_SIZEOF_islessequal
  #undef FIX_SIZEOF_islessgreater
  #undef FIX_SIZEOF_isunordered

/*
 * -macro should be legal by ISO/ANSI C and is same as -(macro).
 * sizeof macro should be legal by ISO/ANSI C and is same as sizeof(macro).
 */
  #undef FIX_NEED_PARENS_FE_DFL_ENV
  #undef FIX_NEED_PARENS_L_tmpnam
  #undef FIX_NEED_PARENS_NULL
  #undef FIX_NEED_PARENS_WCHAR_MAX
  #undef FIX_NEED_PARENS_WCHAR_MIN
  #undef FIX_NEED_PARENS_WEOF

/*
 * sizeof(func(bit.field)) is legal by ISO/ANSI C.
 */
  #undef FIX_SIZEOF_BIT_FIELD

/*
 * [s]scanf should not accept all of 'nans' as a [signalling] nan;
 * It should accept the 'nan' and stop on the 's'.
 */
  #undef FIX_SCAN_nans
  #undef FIX_WSCAN_nans

/*
 * Expressions with (short and long long) and various op= operators done wrong.
 */
  #undef FIX_SHORT_ADDEQ_LONGLONG
  #undef FIX_SHORT_ANDEQ_LONGLONG
  #undef FIX_SHORT_DIVEQ_LONGLONG
  #undef FIX_SHORT_MULEQ_LONGLONG
  #undef FIX_SHORT_OREQ_LONGLONG
  #undef FIX_SHORT_REMEQ_LONGLONG
  #undef FIX_SHORT_SUBEQ_LONGLONG
  #undef FIX_SHORT_XOREQ_LONGLONG

/*
 * Wide char strings can be concatenated with narrow char strings in C99.
 */
  #undef FIX_CONCAT_WIDE_AND_NARROW

/*
 * Can a struct have a declaration like:
 *   bool b8 : 1; : 0, b9 : 1;
 * That is, a member with no ident in the middle of the list.
 */
  #undef FIX_NO_ID_IN_MID

/*
 * _Bool is a new type with C99.
 * This does a: typedef unsigned int _Bool; to allow code to compile.
 */
  #undef FIX_BOOL

/*
 * Having a small bool bit-field member of a struct kills some compilers.
 */
  #undef FIX_BOOL_BITFIELD

/*
 * Can multiple comma separated bool bit-fields be declared with one bool declaration?
 */
  #undef FIX_MULTIPLE_BOOLS

/*
 * _Bool bit-field are a new type with C99.  They can be any size
 * up to the number of bits in a _Bool (most likely, CHAR_BIT).
 * This bypasses bit-fields with "large" number of bits.
 * But, it has been pointed out to me (and Tom Plum) that _Bool
 * bit fields are limited to the number of VALUE bits in a _Bool,
 * (not the total bits which includes padding).
 */
  #undef FIX_BIG_BITFIELD

/*
 * Can zero width _Bool bit-fields be declared?  bool : 0;
 */
  #undef FIX_ZERO_WIDTH_BOOL

/*
 * _Bool is a new type with C99.
 * But, some compilers will not allow assignment to bools.
 */
  #undef FIX_ASSIGN_TO_BOOL

/*
 * Expressions with arith operator on bool bit field done wrong.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_OP_BOOL_BIT_FIELD

/*
 * ++bool  or bool++ not liked.
 */
  #undef FIX_BOOL_ADDADD

/*
 * --bool  or bool-- not liked.
 */
  #undef FIX_BOOL_SUBSUB

/*
 * Function call with int operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_INT

/*
 * Bools should be convertable to ints.
 */
  #undef FIX_INT_FROM_BOOL

/*
 * Function call with bit-field operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_BITFIELD

/*
 * Function call with bool operands should be convertable to bool.
 * Causes some compilers to get internal error or core dump.
 */
  #undef FIX_BOOL_FROM_BOOL

/*
 * Conversion to enum from bool not liked.
 */
  #undef FIX_ENUM_FROM_BOOL

/*
 * _Bool should promote when used with floating-point vars.
 * Some compilers die with things like: bool += 2.0;
 */
  #undef FIX_BOOL_FROM_DBL
  #undef FIX_BOOL_FROM_FLT
  #undef FIX_BOOL_FROM_LDBL

/*
 * Conversion of a floating-point fraction, e.g, 0.2, to _Bool
 * should be 1, not 0.  The semantics are different than
 * conversion to unsigned int.
 */
  #undef FIX_BOOL_FROM_FRACTION

/*
 * Pointers are a special case for assignment to _Bool.  Some compilers
 * do not allow it:  bool = &c;
 */
  #undef FIX_BOOL_FROM_PTR

/*
 * int bf : 3 = (_Bool)1; causes some compilers to complain.
 */
  #undef FIX_BITFIELD_FROM_BOOL

/*
 * bool b = (_Bool)1; causes some compilers to complain.
 */
  #undef FIX_BOOL_CAST

/*
 * inline is a new feature of C99.
 */
  #undef FIX_INLINE

/*
 * Following symbols are from FPCE draft 1996/02/26
 */
  #undef FIX_SYM___STDC_IEC_559__	/* predefined by compiler */
  #undef FIX_SYM_FLT_EVAL_METHOD	/* in <float.h> */

/*
 * Following symbols are from FPCE draft 1994/06/30
 */
  #undef FIX_SYM___FPCE__		/* predefined by compiler */
  #undef FIX_SYM___FPCE_IEEE__		/* predefined by compiler */
  #undef FIX_SYM__MIN_EVAL_FORMAT	/* in <float.h> */
  #undef FIX_SYM__WIDEST_NEED_EVAL	/* in <float.h> */

/*
 * FLT_EVAL_METHOD is supposed to be defined in <float.h>.
 */
  #undef FIX_FLT_EVAL_IN_HEADER

/*
 * _MIN_EVAL_FORMAT is supposed to be defined in <float.h>.
 */
  #undef FIX_MIN_EVAL_IN_HEADER

/*
 * _WIDEST_NEED_EVAL is supposed to be defined in <float.h>.
 */
  #undef FIX_WIDE_NEED_IN_HEADER

/*
 * Translation directives have gone back and forth between pragmas and
 * macros.  The FPCE technical report had more than C99.  Here are all
 * the choices.  They are defined before mydefs.h is included, so they
 * can NOT be undef'ed here.
 *
 * Use these symbols if the pragma causes translation to stop.
 */
/* #undef FIX_PRAGMAS		*/
/* #undef FIX_PRAGMA_FENV_ACCESS	*/
/* #undef FIX_PRAGMA_CONTRACT	*/
/* #undef FIX_PRAGMA_WIDE_RETURNS	*/
/* #undef FIX_PRAGMA_WIDE_PARMS	*/
/* #undef FIX_PRAGMA_WIDE_VARS	*/
/* #undef FIX_PRAGMA_DBL_CONST_DFP64 -- added by DFP TR	*/

/*
 * #pragma STDC FLOAT_CONST_DECIMAL64 ... is unknown or ignored
 */
  #undef FIX_DFP64_PRAGMA

/*
 * pragma 0x4.1p-10 causes a compiler to core dump (t0100100)
 */
  #undef FIX_HEX_FP_PRAGMA

/*
 * pragma fenv_access default causes a compiler to core dump
 */
  #undef FIX_ACCESS_DEFAULT

/*
 * pragma fp_contract default causes a compiler to core dump
 */
  #undef FIX_CONTRACT_DEFAULT

/*
 * pragma fp_wide_function_returns default causes a compiler to core dump
 */
  #undef FIX_RETURNS_DEFAULT

/*
 * pragma fp_wide_function_parameters default causes a compiler to core dump
 */
  #undef FIX_PARAMETERS_DEFAULT

/*
 * pragma fp_wide_variables default causes a compiler to core dump
 */
  #undef FIX_VARIABLES_DEFAULT

/*
 * Does the translator support FPCE hexadecimal floating constants?
 */
  #undef FIX_FPCE_HEX

/*
 * Does the translator support FPCE hexadecimal floating constants
 * for the value zero: 0x0p0?
 */
  #undef FIX_ZERO_HEX

/*
 * Does the translator support FPCE hexadecimal floating constants
 * for type float with a '+': 0x1p+0f
 */
  #undef FIX_pEXPf_HEX

/*
 * Some valid FPCE hexadecimal floating constants are not liked.
 */
  #undef FIX_VALID_FPCE_HEX

/*
 * Valid FPCE hexadecimal floating constants with 'E' in them are rejected.
 * Thinks 'E' in 0xabcdEf0123456789p0 is exponent.
 */
  #undef FIX_E_IN_HEXFP

/*
 * FPCE added floating-point environment <fenv.h> functions.
 * This disables checking all of them.
 * Use this if <fenv.h> is missing.
 * You can disable checking certain ones by using the above methods
 * (one or more of FIX_  FUNC / TRUE _name).
 * Better is to use:
 *   #define FENV_H "fenvdumy.h"
 * so that masking macros exist and are used.
 */
  #undef FIX_FENV_FUNCTIONS
  #undef FIX_FENV10_FUNCTIONS

/*
 * fetestexcept(), feclearexcept() should exist and work.
 * If either of these are missing, there is no way to see which exceptions
 * a given operation caused.  This disables those tests.
 */
  #undef FIX_FE_FLAGS

/*
 * fegetround(), fesetround() should exist and work.
 * Since hardware must do some rounding, dummy macros (like in fenvdumy.h)
 * can be created to indicate the fixed rounding, so this should never
 * need to be used.  Should only need FIX_RND_fesetround.
 */
  #undef FIX_FE_RND

/*
 * fegetenv(), fesetenv(), feupdateenv(), and feholdexcept() should exist
 * and work.
 */
  #undef FIX_FE_ENV

/*
 * fegetexceptflag() and fesetexceptflag() should exist and work.
 */
  #undef FIX_FE_EXCEPT

/*
 * nan*() functions are supposed to be defined.
 * Was FIX_ nan at one point.
 */
  #undef FIX_FUNCS_nan
  #undef FIX_FUNCS10_nan

/*
 * One vendor has a nans() function, which violates user's name space.
 * Was FIX_ nans at one point.
 */
  #undef FIX_FUNC_nans

/*
 * There are several "overloaded" function-like macros.
 * They should take args like d++.
 */
  #undef FIX_MACF_fpclassify
  #undef FIX_MACF_isfinite
  #undef FIX_MACF_isgreater
  #undef FIX_MACF_isgreaterequal
  #undef FIX_MACF_isinf
  #undef FIX_MACF_isless
  #undef FIX_MACF_islessequal
  #undef FIX_MACF_islessgreater
  #undef FIX_MACF_isnan
  #undef FIX_MACF_isnormal
  #undef FIX_MACF_isunordered
  #undef FIX_MACF_signbit

/*
 * There are several "overloaded" function-like macros.
 * If they work ok for single constants and variables, but
 * fail for expressions, define these symbols.
 */
  #undef FIX_fpclassify_EXP

/*
 * There are several "overloaded" function-like macros.
 * If they do not work ok for denormal/subnormal numbers,
 * define these symbols.
 */
  #undef  FIX_fpclassify_DEN
  #undef  FIX_fpclassify_DEN10
  #undef  FIX_isnormal_DEN
  #undef  FIX_isnormal_DEN10

/*
 * islessgreater cannot be used as an argument to a macro
 */
  #undef FIX_LTGT_2_MACRO

/*
 * There are several macros that should return
 * (or are) a signed int type.
 */
  #undef FIX_unsigned_FP_INFINITE
  #undef FIX_unsigned_FP_NAN
  #undef FIX_unsigned_FP_NORMAL
  #undef FIX_unsigned_FP_SUBNORMAL
  #undef FIX_unsigned_FP_ZERO
  #undef FIX_unsigned_fpclassify
  #undef FIX_unsigned_isfinite
  #undef FIX_unsigned_isgreater
  #undef FIX_unsigned_isgreaterequal
  #undef FIX_unsigned_isinf
  #undef FIX_unsigned_isless
  #undef FIX_unsigned_islessequal
  #undef FIX_unsigned_islessgreater
  #undef FIX_unsigned_isnan
  #undef FIX_unsigned_isnormal
  #undef FIX_unsigned_isunordered
  #undef FIX_unsigned_math_errhandling
  #undef FIX_unsigned_signbit
  #undef FIX_unsigned___STDC_IEC_559__
  #undef FIX_unsigned___STDC_DEC_FP__

/*
 * There are several "overloaded" function-like macros.
 * They should take constants and expressions, that is,
 * things different than variables.
 */
  #undef FIX_signbit_NON_VAR

/*
 * The signbit macro does the wrong thing for -0.0 and -0.0L,
 * and +1.0 and +1.0L.
 */
  #undef FIX_MINUS_DBL_signbit
  #undef FIX_MINUS_LDBL_signbit
  #undef FIX_PLUS_DBL_signbit
  #undef FIX_PLUS_LDBL_signbit

/*
 * The "overloaded" function-like macros are macros
 * (not generic or builtin functions).
 */
  #undef FIX_isinf_IS_A_MACRO
  #undef FIX_isnan_IS_A_MACRO
  #undef FIX_isfinite_IS_A_MACRO
  #undef FIX_isnormal_IS_A_MACRO
  #undef FIX_signbit_IS_A_MACRO
  #undef FIX_fpclassify_IS_A_MACRO
  #undef FIX_isless_IS_A_MACRO
  #undef FIX_islessequal_IS_A_MACRO
  #undef FIX_isgreater_IS_A_MACRO
  #undef FIX_isgreaterequal_IS_A_MACRO
  #undef FIX_islessgreater_IS_A_MACRO
  #undef FIX_isunordered_IS_A_MACRO

/*
 * <math.h> (was <fp.h>) object-like symbolic macros are supposed to be defined.
 */
  #undef FIX_SYM_HUGE_VAL
  #undef FIX_SYM_HUGE_VALF
  #undef FIX_SYM_HUGE_VALL
  #undef FIX_SYM_DECIMAL_DIG	/* in <float.h> as of 1998/06/26 */
  #undef FIX_SYM_DECIMAL_DIG_ENUM
  #undef FIX_SYM_INFINITY
  #undef FIX_SYM_NAN
  #undef FIX_SYM_FP_ILOGB0
  #undef FIX_SYM_FP_ILOGBNAN
  #undef FIX_SYM_FP_NAN	/* One vendor has FP_NANQ and FP_NANS. */
  #undef FIX_SYM_FP_INFINITE
  #undef FIX_SYM_FP_NORMAL
  #undef FIX_SYM_FP_SUBNORMAL
  #undef FIX_SYM_FP_ZERO
  #undef FIX_SYM_FP_NAN_ENUM
  #undef FIX_SYM_FP_INFINITE_ENUM
  #undef FIX_SYM_FP_NORMAL_ENUM
  #undef FIX_SYM_FP_SUBNORMAL_ENUM
  #undef FIX_SYM_FP_ZERO_ENUM
  #undef FIX_SYM_MATH_ERREXCEPT
  #undef FIX_SYM_MATH_ERRNO
  #undef FIX_SYM_math_errhandling

/*
 * The FP_ILOGB* macro symbols need <limits.h> for INT_MIN
 */
  #undef FIX_FP_ILOGB_NEEDS_LIMITS_H

/*
 * <fenv.h> object-like symbolic macros are supposed to be #defined
 * (if supported).
 */
  #undef FIX_SYM_FE_INVALID
  #undef FIX_SYM_FE_DIVBYZERO
  #undef FIX_SYM_FE_OVERFLOW
  #undef FIX_SYM_FE_UNDERFLOW
  #undef FIX_SYM_FE_INEXACT
  #undef FIX_SYM_FE_ALL_EXCEPT

  #undef FIX_SYM_FE_INVALID_ENUM
  #undef FIX_SYM_FE_DIVBYZERO_ENUM
  #undef FIX_SYM_FE_OVERFLOW_ENUM
  #undef FIX_SYM_FE_UNDERFLOW_ENUM
  #undef FIX_SYM_FE_INEXACT_ENUM
  #undef FIX_SYM_FE_ALL_EXCEPT_ENUM

  #undef FIX_SYM_FE_TONEAREST
  #undef FIX_SYM_FE_UPWARD
  #undef FIX_SYM_FE_DOWNWARD
  #undef FIX_SYM_FE_TOWARDZERO

  #undef FIX_SYM_FE_TONEAREST_ENUM
  #undef FIX_SYM_FE_UPWARD_ENUM
  #undef FIX_SYM_FE_DOWNWARD_ENUM
  #undef FIX_SYM_FE_TOWARDZERO_ENUM

  #undef FIX_SYM_FE_DFL_ENV

  #undef FIX_SYM_FE_FLTPREC		/* optional */
  #undef FIX_SYM_FE_DBLPREC		/* optional */
  #undef FIX_SYM_FE_LDBLPREC		/* optional */

  #undef FIX_SYM_FE_FLTPREC_ENUM	/* optional */
  #undef FIX_SYM_FE_DBLPREC_ENUM	/* optional */
  #undef FIX_SYM_FE_LDBLPREC_ENUM	/* optional */

  #undef FIX_SYM_FE_TRAP_INVALID	/* optional */
  #undef FIX_SYM_FE_TRAP_DIVBYZERO	/* optional */
  #undef FIX_SYM_FE_TRAP_OVERFLOW	/* optional */
  #undef FIX_SYM_FE_TRAP_UNDERFLOW	/* optional */
  #undef FIX_SYM_FE_TRAP_INEXACT	/* optional */
  #undef FIX_SYM_FE_TRAP_ALL		/* optional */

  #undef FIX_SYM_FE_TRAP_INVALID_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_DIVBYZERO_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_OVERFLOW_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_UNDERFLOW_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_INEXACT_ENUM	/* optional */
  #undef FIX_SYM_FE_TRAP_ALL_ENUM	/* optional */

/*
 * The FE_* macros, when used in #if must not be 0.
 * One implementation first defines the FE_* symbols via enums.
 * Then defines the FE_* macros as itself.
 * They show up as defined, but have the value 0 to #if.
 */
  #undef FIX_FE_MACROS

/*
 * <math.h> (was <fp.h>) typedefs are supposed to be defined.
 */
  #undef FIX_TYPEDEF_float_t
  #undef FIX_TYPEDEF_double_t

/*
 * <fenv.h> typedefs are supposed to be defined.
 */
  #undef FIX_TYPEDEF_fenv_t
  #undef FIX_TYPEDEF_fexcept_t
  #undef FIX_TYPEDEF_fetrap_t	/* optional */

/*
 * FE_DFL_ENV is supposed to be usable.  With this defined,
 * IMPL_COMP_FE_DFL_ENV will be defined in myfloat.h
 */
  #undef FIX_USABLE_FE_DFL_ENV

/*
 * FE_DFL_ENV is supposed to be const qualified.  Either it is not const,
 * or compiler allows pointer to r/w to point to it.
 */
  #undef FIX_MODIFY_FE_DFL_ENV

/*
 * INF should be usable for static and aggregate initialization.
 * This is a should, not a shall, so is optional in FPCE.
 * When added to C99, it became a shall.
 */
  #undef FIX_STATIC_INF
  #undef FIX_STATIC_INF10

/*
 * INF_FLT, INF_DBL, INF_LDBL should be usable for static and aggregate
 * initialization.  They are sometimes done as 1.0/0.0 (which is a valid
 * arithmetic constant expression).  Some compilers allow:
 *   double d = 1.0/0.0;
 * but not:
 *   double d[1] = { 1.0/0.0 };
 * This is mainly needed in the math library tests for compilers that
 * do not support infinity via 1e999999.
 */
  #undef FIX_INF_IN_ARRAY

/*
 * NAN should be usable for static and aggregate initialization.
 * This is a should, not a shall, so is optional in FPCE.
 * When added to C99, it became a shall.
 */
  #undef FIX_STATIC_NAN
  #undef FIX_STATIC_NAN10

/*
 * NAN_FLT, NAN_DBL, NAN_LDBL should be usable for static and aggregate
 * initialization.  They are typically done as 0.0/0.0 (which is a valid
 * arithmetic constant expression).  Some compilers allow:
 *   double d = 0.0/0.0;
 * but not:
 *   double d[1] = { 0.0/0.0 };
 * This is mainly needed in the math library tests.
 */
  #undef FIX_NAN_IN_ARRAY

/*
 * NAN_* should be usable in mixed FP type expressions.
 * Causes a couple of compilers to core dump during translation.
 */
  #undef FIX_NAN_MATH

/*
 * using namespace std; is needed to compile these tests as C++ code
 * (so do not need to do std::sin() or std::printf()).
 * Some older C++ compilers do not have that namespace.
 */
  #undef FIX_NAMESPACE_STD

/*
 * int vla[(int)x]; is a variable length array, new with C99.
 * If you get compile time errors (because the compiler does
 * not support vla's), define this symbol.
 */
  #undef FIX_VLA

/*
 * int vla[(int)(x*y)]; is a variable length array with
 * expression using floating-point variables. If the you get
 * compiler time errors (because the compiler does
 * not support vla's with variables), define this symbol.
 */
  #undef FIX_TRUE_VLA

/*
 * Compound literals are new with C99.
 */
  #undef FIX_COMPOUND_LIT

/*
 * Compound literals with bool members are not liked.
 */
  #undef FIX_BOOL_COMPOUND_LIT

/*
 * (struct bits){1, 1, 1}.member not liked by some compilers.
 */
  #undef FIX_COMPOUND_LIT_MEMBER

/*
 * struct flex { int n; double d[]; }; is a flexible array, new with C99.
 * If you get compile time errors (because the compiler does
 * not support flex arrays), define this symbol.
 */
  #undef FIX_FLEX_ARRAY

/*
 * offsetof() appiled to flexible array should be the same as with a
 * fixed size array.
 */
  #undef FIX_OFFSET_FLEX

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * struct stx { bool bx : 0; ...   bx should not be there.
 */
  #undef FIX_ACC_BAD_BOOL_BITFIELD_DECL

/*
 * Invalid ISO/ANSI C code is accepted as valid. The code in question is:
 * struct stx { bool bx : BOOL_PREC+1; ...   width is too big.
 */
  #undef FIX_ACC_BAD_BOOL_BITFIELD_WIDTH

/*
 * Variable length array (VLA) has many restrictions on them.
 * Many compilers accept invalid code.  Define these to force
 * a failure in the corresponding e018*00 or e018*02 test.
 */
  #undef FIX_ACC_VLA_IN_STRUCT	/* e01806 */
  #undef FIX_ACC_VLA_IN_UNION	/* e01807 */
  #undef FIX_ACC_STATIC_VLA	/* e01808 */
  #undef FIX_ACC_EXTERN_VLA	/* e01809 */
  #undef FIX_ACC_FILESCOPE_VLA	/* e01810 */
  #undef FIX_ACC_FILE_TYPEDEF_VLA	/* e01811 */
  #undef FIX_ACC_INITIALIZE_VLA	/* e01812 */
  #undef FIX_ACC_VLA_IN_COMPOUND_LIT	/* e01813 */
  #undef FIX_ACC_SWITCH_VLA	/* e01814 */
  #undef FIX_ACC_GOTO_VLA	/* e01815 */
  #undef FIX_VLA_SUBSCRIPT_ACC_FLOAT
  #undef FIX_VLA_SUBSCRIPT_ACC_PTR

/*
 * Flexible arrays have many restrictions on them.
 * Many compilers accept invalid code.  Define these to force
 * a failure in the corresponding e018*03 test.
 */
  #undef FIX_ACC_FLEX_ARRAY_IN_STRUCT	/* e0180603 */
  #undef FIX_ACC_FLEX_ARRAY_IN_UNION	/* e0180703 */
  #undef FIX_ACC_STATIC_FLEX_ARRAY	/* e0180803 */
  #undef FIX_ACC_EXTERN_FLEX_ARRAY	/* e0180903 */
  #undef FIX_ACC_FILESCOPE_FLEX_ARRAY	/* e0181003 */
  #undef FIX_ACC_FILE_TYPEDEF_FLEX_ARRAY	/* e0181103 */
  #undef FIX_ACC_INITIALIZE_FLEX_ARRAY	/* e0181203 */
  #undef FIX_ACC_FLEX_ARAY_IN_COMPND_LIT	/* e0181303 */
  #undef FIX_ACC_SWITCH_FLEX_ARRAY	/* e0181403 */
  #undef FIX_ACC_GOTO_FLEX_ARRAY	/* e0181503 */
  #undef FIX_FLEX_ACC_FLOAT
  #undef FIX_FLEX_SUBSCRIPT_ACC_PTR

/*
 * Invalid FPCE C code is accepted as valid. The code in question is:
 * Invalid FPCE hex floating-point constant.  When upgraded the FPCE test
 * suite for C99, the files were renumbered to a better range.
 */
  #if FPCE_TEST_LVL >= 19960226uL
    #undef FIX_ACC_e0100300
   /* ... thru ... */
    #undef FIX_ACC_e0100370
  #else		/* 19940630uL */
    #undef FIX_ACC_e0100212
   /* ... thru ... */
    #undef FIX_ACC_e0100282
  #endif

/*
 * Uniary operators accept integer or pointer operands.
 */
  #undef IMPL_fpclassify_ACC_INT_PTR
  #undef IMPL_isfinite_ACC_INT_PTR
  #undef IMPL_isinf_ACC_INT_PTR
  #undef IMPL_isnan_ACC_INT_PTR
  #undef IMPL_isnormal_ACC_INT_PTR
  #undef IMPL_signbit_ACC_INT_PTR

/*
 * Uniary operators accept incomplete types
 */
  #undef FIX_POST_INC_DEC_ACC_INCOMPLETE
  #undef FIX_PRE_INC_DEC_ACC_INCOMPLETE

/*
 * Uniary operators accept complex or imaginary operands.
 */
  #undef FIX_POST_INC_DEC_ACC_CX_IM
  #undef FIX_PRE_INC_DEC_ACC_CX_IM
  #undef IMPL_fpclassify_ACC_CX_IM
  #undef IMPL_isfinite_ACC_CX_IM
  #undef IMPL_isinf_ACC_CX_IM
  #undef IMPL_isnan_ACC_CX_IM
  #undef IMPL_isnormal_ACC_CX_IM
  #undef IMPL_signbit_ACC_CX_IM

/*
 * Binary operators accept integer or pointer operands.
 */
  #undef IMPL_isgreater_ACC_INT_PTR
  #undef IMPL_isgreaterequal_ACC_INT_PTR
  #undef IMPL_isless_ACC_INT_PTR
  #undef IMPL_islessequal_ACC_INT_PTR
  #undef IMPL_islessgreater_ACC_INT_PTR
  #undef IMPL_isunordered_ACC_INT_PTR

/*
 * Binary operators accept complex or imaginary operands.
 */
  #undef FIX_BIN_GE_ACC_CX_IM
  #undef FIX_BIN_GT_ACC_CX_IM
  #undef FIX_BIN_LE_ACC_CX_IM
  #undef FIX_BIN_LT_ACC_CX_IM
  #undef IMPL_isgreater_ACC_CX_IM
  #undef IMPL_isgreaterequal_ACC_CX_IM
  #undef IMPL_isless_ACC_CX_IM
  #undef IMPL_islessequal_ACC_CX_IM
  #undef IMPL_islessgreater_ACC_CX_IM
  #undef IMPL_isunordered_ACC_CX_IM

/*
 * int func();  ....; int func(float imag) should be accepted.
 */
  #undef  FIX_OLD_STYLE_FLT_IMAG

/*** Translate time: DFP: ***/

/*
 * Decimal FP TR added many new <math.h> functions above and beyond
 * C99.  Most of them are supposed to be overloaded.  This disables
 * checking all of them.
 * You can disable checking certain ones by using the above methods
 * (one or more of FIX_ FUNCS10 / FUNC / TRUE _name).
 */
  #undef FIX_DECFP_FUNCTIONS

/*
 * Decimal FP TR added many new macros and functions above and beyond C99.
 * They may end up in existing standard headers, or be in their own headers.
 * For compilers that have them outside of standard headers, you need to
 * define these symbols (as appropriate).
 */
  #undef FIX_DECFP_IN_FENV_H
  #undef FIX_DECFP_IN_FLOAT_H
  #undef FIX_DECFP_IN_MATH_H
  #undef FIX_DECFP_IN_STDLIB_H
  #undef FIX_DECFP_IN_WCHAR_H

/*
 * An implementation of DFP is supposed to defined this symbol.
 */
  #undef FIX_SYM___STDC_DEC_FP__

/*
 * DEC_EVAL_METHOD is supposed to be defined in <float.h>.
 */
  #undef FIX_DEC_EVAL_IN_HEADER

/*
 * The DFP symbols in headers are only defined with the first usage
 * of that header and with __STDC_WANT_DEC_FP__ defined before that
 * first usage.  [Not sure about this].  See t6060200.
 */
  #undef FIX_DFP_SYMBOLS_IN_HEADER

/*
 * To prevent the Decimal FP support functions in s0000000 from being defined,
 * you need to #define this symbol.  This is for implementations that are
 * starting to support DFP, but too much is still missing.
 */
  #undef FIX_DEC_FP

/*
 * The Decimal FP Tech Report is adding many new symbols to <float.h>.
 *
 * The symbol to represent the smallest denormal/subnormal number.
 * Its name changed as the TR evolved.  Was DEC*_DEN.
 */
  #undef FIX_SYM_DEC32_SUBNORMAL_MIN
  #undef FIX_SYM_DEC64_SUBNORMAL_MIN
  #undef FIX_SYM_DEC128_SUBNORMAL_MIN
  #undef FIX_SYM_DEC32_DEN
  #undef FIX_SYM_DEC64_DEN
  #undef FIX_SYM_DEC128_DEN

/*
 * DFP TR added some more symbols to <fenv.h>
 */
  #undef FIX_SYM_FE_DEC_DOWNWARD
  #undef FIX_SYM_FE_DEC_TONEAREST
  #undef FIX_SYM_FE_DEC_TONEARESTFROMZERO
  #undef FIX_SYM_FE_DEC_TOWARDZERO
  #undef FIX_SYM_FE_DEC_UPWARD

/*
 * DFP TR added some more symbols to <math.h>
 */
  #undef FIX_SYM_DEC_INFINITY
  #undef FIX_SYM_DEC_NAN
  #undef FIX_SYM_HUGE_VAL_D128
  #undef FIX_SYM_HUGE_VAL_D32
  #undef FIX_SYM_HUGE_VAL_D64

/*
 * Binary operators accept mixed Decimal FP and Binary FP operands.
 */
  #undef FIX_BIN_ADD_MIX_DFP_BFP
  #undef FIX_BIN_SUB_MIX_DFP_BFP
  #undef FIX_BIN_MULT_MIX_DFP_BFP
  #undef FIX_BIN_DIV_MIX_DFP_BFP
  #undef FIX_BIN_EQ_MIX_DFP_BFP
  #undef FIX_BIN_GE_MIX_DFP_BFP
  #undef FIX_BIN_GT_MIX_DFP_BFP
  #undef FIX_BIN_LE_MIX_DFP_BFP
  #undef FIX_BIN_LT_MIX_DFP_BFP
  #undef FIX_BIN_NE_MIX_DFP_BFP
  #undef FIX_BIN_PLUS_EQ_MIX_DFP_BFP
  #undef FIX_BIN_SUB_EQ_MIX_DFP_BFP
  #undef FIX_BIN_MULT_EQ_MIX_DFP_BFP
  #undef FIX_BIN_DIV_EQ_MIX_DFP_BFP
  #undef IMPL_isgreater_MIX_DFP_BFP
  #undef IMPL_isgreaterequal_MIX_DFP_BFP
  #undef IMPL_isless_MIX_DFP_BFP
  #undef IMPL_islessequal_MIX_DFP_BFP
  #undef IMPL_islessgreater_MIX_DFP_BFP
  #undef IMPL_isunordered_MIX_DFP_BFP
  #undef FIX_TRI_COND_OP_MIX_DFP_BFP

/*
 * To distinguish BFP from DFP for unsuffixed double constants,
 * the DFP TR add a 'd' and 'D' suffix to make sure that the
 * FP constant is 'double'.  Some compilers that support DFP TR,
 * do not yet support this suffix (causes translation to stop).
 */
  #undef FIX_D_SUFFIX

/*
 * The DFP constants in the system headers cause translation to end.
 */
  #undef FIX_D10_CONSTS

/*
 * Tests of invalid suffixes on DFP constants.
 * Define these if the compiler accepts these invalid forms.
 */
  #undef FIX_ACC_e6100400
  /* thru */
  #undef FIX_ACC_e6100419

/*
 * #pragma STDC FLOAT_CONST_DECIMAL64 should be followed by one of
 * DEFAULT | ON | OFF
 * and honored.
 */
  #undef IMPL_DFP64_ACC_NOTHING		/* accepts nothing */
  #undef IMPL_DFP64_ACC_on		/* accepts on */
  #undef IMPL_DFP64_ACC_off		/* accepts off */
  #undef IMPL_DFP64_ACC_default		/* accepts default */
  #undef IMPL_DFP64_ACC_junk		/* accepts junk */
  #undef IMPL_DFP64_ACC_ON2		/* accepts ON ON */
  #undef IMPL_DFP64_ACC_OFF2		/* accepts OFF OFF */
  #undef IMPL_DFP64_ACC_DEFAULT2	/* accepts DEFAULT DEFAULT */
  #undef IMPL_DFP64_ACC_WRONG_PLACE	/* accepted in wrong place */
  #undef FIX_DFP64_PRAGMA		/* ignored */
  #undef FIX_DFP64_ACC_MIXED		/* works, but accepts mixed DFP/BFP */
  #undef FIX_DFP64_ACC_HEXFP		/* applied to unsuffixed hexadecimal FP const */

/*****************
 * These show up as runtime errors that cause test case failure.
 * These are normally due to bad code generation or bad translation time
 * conversions or bad library functions.
 *
 * First are the old (ISO/ANSI) C89/C90/C95 violations.
 * Second are the Standard C99 violations.
 * Third are the Decimal Floating-Point (DFP) Tech Report violations.
 ****************/

/*** Run time: C89/C90/C95 ***/
/*** Run time: C89/C90/C95: value of constant problems ***/

/*
 * Units Last Place error allowed for decimal (or hex FP) to binary conversion.
 * Must be an integer, since used in preprocessor #if
 *  0 => converted value must match round to nearest (rn) value
 * -1 => converted value is either round -INF (rm) or round +INF (rp) value
 *  j => converted value is in rn +/- j ULPs, inclusive of end points;
 *	 (Std C is 1 ulp except at power of base, where -1/radix ulp ... +1 ulp)
 * rm <= rn, rn <= rp, rm + 1 ulp = rp
 * Undefined will be treated like 0
 * *_DEC2BIN_* is for compile time conversions.
 * *_SCAN2BIN_* is for runtime conversions (scanf and strto*).
 * *_WSCAN2BIN_* is for runtime conversions (wscanf and wcsto*).
 * *_STRTOBIN_ULPS is for runtime conversions (strto*).
 * *_WCSTOBIN_ULPS is for runtime conversions (wcsto*).
 * *_BIN2DEC2BIN_ULPS is for binary to decimal to binary (printf & scanf);
 * *_BIN2HEX2BIN_ULPS is for binary to hexadecimal to binary (printf & scanf);
 *   the roundtrip ULP error must be zero or positive.
 * Symbols with '10' or 'DFP' are for Decimal FP types.
 */
  #undef LD_DEC2BIN_ULPS
  #undef  D_DEC2BIN_ULPS
  #undef  F_DEC2BIN_ULPS
  #undef LD10_DEC2DFP_ULPS
  #undef  D10_DEC2DFP_ULPS
  #undef  F10_DEC2DFP_ULPS

  #undef LD_SCAN2BIN_ULPS
  #undef  D_SCAN2BIN_ULPS
  #undef  F_SCAN2BIN_ULPS
  #undef LD10_SCAN2DFP_ULPS
  #undef  D10_SCAN2DFP_ULPS
  #undef  F10_SCAN2DFP_ULPS

  #undef LD_WSCAN2BIN_ULPS
  #undef  D_WSCAN2BIN_ULPS
  #undef  F_WSCAN2BIN_ULPS

  #undef LD_STRTOBIN_ULPS
  #undef  D_STRTOBIN_ULPS
  #undef  F_STRTOBIN_ULPS
  #undef LD10_STRTODFP_ULPS
  #undef  D10_STRTODFP_ULPS
  #undef  F10_STRTODFP_ULPS

  #undef LD_WCSTOBIN_ULPS
  #undef  D_WCSTOBIN_ULPS
  #undef  F_WCSTOBIN_ULPS

  #undef LD_BIN2DEC2BIN_ULPS
  #undef  D_BIN2DEC2BIN_ULPS
  #undef  F_BIN2DEC2BIN_ULPS
  #undef LD10_DFP2DEC2DFP_ULPS
  #undef  D10_DFP2DEC2DFP_ULPS
  #undef  F10_DFP2DEC2DFP_ULPS

  #undef LD_BIN2HEX2BIN_ULPS
  #undef  D_BIN2HEX2BIN_ULPS
  #undef  F_BIN2HEX2BIN_ULPS

/*
 * If a value of a macro symbol in <float.h> or yourfile.flt is wrong and
 * cannot be fixed (because the decimal to binary conversion is too sloppy)
 * this bypasses tests and some uses of that symbol.  Shown here are just the
 * FLT versions of the symbols, but you can also use DBL and LDBL versions.
 * This mainly effects t0000000/t6000000.
 */
  #undef	FIX_WRONG_DEC32_DIG		/* <decfloat.h> symbols */
  #undef	FIX_WRONG_DEC32_EPS
  #undef	FIX_WRONG_DEC32_MAX
  #undef	FIX_WRONG_DEC32_MAX_EXP
  #undef	FIX_WRONG_DEC32_MIN
  #undef	FIX_WRONG_DEC32_MIN_EXP
  #undef	FIX_WRONG_DECIMAL_DIG		/* Has wrong value (too small) */
  #undef	FIX_WRONG_FLT_DIG		/* <float.h> symbols */
  #undef	FIX_WRONG_FLT_EPS
  #undef	FIX_WRONG_FLT_MAX
  #undef	FIX_WRONG_FLT_MAX_EXP
  #undef	FIX_WRONG_FLT_MIN
  #undef	FIX_WRONG_FLT_MIN_EXP

  #undef	FIX_WRONG_DEN_F10
  #undef	FIX_WRONG_DEN_FLT
  #undef	FIX_WRONG_INF_F10		/* yourfile.flt symbols */
  #undef	FIX_WRONG_INF_FLT		/* yourfile.flt symbols */
  #undef	FIX_WRONG_MAX_F10
  #undef	FIX_WRONG_MAX_FLT
  #undef	FIX_WRONG_MAXm1_F10
  #undef	FIX_WRONG_MAXm1_FLT
  #undef	FIX_WRONG_MIN_F10
  #undef	FIX_WRONG_MIN_FLT
  #undef	FIX_WRONG_ONEm1_F10
  #undef	FIX_WRONG_ONEm1_FLT
  #undef	FIX_WRONG_ONEp1_F10
  #undef	FIX_WRONG_ONEp1_FLT
  #undef	FIX_WRONG_TRD_D_F10
  #undef	FIX_WRONG_TRD_D_FLT
  #undef	FIX_WRONG_TRD_U_F10
  #undef	FIX_WRONG_TRD_U_FLT
  #undef	FIX_WRONG_ULP_F10
  #undef	FIX_WRONG_ULP_FLT

/*
 * If a value of a macro symbol in <float.h> or yourfile.flt is close, but
 * not exact, this bypasses some tests.  It may happen that when the decimal
 * constant is assigned to a var of its type, the value is correct, but if
 * the decimal constant is used in an expression, then its value may differ
 * a little from the correct value.  This mainly effects t0000000/t6000000.
 */
  #undef	FIX_CLOSE_DBL_EPS		/* <float.h> symbols */
  #undef	FIX_CLOSE_DBL_MAX
  #undef	FIX_CLOSE_DBL_MIN
  #undef	FIX_CLOSE_DEC128_EPS
  #undef	FIX_CLOSE_DEC128_MAX
  #undef	FIX_CLOSE_DEC128_MIN
  #undef	FIX_CLOSE_DEC32_EPS
  #undef	FIX_CLOSE_DEC32_MAX
  #undef	FIX_CLOSE_DEC32_MIN
  #undef	FIX_CLOSE_DEC64_EPS		/* <decfloat.h> symbols */
  #undef	FIX_CLOSE_DEC64_MAX
  #undef	FIX_CLOSE_DEC64_MIN
  #undef	FIX_CLOSE_FLT_EPS
  #undef	FIX_CLOSE_FLT_MAX
  #undef	FIX_CLOSE_FLT_MIN
  #undef	FIX_CLOSE_LDBL_EPS
  #undef	FIX_CLOSE_LDBL_MAX
  #undef	FIX_CLOSE_LDBL_MIN

  #undef	FIX_CLOSE_DEN_D10
  #undef	FIX_CLOSE_DEN_DBL		/* yourfile.flt symbols */
  #undef	FIX_CLOSE_DEN_F10
  #undef	FIX_CLOSE_DEN_FLT
  #undef	FIX_CLOSE_DEN_LDBL
  #undef	FIX_CLOSE_MAX_D10
  #undef	FIX_CLOSE_MAX_DBL
  #undef	FIX_CLOSE_MAX_F10
  #undef	FIX_CLOSE_MAX_FLT
  #undef	FIX_CLOSE_MAX_LD10
  #undef	FIX_CLOSE_MAX_LDBL
  #undef	FIX_CLOSE_MAXm1_D10
  #undef	FIX_CLOSE_MAXm1_DBL
  #undef	FIX_CLOSE_MAXm1_F10
  #undef	FIX_CLOSE_MAXm1_FLT
  #undef	FIX_CLOSE_MAXm1_LD10
  #undef	FIX_CLOSE_MAXm1_LDBL
  #undef	FIX_CLOSE_MIN_D10
  #undef	FIX_CLOSE_MIN_DBL
  #undef	FIX_CLOSE_MIN_F10
  #undef	FIX_CLOSE_MIN_FLT
  #undef	FIX_CLOSE_MIN_LD10
  #undef	FIX_CLOSE_MIN_LDBL
  #undef	FIX_CLOSE_ONEm1_D10
  #undef	FIX_CLOSE_ONEm1_DBL
  #undef	FIX_CLOSE_ONEm1_F10
  #undef	FIX_CLOSE_ONEm1_FLT
  #undef	FIX_CLOSE_ONEm1_LD10
  #undef	FIX_CLOSE_ONEm1_LDBL
  #undef	FIX_CLOSE_ONEp1_D10
  #undef	FIX_CLOSE_ONEp1_DBL
  #undef	FIX_CLOSE_ONEp1_F10
  #undef	FIX_CLOSE_ONEp1_FLT
  #undef	FIX_CLOSE_ONEp1_LD10
  #undef	FIX_CLOSE_ONEp1_LDBL
  #undef	FIX_CLOSE_TRD_D10
  #undef	FIX_CLOSE_TRD_DBL
  #undef	FIX_CLOSE_TRD_F10
  #undef	FIX_CLOSE_TRD_FLT
  #undef	FIX_CLOSE_TRD_LD10
  #undef	FIX_CLOSE_TRD_LDBL
  #undef	FIX_CLOSE_ULP_D10
  #undef	FIX_CLOSE_ULP_DBL
  #undef	FIX_CLOSE_ULP_F10
  #undef	FIX_CLOSE_ULP_FLT
  #undef	FIX_CLOSE_ULP_LD10
  #undef	FIX_CLOSE_ULP_LDBL

/*
 * Conversion from numeric constants to internal FP of my values in
 * myfloat.h are done so bad, that you need to use your own versions.
 * This is most likely due to too many digits in the myfloat.h versions.
 */
  #undef FIX_MYFLOAT_PI
  #undef FIX_MYFLOAT_PI34
  #undef FIX_MYFLOAT_PI2
  #undef FIX_MYFLOAT_PI4
  #undef FIX_MYFLOAT_LN2
  #undef FIX_MYFLOAT_LN10
  #undef FIX_MYFLOAT_LOG2
  #undef FIX_MYFLOAT_SQRT2
  #undef FIX_MYFLOAT_M_e
  #undef FIX_MYFLOAT_TWORPI

/*
 * The *_MIN values in <limits.h> are one too high, eg, *_MIN == -*_MAX
 * instead of -*_MAX-1; a symptom of this is invalid is not raised for
 * a floating-point value of *_MIN-1 converted to integral.
 */
  #undef FIX_HI_MIN

/*
 * 1.57 should be equal to 1.570; that is, adding a trailing zero should
 * not change the converted value.  This is Tydeman wish (not Std C).
 * It is FPCE requirement if FPCE requires round nearest.
 */
  #undef FIX_F_EQ_F0

/*
 * 0.0e9999999 is zero, not infinity nor pseudo-infinity nor NaN.
 */
  #undef FIX_ZERO_INFINITY

/*
 * 0.0e-9999999 is zero.  Caused infinite loop in one lint/compiler.
 */
  #undef FIX_ZERO_MINFINITY

/*
 * Decimal (external) to binary (internal) conversion by implementation must
 * produce one of 3 values:  nearest, nearest+ulp, nearest-ulp.  Some
 * implementations produce zero for non-zero finite representable numbers.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_ZERO	/* compile time translation */
  #undef FIX_DEC2DFP_ZERO	/* compile time translation */
  #undef FIX_SCAN2BIN_ZERO
  #undef FIX_SCAN2DFP_ZERO
  #undef FIX_WSCAN2BIN_ZERO
  #undef FIX_STR2BIN_ZERO	/* strto* */
  #undef FIX_WCS2BIN_ZERO	/* wcsto* */

/*
 * Decimal (external) to binary (internal) conversion by implementation must
 * produce result with same sign as source.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_SIGN	/* compile time translation */
  #undef FIX_DEC2DFP_SIGN	/* compile time translation */
  #undef FIX_SCAN2BIN_SIGN
/*  #undef FIX_SCAN2DFP_SIGN */
  #undef FIX_WSCAN2BIN_SIGN
/*  #undef FIX_STR2BIN_SIGN	// strto* */
/*  #undef FIX_WCS2BIN_SIGN	// wcsto* */

/*
 * If the error in decimal (external) to binary (internal) conversion
 * is so large that it cannot be represented as a long int (used during
 * pre-processor), then define this symbol as a double value, eg,
 * #define FIX_DEC2BIN_LARGE 2.0e9
 * This is useful if most conversions have a small error (bypassed by
 * *_DEC2BIN_ULPS) and a few conversions with large error (bypassed by
 * this symbol).  This ignores errors LARGER than the macro's value.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_LARGE
  #undef FIX_DEC2DFP_LARGE
  #undef FIX_SCAN2BIN_LARGE
  #undef FIX_SCAN2DFP_LARGE
  #undef FIX_WSCAN2BIN_LARGE
  #undef FIX_STRTO2BIN_LARGE
  #undef FIX_WCSTO2BIN_LARGE

/*
 * Some conversion tests result in one of the two numbers being compared
 * being infinity and the other being a large finite.  The two numbers
 * are the expected correctly rounded value and the actual value.
 * That condition results in an infinite ulps error.  This symbol
 * allows those failures to be bypassed.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_INF
  #undef FIX_DEC2DFP_INF
  #undef FIX_DFP2BFP_INF
  #undef FIX_SCAN2BIN_INF
  #undef FIX_SCAN2DFP_INF
  #undef FIX_WSCAN2BIN_INF

/*
 * Decimal (external) to binary (internal) conversion by implementation must
 * produce one of 3 values:  nearest, nearest+ulp, nearest-ulp.  Some
 * implementations produce NaN for non-zero normal numbers.  Others produce
 * a NaN ulps error.  This symbol allows those failures to be bypassed.
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_DEC2BIN_NAN
  #undef FIX_DEC2DFP_NAN
  #undef FIX_SCAN2BIN_NAN
  #undef FIX_SCAN2DFP_NAN
  #undef FIX_WSCAN2BIN_NAN

/*
 * Decimal (external) to binary (internal) conversion by compiler of
 * value and -value should produce the same absolute value.
 */
  #undef FIX_DEC2BIN_OF_NEG
  #undef FIX_DEC2DFP_OF_NEG

/*
 * Decimal (external) to binary (internal) conversion by compiler must
 * produce one of 3 values:  nearest, nearest+ulp, nearest-ulp.  Some
 * compilers cannot even do that which is ISO/ANSI C requirement.
 */
  #undef FIX_DEC2BIN_3
  #undef FIX_SCAN2BIN_3
  #undef FIX_WSCAN2BIN_3

/*
 * Decimal (external) to binary (internal) conversion by compiler of
 * minimum normal long double number (MIN_LDBL) is not same as LDBL_MIN.
 */
  #undef FIX_MIN_LDBL
  #undef FIX_MIN_LD10

/*
 * If the error in binary (internal) to decimal (external) conversion
 * is so large that it cannot be represented as a long int (used during
 * pre-processor), then define this symbol as a double value, eg,
 * #define FIX_BIN2DEC_LARGE 2.0e9
 * This is useful if most conversions have a small error (bypassed by
 * *_BIN2DEC_*_ULPS) and a few conversions with large error (bypassed by
 * this symbol).  This ignores errors LARGER than the macros value.
 */
  #undef FIX_BIN2DEC_LARGE

/*** Run time: C89/C90/C95: code generation problems ***/

/*
 * constant*constant != var*var for same value
 */
  #undef FIX_CONST_CONST_EQ_VAR_VAR

/*
 * Static constant expression should be same as automatic constant expression
 * in all precisions.
 */
  #undef FIX_STATIC_EQ_AUTO

/*
 * Static constant expression should be same as automatic constant expression
 * in long double precision.  Or, translation time math should be the same as
 * run-time math.
 */
  #undef FIX_STATIC_EQ_AUTO_LDBL
  #undef FIX_STATIC_EQ_AUTO_LD10

/*
 * FP expressions using const VAR's should be run-time time, not
 * translation time, unless under pragma fenv_access off.
 */
  #undef FIX_CONST_VAR_EXP_AT_TRANS

/*
 * FP constant expressions should be run-time, not translation time,
 * unless under pragma fenv_access off.  This covers all five:
 * 0.0/0.0, 1.0/0.0, MAX*MAX, MIN*MIN, 1.0/3.0
 * For finer control see the next five items
 */
  #undef FIX_CONSTANT_EXP_AT_TRANS

/*
 * FP constant expression for invalid, eg, 0.0 / 0.0, should be run-time,
 * not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_0_OVER_0_EXP_AT_TRANS

/*
 * FP constant expression for divide by zero, eg, 1.0 / 0.0, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_1_OVER_0_EXP_AT_TRANS

/*
 * FP constant expression for overflow, eg, MAX * MAX, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_MAX_TIMES_MAX_EXP_AT_TRANS

/*
 * FP constant expression for underflow, eg, MIN * MIN, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_MIN_TIMES_MIN_EXP_AT_TRANS

/*
 * FP constant expression for inexact, eg, 1.0 / 3.0, should be
 * run-time, not translation time, unless under pragma fenv_access off.
 * This is a subset of FIX_CONSTANT_EXP_AT_TRANS.
 */
  #undef FIX_1_OVER_3_EXP_AT_TRANS

/*
 * !-0.f should be 1, not 0 by ISO/ANSI C.
 */
  #undef FIX_BANG_MINUS_ZERO

/*
 * !1.f should be 0, not 1 by ISO/ANSI C.
 */
  #undef FIX_BANG_ONE

/*
 * The trinary operation: i = 0.0 ? 1.0 : 0.0 ; should be 0 by ISO/ANSI C.
 */
  #undef FIX_TRI_OP_OF_FLOATS

/*
 * 'for' loop with downward decrement of FP var [for(r=0.0;min<r;r--) ] done wrong.
 */
  #undef FIX_DOWNWARD_FOR_LOOP

/*
 * Code generation for 'ldbl -= ulp;' done wrong.  So use ldbl = ldbl - ulp;
 * (Only a few uses of this bypass have been done).
 * Same problem applies to other similar operators: +=, *=, and /=.
 */
  #undef FIX_FP_MINUS_EQ_FP
  #undef FIX_FP10_MINUS_EQ_FP10
  #undef FIX_INT_MINUS_EQ_FP
  #undef FIX_INT_MINUS_EQ_FPCONST
  #undef FIX_LDBL_MINUS_EQ_FP
  #undef FIX_LDBL_MINUS_EQ_INT
  #undef FIX_ULLI_MINUS_EQ_FP
  #undef FIX_SLLI_MINUS_EQ_FP
  #undef FIX_UB_MINUS_EQ_FP
  #undef FIX_SB_MINUS_EQ_FP
  #undef FIX_ENUM_MINUSEQ_ENUM

  #undef FIX_FP_PLUS_EQ_FP
  #undef FIX_FP_PLUS_EQ_INT
  #undef FIX_INT_PLUS_EQ_FP
  #undef FIX_ULLI_PLUS_EQ_FP
  #undef FIX_SLLI_PLUS_EQ_FP
  #undef FIX_UB_PLUS_EQ_FP
  #undef FIX_SB_PLUS_EQ_FP
  #undef FIX_PLUS_EQ_FP_FUNC		/* fp += fp_fn() */
  #undef FIX_FP_PTR_PLUS_EQ_BOOL	/* *fp += b */

  #undef FIX_INT_STAR_EQ_FP
  #undef FIX_ULLI_STAR_EQ_FP
  #undef FIX_SLLI_STAR_EQ_FP
  #undef FIX_UB_STAR_EQ_FP
  #undef FIX_SB_STAR_EQ_FP

  #undef FIX_INT_DIV_EQ_FP
  #undef FIX_ULLI_DIV_EQ_FP
  #undef FIX_SLLI_DIV_EQ_FP
  #undef FIX_UB_DIV_EQ_FP
  #undef FIX_SB_DIV_EQ_FP

/*
 * Code generation for 'ldbl--;' done wrong.  So use ldbl = ldbl - one;
 * (Only a few uses of this bypass have been done).
 */
  #undef FIX_FP_MINUS_MINUS
  #undef FIX_FP10_MINUS_MINUS

/*
 * Code generation for 'd=ldbl++;' done wrong.  So use two stmts.
 * (Only bypass in t0160100 has been done).
 */
  #undef FIX_FP_PLUS_PLUS

/*
 * Code generation for promotion of integer types with rank less than int
 * are done wrong.  Such as, signed int < unsigned short int.
 */
  #undef FIX_BAD_INTEGER_PROMOTION

/*
 * sizeof float constant is double (should be float by ISO/ANSI C)
 * sizeof float expression is double (should be float by ISO/ANSI C)
 * (This can impact all the classification macros).
 * Was FIX_SIZEOF_FLOAT_CONST_IS_DBL -- confused a compiler.
 */
  #undef FIX_SIZEOF_FLT_CONST_IS_DBL
  #undef FIX_SIZEOF_F10_CONST_IS_D10

/*
 * Conversion/promotion/cast/assignment from one type (y) to another
 * type (x) should be supported, e.g., x=y, or (x)y.  It either kills
 * compile if not supported, or produces the wrong result at run time.
 * x, y may be one of: LDBL, DBL, FLT, [U|S]LLI, [U|S]LI, [U|S]I, [U|S]SI,
 * [U|S|P]C, ENUM, [U|S]B{its}.  Use FP if all of LDBL/DBL/FLT apply.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_FP_FROM_ULLI
  #undef FIX_FP10_FROM_ULLI
  #undef FIX_DBL_FROM_ULLI
  #undef FIX_D10_FROM_ULLI
  #undef FIX_FLT_FROM_ULLI
  #undef FIX_F10_FROM_ULLI
  #undef FIX_LDBL_FROM_ULLI
  #undef FIX_LD10_FROM_ULLI
  #undef FIX_FP_FROM_SLLI
  #undef FIX_LDBL_FROM_LONG
  #undef FIX_LD10_FROM_LONG
  #undef FIX_ULLI_FROM_FLT
  #undef FIX_ULLI_FROM_FP
  #undef FIX_ULLI_FROM_LARGE_FP_CONST
  #undef FIX_SLLI_FROM_FP
  #undef FIX_ULI_FROM_FLT
  #undef FIX_ULI_FROM_FP
  #undef FIX_ULI_FROM_LARGE_FP_CONST
  #undef FIX_SLI_FROM_FP
  #undef FIX_UI_FROM_FP
  #undef FIX_SI_FROM_FP
  #undef FIX_USI_FROM_FP
  #undef FIX_SSI_FROM_FP
  #undef FIX_UC_FROM_FP
  #undef FIX_SC_FROM_FP
  #undef FIX_PC_FROM_FP
  #undef FIX_INT_FROM_BITFIELD
  #undef FIX_ENUM_FROM_BITFIELD
  #undef FIX_ENUM_FROM_INT_TYPE
  #undef FIX_ENUM_FROM_FP
  #undef FIX_ENUM_FROM_FP10
  #undef FIX_ENUM_FROM_CMPLX
  #undef FIX_ENUM_FROM_CMPLX10
  #undef FIX_UB_FROM_FP
  #undef FIX_SB_FROM_FP

/*
 * Code generation for res == ( vl += vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_PLUSEQUAL

/*
 * Code generation for res == ( vl -= vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_MINUSEQUAL

/*
 * Code generation for res == ( vl *= vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_STAREQUAL

/*
 * Code generation for res == ( vl /= vr) done wrong, where vl is of
 * type floating-point.
 */
  #undef FIX_EQUALEQUAL_FP_DIVEQUAL

/*
 * Code generation for vl += vr done wrong, where vl is of
 * type bit-field.
 */
  #undef FIX_BITFIELD_PLUS_EQUAL

/*
 * Some valid ISO/ANSI C code causes runtime problems and is not covered
 * by any other disallow.
 */
  #undef FIX_BUGGY_CODE

/*
 * Adding extra code allows some test cases to run.  Without the dummy code,
 * it should run as per ISO/ANSI C.  This may indicate a compiler bug, or a
 * test case bug: bad pointer, bad array index.
 */
  #undef FIX_T0330000

/*
 * Adding extra code allows some test cases to run.  Without the dummy code,
 * it should run as per ISO/ANSI C.  This may indicate a compiler bug, or a
 * test case bug: bad pointer, bad array index.
 */
  #undef NEED_DUMMY_CODE

/*
 * Assignments must do the store as per ISO/ANSI C.  But, in some cases,
 * making the variable volatile is needed to force that store.
 */
  #undef NEED_VOLATILE

/*
 * Assignments must do the store as per ISO/ANSI C.  But, in some cases,
 * need to call a function with the address of the var to force that store.
 */
  #undef NEED_FORCE_STORE

/*
 * Assignments must do a load and store instead of a move.  This is needed
 * if the rounding direction has been changed.
 */
  #undef FIX_LOAD_STORE

/*
 * Complicated expressions that cause spilling of intermediate values
 * must preserve the full precision of the value spilled.
 * If t0130000 detects varying precision for FLT ops, define this symbol.
 * If t6130000 detects varying precision for F10 ops, define this symbol.
 */
  #undef FIX_SPILL_FLT
  #undef FIX_SPILL_F10

/*
 * Assignments must store to memory to perform their specified
 * conversions, eg, cannot use the wider value in the register.  This
 * is an ISO/ANSI C requirement.
 */
  #undef FIX_USE_REG_VAL

/*
 * Casts must store to memory to perform their specified conversions,
 * eg, cannot use the wider value in the register.  This is an
 * ISO/ANSI C requirement.
 */
  #undef FIX_IGNORE_CAST

/*
 * FP constants cast to lower precision should do the cast at run-time
 * (and raise inexact), not translation time (which bypasses inexact).
 */
  #undef FIX_CAST_AT_TRANS

/*
 * FP constants cast to int should get the correct value.
 */
  #undef FIX_CAST_2_INT_OF_FP_CONST

/*
 * Some casts work, some fail.  This bypasses the known failures.
 * Needed for gcc 333, 412 in t0310200.
 */
  #undef FIX_UNKNOWN_CAST

/*
 * LDBL arrays should be done right.  In one case, the array was stored
 * and initialized correctly, but the runtime array references were done
 * as if it were double in size instead of long double.
 */
  #undef FIX_LDBL_ARRAY
  #undef FIX_LD10_ARRAY

/*
 * <float.h> might be shared between several compilers, some of which have
 * LDBL == DBL, and others have LDBL > DBL.  <float.h> should be updated to
 * take into account which compiler is using it, but until that happens, this
 * allows test of <float.h> to be bypassed.
 */
  #undef FIX_LDBL_OK_IN_FLOAT_H
  #undef FIX_LD10_OK_IN_FLOAT_H

/*** Run time: C89/C90/C95: input/output library function problems ***/

/*
 * Unit in Last Place error allowed between expected and actual strings
 * produced by printf of %f formats of (long) double values.  The first
 * letter indicates the type of value being printed, the letter before
 * ULPS indicates the format being used (e, f, g, or a).
 */
  #undef  F_BIN2DEC_E_ULPS
  #undef  D_BIN2DEC_E_ULPS
  #undef LD_BIN2DEC_E_ULPS
  #undef  D_BIN2DEC_F_ULPS
  #undef LD_BIN2DEC_F_ULPS
  #undef  D_BIN2DEC_G_ULPS
  #undef LD_BIN2DEC_G_ULPS
  #undef  D_BIN2HEX_A_ULPS
  #undef LD_BIN2HEX_A_ULPS

/*
 * [s]scanf should work with double.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCANF_D10

/*
 * [s]scanf should work with long double.  At least one compiler treats
 * long double the same as double to sscanf, yet long double and double
 * are different hardware representations.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCANF_LDBL
  #undef FIX_WSCANF_LDBL
  #undef FIX_SCANF_LD10
  #undef FIX_WSCANF_LD10

/*
 * [s]scanf should work with float.  At least one compiler core dumps
 * in t3040000 with "unusual" input scanned into a float.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCANF_FLT
  #undef FIX_WSCANF_FLT
  #undef FIX_SCANF_F10
  #undef FIX_WSCANF_F10

/*
 * [s]scanf should return the correct count via its return code.
 * If the count is wrong, define these.  t304* tests.
 */
  #undef FIX_SCAN_RC
  #undef FIX_WSCAN_RC

/*
 * [s]scanf should work with long double and do good decimal to binary
 * conversions.  If it is sloppy, define these symbols with the number
 * of bits/digits to round and drop from the values in memory as an
 * attempt to make the numbers 'nice'.
 * Used by t1xx*3 tests, most useful for t1522003 (pow).
 */
  #undef FIX_BOTTOM_N_BITS
  #undef FIX_BOTTOM_N_DIGS

/*
 * This bypasses all printf tests with specific combinations of flags.
 * See g3070000.h for usage.  There are 32 possible defines for each %e/f/g,
 * of which only the first and last are shown here.
 */
  #undef FIX_T3070000	/* %f */
/* ... */
  #undef FIX_T3070031
  #undef FIX_T3070100	/* %e */
/* ... */
  #undef FIX_T3070131
  #undef FIX_T3070200	/* %g */
/* ... */
  #undef FIX_T3070231

/*
 * This bypasses some printf tests with specific combinations of flags.
 * See g3070000.h for usage.  There are 32 possible defines for each %e/f/g,
 * of which only the first and last are shown here.
 */
  #undef FIX_T3070000_CASES	/* %f */
/* ... */
  #undef FIX_T3070031_CASES
  #undef FIX_T3070100_CASES	/* %e */
/* ... */
  #undef FIX_T3070131_CASES
  #undef FIX_T3070200_CASES	/* %g */
/* ... */
  #undef FIX_T3070231_CASES

/*
 * %g done with wrong precision.
 * This bypasses tests with no explicit precision.
 */
  #undef FIX_PRINTF_NO_PRECISION
  #undef FIX_WPRINTF_NO_PRECISION

/*
 * %.f done as %.6f instead of %.0f
 * This bypasses tests with an implicit zero precision.
 */
  #undef FIX_PRINTF_IMPLICIT_PRECISION
  #undef FIX_WPRINTF_IMPLICIT_PRECISION

/*
 * %.0g done wrong.  300.0 done as 3 instead of expected 3e+02
 * This bypasses tests with an explicit zero precision.
 */
  #undef FIX_PRINTF_ZERO_PRECISION
  #undef FIX_WPRINTF_ZERO_PRECISION

/*
 * %.1g done wrong.  3e-2 done as 0.030 instead of expected 0.03
 * This bypasses tests with an explicit one precision.
 */
  #undef FIX_PRINTF_ONE_PRECISION
  #undef FIX_WPRINTF_ONE_PRECISION

/*
 * %#g causes unusual results (such as extra zeros at end of number).
 * This bypasses tests with a "#" format flag.
 */
  #undef FIX_PRINTF_SHARP_FLAG
  #undef FIX_WPRINTF_SHARP_FLAG

/*
 * %#g causes wrong rounding at midpoint tests.
 * This bypasses tests with a "#" format flag and value is x.5.
 */
  #undef FIX_PRINTF_SHARP_RND
  #undef FIX_WPRINTF_SHARP_RND

/*
 * %e and %a causes wrong rounding at midpoint tests.
 * This bypasses tests with a "%e" format flag and value is x.5.
 * This bypasses tests with a "%a" format flag and value is x.5.
 */
  #undef FIX_PRINTF_e_RND
  #undef FIX_PRINTF_aA_RND	/* %a => 0xM.Np+d */
  #undef FIX_WPRINTF_aA_RND	/* %a => 0xM.Np+d */

/*
 * %0f causes unusual results.
 * This bypasses tests with a "0" format flag.
 */
  #undef FIX_PRINTF_ZERO_FLAG
  #undef FIX_WPRINTF_ZERO_FLAG

/*
 * % f causes unusual results.
 * This bypasses tests with a " " format flag.
 */
  #undef FIX_PRINTF_SPACE_FLAG
  #undef FIX_WPRINTF_SPACE_FLAG

/*
 * % 0f causes unusual results (such as putting " " in middle of zeros).
 * This bypasses tests with both " " and "0" format flags.
 */
  #undef FIX_PRINTF_SPACE_ZERO_FLAGS
  #undef FIX_WPRINTF_SPACE_ZERO_FLAGS

/*
 * %#.0f causes unusual results when the expected result is just zeros.
 * This bypasses tests with expected result of all zeros.
 */
  #undef FIX_PRINTF_ZERO_RES
  #undef FIX_WPRINTF_ZERO_RES

/*
 * %.6f of value -1e-7 should be -0.000000 (but many drop the minus sign).
 * This bypasses tests with expected negative result of all zeros.
 */
  #undef FIX_PRINTF_NEGATIVE_ZERO
  #undef FIX_WPRINTF_NEGATIVE_ZERO

/*
 * Negative values being printed cause many varied results depending
 * upon the flags.  This bypasses tests with negative values.
 */
  #undef FIX_PRINTF_NEGATIVE
  #undef FIX_WPRINTF_NEGATIVE

/*
 * %e and some %g have an exponent of the wrong form, so bypass them.
 * Most common cause is minimum exponent is 3 digits (should be 2 digits).
 */
  #undef FIX_PRINTF_HAS_EXPONENT
  #undef FIX_WPRINTF_HAS_EXPONENT

/*
 * [s]printf should return the correct value (of number of characters output).
 * This ignores cases where return value is wrong.
 */
  #undef FIX_PRINTF_RC
  #undef FIX_WPRINTF_RC

/*
 * [s]printf should return the correct value (of number of characters output).
 * This ignores cases where return value is negative.
 */
  #undef FIX_PRINTF_NEGATIVE_RC
  #undef FIX_WPRINTF_NEGATIVE_RC

/*
 * [w]printf is required to print at least 4095 (was 509 with C89)
 * characters in any single conversion.  This bypasses the tests of
 * IMPL_MAX_*_RADIX.
 */
  #undef FIX_SMALL_PRINTF_ENV_LIMIT
  #undef FIX_SMALL_WPRINTF_ENV_LIMIT

/*
 * Return from main() does an implicit flush of all I/O streams.
 * If you need an explicit flush just before the end of main,
 * then you need to define this symbol.  Affects SetSuccess found
 * in leaf.h
 */
  #undef FIX_IMPLICIT_FLUSH

/*
 * Translation time constant value should be same as run-time conversion.
 */
  #undef FIX_TRANS_EQ_RUN_TIME
  #undef FIX_TRANS10_EQ_RUN_TIME10

/*
 * strtof/strtod/strtold should equal scanf of decimal numbers to binary
 * [wcstof/wcstod/wcstold should equal wscanf of decimal numbers to binary]
 * of float/double/long double.
 * Symbols w/ '10' are for Decimal FP.
 */
  #undef FIX_strto_EQ_scanf
  #undef FIX_wcsto_EQ_wscanf
  #undef FIX_strto10_EQ_scanf10
  #undef FIX_wcsto10_EQ_wscanf10

/*
 * Does *scanf correctly support %n?
 */
  #undef FIX_SCAN_PERCENT_n
  #undef FIX_WSCAN_PERCENT_n

/*
 * Does *scanf correctly support one character lookahead?
 */
  #undef FIX_SCAN_LOOKAHEAD
  #undef FIX_WSCAN_LOOKAHEAD

/*
 * Is EOF of type int?  At least one compiler has it as long.
 */
  #undef  FIX_NON_INT_EOF

/*
 * Does *scanf incorrectly support one character lookahead
 * at End Of File (EOF)?  That is, "100e0" is treated as EOF.
 */
  #undef FIX_SCAN_EOF
  #undef FIX_WSCAN_EOF

/*
 * Does *scanf incorrectly report EOF after matching some text?
 * That is, " }\nEOF" is EOF to "%*[^{]" in g1xx0003.h
 */
  #undef FIX_SCAN_EARLY_EOF
  #undef FIX_WSCAN_EARLY_EOF

/*
 * Does *scanf incorrectly report EOF after matching some text?
 * That is, " }\nEOF" is not EOF to "%*[^{]{" in g1xx0003.h
 */
  #undef FIX_SCAN_LATE_EOF
  #undef FIX_WSCAN_LATE_EOF

/*
 * Do strto* / wcsto* correctly support unlimited character lookahead?
 */
  #undef FIX_STRTO_LOOKAHEAD
  #undef FIX_WCSTO_LOOKAHEAD

/*
 * Do scanf and strto* process FP numbers that start with junk?
 * For example, &5e0, \a0xf.3p0
 */
  #undef FIX_SCAN_JUNK
  #undef FIX_WSCAN_JUNK

/*
 * Do scanf and strto* process FP numbers that have no digits?
 * For example, .e0, 0x.p0
 */
  #undef FIX_SCAN_NODIGITS
  #undef FIX_WSCAN_NODIGITS

/*
 * Do scanf and strto* reject FP numbers that have no '.' with 'e'?
 * For example, 100e0
 */
  #undef FIX_SCAN_NODOT_E
  #undef FIX_WSCAN_NODOT_E

/*
 * Does scanf return wrong count for valid FP number followed by
 * just white space?  For example, 100\t
 */
  #undef FIX_SCAN_FP_WS
  #undef FIX_WSCAN_FP_WS

/*
 * Do scanf and strto* correctly process FP numbers with too many signs?
 * For example, -+5e0, +-0xf.3p0
 */
  #undef FIX_BAD_SIGNS

/*
 * Do scanf and strto* correctly process FP numbers with too many '.'?
 * For example, 5..0, 5.0.2e0
 */
  #undef FIX_EXTRA_DOTS

/*
 * Do scanf and strto* correctly process FP numbers with bad exponents?
 * For example, 5ex, 5e-x, 5e+x.
 */
  #undef FIX_BAD_EXPONENT

/*
 * Do scanf and strto* correctly process decimal FP numbers with binary exponents?
 * For example, 5p0, 5.0pe3
 */
  #undef FIX_DEC_WITH_BIN_EXPONENT

/*
 * Do scanf and strto* correctly process FP numbers with bad bin exponents?
 * For example, 0x5px, 0x5p-x, 0x5p+x.
 */
  #undef FIX_BAD_BIN_EXPONENT

/*
 * Do scanf and strto* correctly process FP numbers with no bin exponents?
 * For example, 0x5, 0x5.0, 0x.5.
 */
  #undef FIX_NO_BIN_EXPONENT

/*
 * strto* / wcsto* sets pointer to start of string (pointer difference
 * is zero), when expected a positive difference.
 * Symbols with '10' in them are for Decimal FP.
 */
  #undef FIX_STRTO_ZERO_PTR_DIFF
  #undef FIX_WCSTO_ZERO_PTR_DIFF
  #undef FIX_STRTO10_ZERO_PTR_DIFF
  #undef FIX_WCSTO10_ZERO_PTR_DIFF

/*
 * Conversion from "decimal" to internal FP should set pointer
 * for strtof, strtod, strtold, and wcstof, wcstod, wcstold,
 * so pointer difference (from start of string) is correct.
 */
  #undef FIX_STRTO_BAD_PTR_DIFF
  #undef FIX_WCSTO_BAD_PTR_DIFF

/*
 * scanf of decimal numbers to binary of float/double/long double should
 * honor the current rounding direction.  This also applies to the
 * strtod, strtof, and strtold functions.
 */
  #undef FIX_scanf_ROUNDS
  #undef FIX_wscanf_ROUNDS

/*
 * strtod/f/ld and scanf, when they convert negative numbers and the
 * current rounding direction is +INF or -INF, then it matters which
 * comes first:  rounding or negating.  IEEE-754 requires that the
 * negating come first and that rounding be last.
 */
  #undef FIX_strto_RND_THEN_NEG
  #undef FIX_wcsto_RND_THEN_NEG

/*
 * printf of binary to decimal numbers should
 * honor the current rounding direction.
 */
  #undef FIX_printf_ROUNDS
  #undef FIX_wprintf_ROUNDS

/*
 * File I/O has problems, so bypass tests of fprintf, fscanf.
 */
  #undef FIX_TEST_fprintf
  #undef FIX_TEST_fscanf
  #undef FIX_TEST_fwprintf
  #undef FIX_TEST_fwscanf
  #undef FIX_TEST_sprintf
  #undef FIX_TEST_swprintf

/*
 * Binary file I/O requires new-line at end of file (as if it were
 * a text file).
 */
  #undef FIX_NEED_FINAL_NEW_LINE

/*
 * File position indicator is wrong after fscanf. so skip tests of ftell.
 */
  #undef FIX_TEST_ftell

/*
 * Conversion from internal FP to decimal of finite numbers should produce
 * just digits, radix point, signs, and 'e' or 'E'.  One compiler does:
 * 405c813f3978f8940984 => +?.?<0000000000000000000e+27
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_JUNK
  #undef FIX_WPRINT_JUNK
  #undef FIX_PRINT10_JUNK
  #undef FIX_WPRINT10_JUNK

/*
 * Conversion from internal FP to decimal and back should be identity function.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_SCAN_IDENT
  #undef FIX_WPRINT_WSCAN_IDENT
  #undef FIX_PRINT10_SCAN10_IDENT
  #undef FIX_WPRINT10_WSCAN10_IDENT

/*
 * Conversion from internal FP to decimal and back should be identity function
 * for small numbers (close to denormal).
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_SCAN_IDENT_TINY
  #undef FIX_WPRINT_WSCAN_IDENT_TINY
  #undef FIX_PRINT10_SCAN10_IDENT_TINY
  #undef FIX_WPRINT10_WSCAN10_IDENT_TINY

/*** Run time: C89/C90/C95: math library function problems ***/

/*
 * One of frexp or ldexp is wrong w/ denorms or other values, so the
 * ulp* functions in s0000000.fjt need a workaround.
 */
  #undef ULP_WORKAROUND
  #undef ULP10_WORKAROUND

/*
 * Is the compiler's decimal to binary conversion so bad that it
 * interferes with the testing of the math library?  That is, are
 * the decimal values used as the arguments and/or expected results
 * in the test vectors converted so poorly that there are bogus errors?
 * Do you have some functions that can correctly convert a decimal value
 * as a string into the internal floating-point format?  If yes to all
 * of the above, then you can define symbols like:
 *   #define t1102001 "v1102001.ovr"
 * to cause that file to be included in g1100000.h (via OVERRIDE_TV) so
 * that you can invoke your function to do the correct decimal to binary
 * conversion and then assign that value to the appropriate test vector
 * element. If you need this, contact Fred Tydeman for the override files
 * (you get to provide the decimal to binary conversion function).
 */
  #undef t1100000
  #undef t1100001
  #undef t1100003
  #undef t1101000
  #undef t1101001
  #undef t1101003
  #undef t1102000
  #undef t1102001
  #undef t1102003
/* ... thru ... */
  #undef t1980000
  #undef t1980001
  #undef t1981000
  #undef t1981001
  #undef t1982000
  #undef t1982001

/*
 * If the error is so large that it ends up being infinity.
 */
  #undef FIX_INF_ULP_pow

/*
 * If the error is so large that it ends up being NaN.
 */
  #undef FIX_NAN_ULP_cosh
  #undef FIX_NAN_ULP10_cosh

/*
 * The point at which argument reduction by 2 PI fails and the error
 * becomes much larger than for small arguments. It is assumed that for
 * fabs( argument ) < LARGE_ARG_*, the error in the trig function is
 * small, eg, 5 ulp, and is less than ULP_*.  But, once the argument
 * exceeds LARGE_ARG_*, the error becomes very large, eg, 5.0e35.
 * This number should be at least FLT_RADIX ** (*_MANT_DIG/2).
 * Since it may depend the number of digits for each floating-point type,
 * we need this for each type of trig function.
 * It could be given a value in the *.bug files if it is smaller than the
 * default value in myfloat.h.
 */
  #undef LARGE_ARG_cos
  #undef LARGE_ARG_cosf
  #undef LARGE_ARG_cosl
  #undef LARGE_ARG_sin
  #undef LARGE_ARG_sinf
  #undef LARGE_ARG_sinl
  #undef LARGE_ARG_tan
  #undef LARGE_ARG_tanf
  #undef LARGE_ARG_tanl

/*
 * Function is supposed to be even or odd, but symmetry is not done to last bit.
 * With these defined, use the above ULP_* to see if close enough.
 */
  #undef FIX_EVENODD_asin
/* ... thru ... */
  #undef FIX_EVENODD_trunc
  #undef FIX_EVENODD10_asin
/* ... thru ... */
  #undef FIX_EVENODD10_trunc

/*
 * Library functions not raise flags as expected; either too few or too many.
 */
  #undef FIX_FLAG_acos
/* ... thru ... */
  #undef FIX_FLAG_trunc
  #undef FIX_FLAG10_acos
/* ... thru ... */
  #undef FIX_FLAG10_trunc

/*
 * Library functions not raise same flags when test even/odd property,
 * eg, hypot(x,y) vs hypot(y,x)
 */
  #undef FIX_FLAG_hypot_EVENODD

/*
 * Library functions clear some flags
 */
  #undef FIX_CLR_FLAGS_acos
/* ... thru ... */
  #undef FIX_CLR_FLAGS_trunc
  #undef FIX_CLR_FLAGS10_acos
/* ... thru ... */
  #undef FIX_CLR_FLAGS10_trunc

/*
 * Library functions result depends upon flags
 */
  #undef FIX_DEPENDS_FLAGS_acos
/* ... thru ... */
  #undef FIX_DEPENDS_FLAGS_trunc
  #undef FIX_DEPENDS_FLAGS10_acos
/* ... thru ... */
  #undef FIX_DEPENDS_FLAGS10_trunc

/*
 * Library functions do inexact flag wrong; either not raise when should, or
 * raise when should not.
 */
  #undef FIX_INEXACT_acos
/* ... thru ... */
  #undef FIX_INEXACT_trunc
  #undef FIX_INEXACT10_acos
/* ... thru ... */
  #undef FIX_INEXACT10_trunc

/*
 * Library functions of NaN argument should not raise Invalid.
 * Some bad libraries do raise Invalid for a NaN argument.
 */
  #undef FIX_F_OF_NAN_IS_QUIET

/*
 * Library functions of two NaN arguments should return one of them.
 * Some bad libraries return a fixed (constant) NaN independent of NaN argument.
 * Either check for either NaN (w/o signs), either NaN (w/ signs) or some NaN.
 */
  #undef FIX_SAME_2NAN	/* if defined => some NaN */
  #undef IMPL_SAME_2NAN	/* if defined => ignore signs */

/*
 * Library functions of NaN argument should return the same NaN (as
 * per Annex F.9, paragraph 13 in Recommended practice; Change in sign
 * of NaN is OK as same paragraph.)
 * Some bad libraries return a fixed (constant) NaN independent of NaN argument.
 * Either check for same identical NaN, or same NaN (w/o signs) or some NaN.
 */
  #undef FIX_SAME_NAN	/* if defined => some NaN */
  #undef IMPL_SAME_NAN	/* if defined => ignore signs */

/*
 * Some library functions of denorm argument should be same denorm.
 * Some bad libraries return either zero or different denorm.
 * Either check for same denorm or ULP_f error.
 */
  #undef FIX_SAME_DEN

/*
 * Some library functions of -0.0 argument should be -0.0.
 * Some bad libraries return +0.0.
 * Either check for same zero or some zero.
 */
  #undef FIX_SAME_ZERO

/*
 * Some hardware (such as IBM S/360) treat signed zero as positive zero.
 * That is, -0.0 * +1.0 is +0.0 instead of -0.0; yet -(x-x) is -0.0
 * This matters the most to copysign().
 */
  #undef FIX_TRUE_SIGNED_ZERO

/*
 * Library functions of NaN argument should be a NaN (in most cases).
 * With this defined, all library functions will bypass testing with NaNs.
 */
  #undef FIX_F_OF_NAN_IS_NAN

/*
 * NaN argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_NAN_acos
/* ... thru ... */
  #undef FIX_NAN_trunc
  #undef FIX_NAN10_acos
/* ... thru ... */
  #undef FIX_NAN10_trunc

/*
 * Zero argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_ZERO_acos
/* ... thru ... */
  #undef FIX_ZERO_trunc
  #undef FIX_ZERO10_acos
/* ... thru ... */
  #undef FIX_ZERO10_trunc

/*
 * Denormal argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_DEN_acos
/* ... thru ... */
  #undef FIX_DEN_trunc
  #undef FIX_DEN10_acos
/* ... thru ... */
  #undef FIX_DEN10_trunc

/*
 * "Small" arguments cause too many errors, so bypass testing with them.
 */
  #undef FIX_SMALL_acos
/* ... thru ... */
  #undef FIX_SMALL_trunc
  #undef FIX_SMALL10_acos
/* ... thru ... */
  #undef FIX_SMALL10_trunc

/*
 * "Large" arguments cause too many errors, so bypass testing with them.
 */
  #undef FIX_LARGE_acos
/* ... thru ... */
  #undef FIX_LARGE_trunc
  #undef FIX_LARGE10_acos
/* ... thru ... */
  #undef FIX_LARGE10_trunc

/*
 * Infinity argument(s) cause too many errors, so bypass testing with them.
 */
  #undef FIX_INF_acos
/* ... thru ... */
  #undef FIX_INF_trunc
  #undef FIX_INF10_acos
/* ... thru ... */
  #undef FIX_INF10_trunc

/*
 * C89 allowed fmod(x,0.0) to be either domain error or zero.  FPCE now
 * requires it be domain error.  This allows FPCE domain errors to be treated
 * as zero result so will pass test.  If others are found with this
 * implementation-defined behavior, they will be added to the list.
 */
  #undef FIX_DOMAIN_fmod

/*
 * Some argument(s) should be NaN result, so bypass testing with them.
 * Random invalid arguments cause random results (should be NaN with invalid).
 * So, do not test with arguments that are domain errors.
 * One function even randomly altered the stack pointer which caused strange
 * behavior.
 */
  #undef FIX_NAN_RES_acos
/* ... thru ... */
  #undef FIX_NAN_RES_trunc
  #undef FIX_NAN_RES10_acos
/* ... thru ... */
  #undef FIX_NAN_RES10_trunc

/*
 * Some argument(s) should be signed zero result, so test with any zero result.
 */
  #undef FIX_SIGNED_ZERO_RES_acos
/* ... thru ... */
  #undef FIX_SIGNED_ZERO_RES_trunc

/*
 * Some argument(s) should be zero result, so bypass testing with them.
 */
  #undef FIX_ZERO_RES_acos
/* ... thru ... */
  #undef FIX_ZERO_RES_trunc
  #undef FIX_ZERO_RES10_acos
/* ... thru ... */
  #undef FIX_ZERO_RES10_trunc

/*
 * Some argument(s) should be denormal result, so bypass testing with them.
 */
  #undef FIX_DEN_RES_acos
/* ... thru ... */
  #undef FIX_DEN_RES_trunc
  #undef FIX_DEN_RES10_acos
/* ... thru ... */
  #undef FIX_DEN_RES10_trunc

/*
 * Some argument(s) should be "small" result, so bypass testing with them.
 */
  #undef FIX_SMALL_RES_acos
/* ... thru ... */
  #undef FIX_SMALL_RES_trunc
  #undef FIX_SMALL_RES10_acos
/* ... thru ... */
  #undef FIX_SMALL_RES10_trunc

/*
 * Some argument(s) should be "large" result, so bypass testing with them.
 */
  #undef FIX_LARGE_RES_acos
/* ... thru ... */
  #undef FIX_LARGE_RES_trunc
  #undef FIX_LARGE_RES10_acos
/* ... thru ... */
  #undef FIX_LARGE_RES10_trunc

/*
 * Some argument(s) should be infinity result, so bypass testing with them.
 */
  #undef FIX_INF_RES_acos
/* ... thru ... */
  #undef FIX_INF_RES_trunc
  #undef FIX_INF_RES10_acos
/* ... thru ... */
  #undef FIX_INF_RES10_trunc

/*
 * Some argument(s) should NOT be NaN result, so bypass testing with
 * them.  That is, bypass tests where the actual result got is a
 * NaN. So far, only added this bypass to these functions.  Can be
 * added to others if needed.
 */
  #undef FIX_NAN_GOT_acosh
  #undef FIX_NAN_GOT_asinh
  #undef FIX_NAN_GOT_atan
  #undef FIX_NAN_GOT_atan2
  #undef FIX_NAN_GOT_cos
  #undef FIX_NAN_GOT_fma
  #undef FIX_NAN_GOT_sin
  #undef FIX_NAN_GOT_tan
  #undef FIX_NAN_GOT10_acosh
  #undef FIX_NAN_GOT10_asinh
  #undef FIX_NAN_GOT10_atan
  #undef FIX_NAN_GOT10_atan2
  #undef FIX_NAN_GOT10_cos
  #undef FIX_NAN_GOT10_fma
  #undef FIX_NAN_GOT10_sin
  #undef FIX_NAN_GOT10_tan

/*
 * Some argument(s) result in the function returning the argument as
 * its result, so bypass testing with them.  That is, bypass tests
 * where the actual result got is the argument. So far, only added
 * this bypass to 2 trig functions.  Can be added to others if needed.
 */
  #undef FIX_ARG_GOT10_cos
  #undef FIX_ARG_GOT10_sin
  #undef FIX_ARG_GOT_cos
  #undef FIX_ARG_GOT_sin

/*
 * Some argument(s) should NOT be zero result, so bypass testing with them.
 * This was needed to bypass testing func(x) is zero and func(-x) is not zero.
 * That is, bypass tests where the actual result got is a zero. So far, only
 * added this bypass to 3 trig functions.  Can be added to others if needed.
 */
  #undef FIX_ZERO_GOT_cos
  #undef FIX_ZERO_GOT_sin
  #undef FIX_ZERO_GOT_tan

/*
 * Some argument(s) should NOT be inf result, so bypass testing with them.
 * This was needed to bypass testing func(x) is inf and func(-x) is not inf.
 * This was needed to bypass testing func(x) is inf, but expected is finite.
 * That is, bypass tests where the actual result got is an inf.
 */
  #undef FIX_INF_GOT10_asinh
  #undef FIX_INF_GOT10_atan
  #undef FIX_INF_GOT10_atan2
  #undef FIX_INF_GOT10_atanh
  #undef FIX_INF_GOT10_fma
  #undef FIX_INF_GOT10_hypot
  #undef FIX_INF_GOT10_lgamma
  #undef FIX_INF_GOT10_pow
  #undef FIX_INF_GOT10_tan
  #undef FIX_INF_GOT10_tgamma
  #undef FIX_INF_GOT_asinh
  #undef FIX_INF_GOT_atan
  #undef FIX_INF_GOT_atan2
  #undef FIX_INF_GOT_atanh
  #undef FIX_INF_GOT_fma
  #undef FIX_INF_GOT_hypot
  #undef FIX_INF_GOT_lgamma
  #undef FIX_INF_GOT_pow
  #undef FIX_INF_GOT_tan
  #undef FIX_INF_GOT_tgamma

/*
 * Some argument(s) should NOT be NaN result, so bypass testing with them.
 * That is, bypass tests where the actual result got is invalid raised.
 */
  #undef FIX_INVALID_GOT_fma
  #undef FIX_INVALID_GOT10_fma

/*
 * Some argument(s) should NOT be inf result, so bypass testing with them.
 * That is, bypass tests where the actual result got is overflow raised.
 */
  #undef FIX_OVERFLOW_GOT_fma
  #undef FIX_OVERFLOW_GOT10_fma

/*
 * Library function's result not in expected range.
 */
  #undef FIX_RANGE_acos
/* ... thru ... */
  #undef FIX_RANGE_trunc
  #undef FIX_RANGE10_acos
/* ... thru ... */
  #undef FIX_RANGE10_trunc

/*
 * Library function's result not exact (so might be out of expected range).
 */
  #undef FIX_BIT4BIT_ceil
  #undef FIX_BIT4BIT_floor
  #undef FIX_BIT4BIT_llrint
  #undef FIX_BIT4BIT_llround
  #undef FIX_BIT4BIT_lrint
  #undef FIX_BIT4BIT_lround
  #undef FIX_BIT4BIT_nearbyint
  #undef FIX_BIT4BIT_rint
  #undef FIX_BIT4BIT_round
  #undef FIX_BIT4BIT_trunc
  #undef FIX_BIT4BIT10_llrint
  #undef FIX_BIT4BIT10_llround
  #undef FIX_BIT4BIT10_lrint
  #undef FIX_BIT4BIT10_lround

/*
 * Does DBL function return LDBL value (wider precision and/or
 * exponent range).  This idea could be applied to all the math
 * functions, but these are the only ones so far to matter.
 */
  #undef FIX_NORMAL_RETURN_hypot
  #undef FIX_NORMAL_RETURN_nextafter
  #undef FIX_NORMAL_RETURN_nextafterd64
  #undef FIX_NORMAL_RETURN_nexttoward
  #undef FIX_NORMAL_RETURN_nexttowardd64

/*
 * Function result has more precision than can portability test.
 * With these defined, limit precision test in result.
 */
  #undef FIX_FULL_remquo

/*
 * Quotient not computed.
 */
  #undef FIX_QUOT_remquo

/*
 * Sign of quotient wrong.
 */
  #undef FIX_QUOT_SIGN_remquo

/*
 * Function result should be independent of rounding direction.
 * Instead, these functions are affected by rounding direction.
 */
  #undef FIX_RND_fmod
  #undef FIX_RND_remainder
  #undef FIX_RND_remquo

/*
 * Function result should be dependent upon current rounding direction.
 * Instead, these functions only do default rounding direction.
 */
  #undef FIX_RND_fma
  #undef FIX_RND_llrint
  #undef FIX_RND_lrint
  #undef FIX_RND_nearbyint
  #undef FIX_RND_rint
  #undef FIX_RND10_fma
  #undef FIX_RND10_llrint
  #undef FIX_RND10_lrint
  #undef FIX_RND10_nearbyint
  #undef FIX_RND10_rint

/*
 * Rounding of midpoint (+/-0.5, +/-1.5, +/-2.5, ...) is done wrong
 */
  #undef FIX_ROUND_HALF_round

/*
 * Powers of 2 cause problems
 */
  #undef FIX_POW2_frexp

/*
 * Negative numbers cause problems
 */
  #undef FIX_NEGATIVE_asinh
  #undef FIX_NEGATIVE_pow

/*** Run time: C89/C90/C95: other library function problems ***/

/*
 * Independent of trapping, can a signal(SIGFPE,...) be done?
 */
  #undef FIX_SIGNAL_SIGFPE

/*
 * Assuming a FPU trap gets turned into a signal of SIGFPE by the
 * enabled trap handler, what behavior does the signal handler do?
 * Define this symbol to have the signal handler do an explicit
 * acknowledge of the signal, as well as set behavior back to default.
 */
  #undef FIX_NON_SYS_V_SIGNALS

/*
 * When a signal handler is entered, is the handling reset to SIG_DFL?
 * If not, define this symbol.
 */
  #undef FIX_SIG_DFL

/*
 * Can volatile be combined with sig_atomic_t?
 * If not, define this symbol.
 */
  #undef FIX_VOLATILE_SIG_ATOMIC

/*
 * A signal handler should leave the FPU exception flags alone.
 * Found one that clears inexact.
 */
  #undef FIX_SIGNAL_CLEAR_INEXACT

/*** Run time: C99 ***/
/*** Run time: C99: value of constant problems ***/

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some compilers flush
 * all of them to zero.  ISO/ANSI C requires that representable values
 * be nearest or +/- one representation.  DEN gets flushed to zero.
 * MIN-DEN becomes MIN-zero => MIN.
 * This is TRANSLATION time constant problem.
 */
/*#undef FIX_DEC2BIN_ZERO	// described elsewhere */
/*#undef FIX_DEC2DFP_ZERO	// described elsewhere */
  #undef FIX_FLUSH_HEX_DENORM

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some compilers flush
 * some of them to zero.  ISO/ANSI C requires that representable
 * values be nearest or +/- one representation.  MIN-DEN does not
 * flush DEN, so MIN-DEN becomes denorm and it gets flushed to zero.
 * Also, for float and dbl, if constant expressions are done as ldbl,
 * then intermediate denorms are normals to ldbl (so are not flushed),
 * but final result converted to correct type is denorm and flushed.
 * This is TRANSLATION time expression problem.
 */
  #undef FIX_FLUSH_FINAL_DENORM
  #undef FIX_FLUSH_FINAL_DENORM10

/*
 * Decimal (external) to binary (internal) conversion by compiler of
 * denormal numbers during translation is off by a factor of two too high.
 */
  #undef FIX_DENORM_TWO

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some compilers convert
 * them to PseudoDenormals (an unsupported hardware format).  Some
 * hardware treats PseudoDenormals as values bigger than minimum normal.
 * ISO/ANSI C requires that representable values be supported.
 */
  #undef FIX_PSEUDO_DENORMALS

/*
 * Unnormals are NOT in IEEE-754.  Some compilers convert some decimal
 * constants (near overflow threshold) into them, while other system's
 * scanf convert 1.00...0123 (1+small) into them.  When unnormals are
 * used, they are treated like invalid operands.  On an x86, unnormals
 * are numbers with the explicit leading bit set to zero and exponent
 * is non-zero.
 */
  #undef FIX_UNNORMALS
  #undef FIX_UNNORMALS10

/*
 * Pseudo-Infinity is NOT in IEEE-754.  Some compilers convert some decimal
 * constants (past overflow threshold) into them instead of true infinity.
 * When pseudo-infinity is used, it is treated like invalid operands.
 * On an x86, pseudo-infinities are numbers with the explicit leading bit
 * set to zero, but the exponent is all ones.
 *
 * One compiler only does this error for Minus infinity of type long double.
 * Some versions made -pseudo infinity, others made -NaN.
 */
  #undef FIX_PSEUDO_INFINITY
  #undef FIX_M_PSEUDO_INFINITY

/*
 * Denormals (aka subnormals) are in IEEE-754.  Some hardware flush
 * all of them to zero.  This covers operands and results both being
 * flushed at RUNTIME.  Symbols for binary FP and decimal FP.
 */
  #undef FIX_FLUSH_DENORM
  #undef FIX_FLUSH_DENORM10

/*
 * If a denormal operand to a RUNTIME operation is flushed, need this symbol.
 */
  #undef FIX_FLUSH_DEN_OPERAND

/*
 * If a denormal result from a RUNTIME operation is flushed, need this symbol.
 */
  #undef FIX_FLUSH_DEN_RESULTS
  #undef FIX_FLUSH_DEN10_RESULTS

/*
 * Systems that flush denormals forgot to flush the denormal results from
 * some math functions.
 */
  #undef FIX_NON_FLUSHED_DEN_nextafter
  #undef FIX_NON_FLUSHED_DEN_nexttoward

/*** Run time: C99: code generation problems ***/

/*
 * float overflow is infinity (not NaN nor MAX_type).
 */
  #undef FIX_FLT_OVER_IS_INF
  #undef FIX_F10_OVER_IS_INF

/*
 * -MAX_type is -infinity (should be finite).
 */
  #undef FIX_mMAX_IS_INF

/*
 * -INF_type causes unusual results in compares to gcc 4.4.0
 */
  #undef FIX_mINF_D10
  #undef FIX_mINF_DBL
  #undef FIX_mINF_F10
  #undef FIX_mINF_FLT
  #undef FIX_mINF_LD10
  #undef FIX_mINF_LDBL

/*
 * MAX_type*MAX_type is infinity (not NaN nor MAX_type).
 */
  #undef FIX_MAX_x_MAX_IS_INF

/*
 * MAX_type+MAX_type is infinity (not NaN nor MAX_type).
 * At least one compiler has MAX+MAX be MIN!
 */
  #undef FIX_MAX_p_MAX_IS_INF

/*
 * __STDC_IEC_559__ can't be #undef nor #define.
 */
  #undef FIX_CHANGE_STDC_IEC_559

/*
 * __FPCE__ can't be #undef nor #define.
 */
  #undef FIX_CHANGE_FPCE

/*
 * __FPCE_IEEE__ can't be #undef nor #define.
 */
  #undef FIX_CHANGE_FPCE_IEEE

/*
 * [_Bool] Bit-fields should promote to signed int (value preserving).
 */
  #undef FIX_BAD_BITFIELD_PROMOTION
  #undef FIX_BAD_BOOLBITFIELD_PROMOTION
  #undef FIX_BAD_BOOL32BITFLD_PROMOTION

/*
 * Assignment to _Bool should be quiet (raise no exceptions),
 * even for NaN, infinity, denormal.
 */
  #undef FIX_QUIET_ASSIGN_TO_BOOL

/*
 * _Bool is faked with unsigned int.
 * So, _Bool b = 0.5; does the wrong thing.
 */
  #undef FIX_TRUE_BOOL

/*
 * if(bool_var) kills some compilers
 */
  #undef FIX_BOOL_IN_IF

/*
 * Code generation for res == ( vl += vr) done wrong, where vl is of
 * type bool.
 */
  #undef FIX_EQUALEQUAL_BOOL_PLUSEQUAL

/*
 * Code generation for bool vars in register kills some compilers.
 */
  #undef FIX_REG_VARS

/*
 * Code generation for vl -= vr; done wrong, where vl is of type LDBL
 * and vr is bool.
 */
  #undef FIX_LDBL_SUBEQUAL_BOOL

/*
 * Large (too big) floating-point values converted to unsigned long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_ULLONG_SET_INVALID
  #undef FIX_2BIG2_ULLONGP_SET_INVALID
  #undef FIX_2BIG2_ULLONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SLLONG_SET_INVALID
  #undef FIX_2BIG2_SLLONGP_SET_INVALID
  #undef FIX_2BIG2_SLLONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_ULONG_SET_INVALID
  #undef FIX_2BIG2_ULONGP_SET_INVALID
  #undef FIX_2BIG2_ULONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SLONG_SET_INVALID
  #undef FIX_2BIG2_SLONGP_SET_INVALID
  #undef FIX_2BIG2_SLONGM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UINT_SET_INVALID
  #undef FIX_2BIG2_UINTP_SET_INVALID
  #undef FIX_2BIG2_UINTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SINT_SET_INVALID
  #undef FIX_2BIG2_SINTP_SET_INVALID
  #undef FIX_2BIG2_SINTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_USHRT_SET_INVALID
  #undef FIX_2BIG2_USHRTP_SET_INVALID
  #undef FIX_2BIG2_USHRTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SSHRT_SET_INVALID
  #undef FIX_2BIG2_SSHRTP_SET_INVALID
  #undef FIX_2BIG2_SSHRTM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UCHAR_SET_INVALID
  #undef FIX_2BIG2_UCHARP_SET_INVALID
  #undef FIX_2BIG2_UCHARM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SCHAR_SET_INVALID
  #undef FIX_2BIG2_SCHARP_SET_INVALID
  #undef FIX_2BIG2_SCHARM_SET_INVALID

/*
 * Large (too big) floating-point values converted to plain char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_PCHAR_SET_INVALID
  #undef FIX_2BIG2_PCHARP_SET_INVALID
  #undef FIX_2BIG2_PCHARM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UBITS_SET_INVALID
  #undef FIX_2BIG2_UBITSP_SET_INVALID
  #undef FIX_2BIG2_UBITSM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SBITS_SET_INVALID
  #undef FIX_2BIG2_SBITSP_SET_INVALID
  #undef FIX_2BIG2_SBITSM_SET_INVALID

/*
 * Large (too big) floating-point values converted to plain bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_PBITS_SET_INVALID
  #undef FIX_2BIG2_PBITSP_SET_INVALID
  #undef FIX_2BIG2_PBITSM_SET_INVALID

/*
 * Large (too big) floating-point values converted to unsigned ENUM
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_UENUM_SET_INVALID
  #undef FIX_2BIG2_UENUMP_SET_INVALID
  #undef FIX_2BIG2_UENUMM_SET_INVALID

/*
 * Large (too big) floating-point values converted to signed ENUM
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_2BIG2_SENUM_SET_INVALID
  #undef FIX_2BIG2_SENUMP_SET_INVALID
  #undef FIX_2BIG2_SENUMM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_ULLONG_SET_INVALID
  #undef FIX_NAN2_ULLONGP_SET_INVALID
  #undef FIX_NAN2_ULLONGM_SET_INVALID

/*
 * NaN floating-point values converted to signed long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SLLONG_SET_INVALID
  #undef FIX_NAN2_SLLONGP_SET_INVALID
  #undef FIX_NAN2_SLLONGM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_ULONG_SET_INVALID
  #undef FIX_NAN2_ULONGP_SET_INVALID
  #undef FIX_NAN2_ULONGM_SET_INVALID

/*
 * NaN floating-point values converted to signed long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SLONG_SET_INVALID
  #undef FIX_NAN2_SLONGP_SET_INVALID
  #undef FIX_NAN2_SLONGM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_UINT_SET_INVALID
  #undef FIX_NAN2_UINTP_SET_INVALID
  #undef FIX_NAN2_UINTM_SET_INVALID

/*
 * NaN floating-point values converted to signed int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SINT_SET_INVALID
  #undef FIX_NAN2_SINTP_SET_INVALID
  #undef FIX_NAN2_SINTM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_USHRT_SET_INVALID
  #undef FIX_NAN2_USHRTP_SET_INVALID
  #undef FIX_NAN2_USHRTM_SET_INVALID

/*
 * NaN floating-point values converted to signed short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SSHRT_SET_INVALID
  #undef FIX_NAN2_SSHRTP_SET_INVALID
  #undef FIX_NAN2_SSHRTM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_UCHAR_SET_INVALID
  #undef FIX_NAN2_UCHARP_SET_INVALID
  #undef FIX_NAN2_UCHARM_SET_INVALID

/*
 * NaN floating-point values converted to signed char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SCHAR_SET_INVALID
  #undef FIX_NAN2_SCHARP_SET_INVALID
  #undef FIX_NAN2_SCHARM_SET_INVALID

/*
 * NaN floating-point values converted to plain char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_PCHAR_SET_INVALID
  #undef FIX_NAN2_PCHARP_SET_INVALID
  #undef FIX_NAN2_PCHARM_SET_INVALID

/*
 * NaN floating-point values converted to unsigned bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_UBITS_SET_INVALID
  #undef FIX_NAN2_UBITSP_SET_INVALID
  #undef FIX_NAN2_UBITSM_SET_INVALID

/*
 * NaN floating-point values converted to signed bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_SBITS_SET_INVALID
  #undef FIX_NAN2_SBITSP_SET_INVALID
  #undef FIX_NAN2_SBITSM_SET_INVALID

/*
 * NaN floating-point values converted to plain bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_NAN2_PBITS_SET_INVALID
  #undef FIX_NAN2_PBITSP_SET_INVALID
  #undef FIX_NAN2_PBITSM_SET_INVALID

/*
 * NAN floating-point values converted to bool and bool bit-field
 * should NOT raise (set) invalid.  Both ends; Plus end; Minus end.
 * In addition, the result should be true (1).
 */
  #undef FIX_NAN2_BOOL_IS_TRUE
  #undef FIX_NAN2_BOOL_SET_INVALID
  #undef FIX_NAN2_BOOLP_SET_INVALID
  #undef FIX_NAN2_BOOLM_SET_INVALID
  #undef FIX_NAN2_BOOLBIT_SET_INVALID
  #undef FIX_NAN2_BOOLBITP_SET_INVALID
  #undef FIX_NAN2_BOOLBITM_SET_INVALID

/*
 * INF floating-point values converted to unsigned long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_ULLONG_SET_INVALID
  #undef FIX_INF2_ULLONGP_SET_INVALID
  #undef FIX_INF2_ULLONGM_SET_INVALID

/*
 * INF floating-point values converted to signed long long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SLLONG_SET_INVALID
  #undef FIX_INF2_SLLONGP_SET_INVALID
  #undef FIX_INF2_SLLONGM_SET_INVALID

/*
 * INF floating-point values converted to unsigned long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_ULONG_SET_INVALID
  #undef FIX_INF2_ULONGP_SET_INVALID
  #undef FIX_INF2_ULONGM_SET_INVALID

/*
 * INF floating-point values converted to signed long
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SLONG_SET_INVALID
  #undef FIX_INF2_SLONGP_SET_INVALID
  #undef FIX_INF2_SLONGM_SET_INVALID

/*
 * INF floating-point values converted to unsigned int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_UINT_SET_INVALID
  #undef FIX_INF2_UINTP_SET_INVALID
  #undef FIX_INF2_UINTM_SET_INVALID

/*
 * INF floating-point values converted to signed int
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SINT_SET_INVALID
  #undef FIX_INF2_SINTP_SET_INVALID
  #undef FIX_INF2_SINTM_SET_INVALID

/*
 * INF floating-point values converted to unsigned short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_USHRT_SET_INVALID
  #undef FIX_INF2_USHRTP_SET_INVALID
  #undef FIX_INF2_USHRTM_SET_INVALID

/*
 * INF floating-point values converted to signed short
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SSHRT_SET_INVALID
  #undef FIX_INF2_SSHRTP_SET_INVALID
  #undef FIX_INF2_SSHRTM_SET_INVALID

/*
 * INF floating-point values converted to unsigned char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_UCHAR_SET_INVALID
  #undef FIX_INF2_UCHARP_SET_INVALID
  #undef FIX_INF2_UCHARM_SET_INVALID

/*
 * INF floating-point values converted to signed char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SCHAR_SET_INVALID
  #undef FIX_INF2_SCHARP_SET_INVALID
  #undef FIX_INF2_SCHARM_SET_INVALID

/*
 * INF floating-point values converted to plain char
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_PCHAR_SET_INVALID
  #undef FIX_INF2_PCHARP_SET_INVALID
  #undef FIX_INF2_PCHARM_SET_INVALID

/*
 * INF floating-point values converted to unsigned bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_UBITS_SET_INVALID
  #undef FIX_INF2_UBITSP_SET_INVALID
  #undef FIX_INF2_UBITSM_SET_INVALID

/*
 * INF floating-point values converted to signed bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_SBITS_SET_INVALID
  #undef FIX_INF2_SBITSP_SET_INVALID
  #undef FIX_INF2_SBITSM_SET_INVALID

/*
 * INF floating-point values converted to plain bits
 * should raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_PBITS_SET_INVALID
  #undef FIX_INF2_PBITSP_SET_INVALID
  #undef FIX_INF2_PBITSM_SET_INVALID

/*
 * INF floating-point values converted to bool and bool bit-field
 * should NOT raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_INF2_BOOL_SET_INVALID
  #undef FIX_INF2_BOOLP_SET_INVALID
  #undef FIX_INF2_BOOLM_SET_INVALID
  #undef FIX_INF2_BOOLBIT_SET_INVALID
  #undef FIX_INF2_BOOLBITP_SET_INVALID
  #undef FIX_INF2_BOOLBITM_SET_INVALID

/*
 * Finite floating-point values converted to bool and bool bit-field
 * should NOT raise (set) invalid.  Both ends; Plus end; Minus end.
 */
  #undef FIX_FP2_BOOL_SET_INVALID
  #undef FIX_FP2_BOOLP_SET_INVALID
  #undef FIX_FP2_BOOLM_SET_INVALID
  #undef FIX_FP2_BOOLBIT_SET_INVALID
  #undef FIX_FP2_BOOLBITP_SET_INVALID
  #undef FIX_FP2_BOOLBITM_SET_INVALID

/*
 * Too large and in-range floating-point values converted
 * to various int types randomly raises invalid.
 */
  #undef FIX_ULLONG_RANDOM_INVALID
  #undef FIX_SLLONG_RANDOM_INVALID
  #undef FIX_ULONG_RANDOM_INVALID
  #undef FIX_SLONG_RANDOM_INVALID
  #undef FIX_UINT_RANDOM_INVALID
  #undef FIX_SINT_RANDOM_INVALID
  #undef FIX_USHRT_RANDOM_INVALID
  #undef FIX_SSHRT_RANDOM_INVALID
  #undef FIX_UCHAR_RANDOM_INVALID
  #undef FIX_SCHAR_RANDOM_INVALID
  #undef FIX_PCHAR_RANDOM_INVALID
  #undef FIX_UBITS_RANDOM_INVALID
  #undef FIX_SBITS_RANDOM_INVALID
  #undef FIX_PBITS_RANDOM_INVALID
  #undef FIX_UENUM_RANDOM_INVALID
  #undef FIX_SENUM_RANDOM_INVALID
  #undef FIX_BOOL_RANDOM_INVALID
  #undef FIX_BOOLBIT_RANDOM_INVALID

/*
 * Valid large and in-range floating-point values converted
 * to unsigned long long int produce wrong value and raises invalid.
 * It appears to only happen for values: ULLONG_MAX/2 ... ULLONG_MAX,
 * that is, the conversion appears to be done is if to signed long long.
 */
  #undef FIX_VALID_FP_2_ULLONG

/*
 * unsigned long long int ulli = -0.999; should be 0uLL
 * unsigned      long int ulli = -0.999; should be 0uL w/o invalid
 */
  #undef FIX_ULLI_FROM_NEG
  #undef FIX_ULI_FROM_NEG

/*
 * unsigned long long int ulli = +0.999; should be 0uLL
 * unsigned      long int  uli = +0.999; should be 0uL
 */
  #undef FIX_ULLI_FROM_POS
  #undef FIX_ULI_FROM_POS

/*
 * f = ui; or f = i; should round (not truncate).
 */
  #undef FIX_I2F_ROUND

/*
 * d = ulli; or d = lli; should round (not truncate).
 */
  #undef FIX_LL_2_REAL_TRUNC

/*
 * long long constants should be usable in preprocessor #if stmts.
 */
  #undef FIX_LL_PP_CONSTANTS

/*
 * long long constants should be usable with floating point constants
 * (particularly, in initializers).
 */
  #undef FIX_LONGLONG_WITH_FP_CONSTS

/*
 * LLONG_MIN in <limits.h> is defined using the wrong syntax, so that
 * it ends up as a positive number.
 */
  #undef FIX_POSITIVE_LLONG_MIN

/*
 * LLONG_MAX in <limits.h> is defined using the wrong syntax, so that
 * it ends up as a negative number.
 */
  #undef FIX_NEGATIVE_LLONG_MAX

/*
 * 1e2147483648 (eg, 10 ** ( 2 ** 32 ) ) should convert to the same value
 * at translation time as run-time.
 */
  #undef FIX_1E2TO32

/*
 * Do scanf and strto* correctly process hex FP numbers with missing hex digits?
 * For example, 0x, 0X, 0xy, 0XY.
 */
  #undef FIX_BAD_0X

/*
 * Do scanf and strto* correctly process I and IN (bad forms of INF)?
 */
  #undef FIX_BAD_INF

/*
 * Do scanf and strto* correctly process "INFI..." (bad forms of INF)?
 * That is, INF with part of INITY.
 */
  #undef FIX_INF_EXTRA

/*
 * Do scanf and strto* correctly process N, NA, NAAN (bad forms of NAN)?
 */
  #undef FIX_BAD_NAN

/*
 * Do scanf and strto* correctly process "NAN(..." (bad forms of NAN)?
 */
  #undef FIX_NAN_EXTRA

/*
 * Hex FP not liked by *scanf or strto* at runtime.
 */
  #undef FIX_FPCE_HEX_RUNTIME

/*
 * In C89, freopen requires a non-null 1st pointer.
 * In C99, freopen allows a NULL 1st pointer.
 * Use this if you get core dumps at runtime in t3040000.
 */
  #undef FIX_C99_freopen

/*
 * Constant expressions should be run-time time, not translation time.
 * -0.0 is not the same as +0.0.  Some compilers evaluate constant
 * expressions involving -0.0 at translate time and produce +0.0
 */
  #undef FIX_MINUS_ZERO_CONSTANT_EXP

/*
 * 0.0f / 0.0f should be a NaN.
 */
  #undef FIX_0F_OVER_0F_IS_NAN

/*
 * 0.0 / 0.0 should be a NaN.
 */
  #undef FIX_0D_OVER_0D_IS_NAN

/*
 * In C89, initialization of aggregates (arrays and structs) and
 * unions was required to be done with constant expressions, e.g., the
 * same as if it was a (compile time) static initialization.  Only
 * auto scalar initializations were left to runtime.  In C99, this was
 * changed to: static => compile time; auto => runtime; independent of
 * scalar/aggregate.  So, auto double d[] = {1.0/0.0}; used to not
 * raise exceptions, now it does.  Define this symbol if the compiler
 * does auto aggregate/union initialization at compile time.
 */
  #undef FIX_AGG_INIT_IS_STATIC

/*
 * Conversion from hexadecimal to internal FP should not suffer double rounding.
 */
  #undef FIX_BAD_HEX_ROUNDING

/*
 * Conversion from hexadecimal to internal FP of very small values
 * should be zero.
 */
  #undef FIX_BAD_HEX_SMALL

/*
 * Conversion from hexadecimal to internal FP of my PI* values in
 * myfloat.h are done so bad, that we need to use the decimal
 * versions.
 */
  #undef FIX_HEX_PI

/*
 * Hexadecimal FP zero, 0x0p0, is zero, not one.
 */
  #undef FIX_HEXZERO_IS_ZERO

/*
 * FP constant (expressions) should be round to nearest.
 */
  #undef FIX_TRANS_ROUND_OK

/*
 * C's FLT_ROUNDS is dynamic and indicates current rounding direction.
 */
  #undef FIX_DYNAMIC_FLT_ROUNDS

/*
 * Conversion from "decimal" to internal FP of infinity should work
 * for strtof, strtod, strtold, and wcstof, wcstod, wcstold.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_STRTO_INF
  #undef FIX_WCSTO_INF
  #undef FIX_STRTO10_INF
  #undef FIX_WCSTO10_INF

/*
 * Conversion from "decimal" to internal FP of NaN should work
 * for strtof, strtod, strtold, and wcstof, wcstod, wcstold.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_STRTO_NAN
  #undef FIX_WCSTO_NAN
  #undef FIX_STRTO10_NAN
  #undef FIX_WCSTO10_NAN

/*
 * Conversion from "decimal" to internal FP of infinity should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCAN_INF
  #undef FIX_WSCAN_INF
  #undef FIX_SCAN10_INF
  #undef FIX_WSCAN10_INF

/*
 * Conversion from "decimal" to internal FP of NaN should work.
 * NAN(...) not liked by *scanf or strto*
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCAN_NAN
  #undef FIX_WSCAN_NAN
  #undef FIX_SCAN10_NAN
  #undef FIX_WSCAN10_NAN
  #undef FIX_NAN_NCHAR

/*
 * Conversion from "decimal" to internal FP of -0.0 should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_SCAN_mZERO
  #undef FIX_WSCAN_mZERO
  #undef FIX_SCAN10_mZERO
  #undef FIX_WSCAN10_mZERO

/*
 * scanf should support %F
 */
  #undef FIX_SCAN_F
  #undef FIX_WSCAN_F

/*
 * [w]scanf should support %a and %A
 */
  #undef FIX_SCAN_aA
  #undef FIX_WSCAN_aA

/*
 * [w]printf should support %F
 */
  #undef FIX_PRINT_F
  #undef FIX_WPRINT_F

/*
 * [w]printf should support %a and %A
 */
  #undef FIX_PRINT_aA
  #undef FIX_WPRINT_aA

/*
 * printf, using %a and %A, can produce as least 4 different outputs
 * for the same number (first digit is: 1, 2-3, 4-7, 8-f).  Depending
 * upon the precision and that first digit, the output may be exact
 * or rounded.  This bypasses tests where a rounded [which is wrong]
 * result may be produced.  Affects t0250900, t30703*.
 */
  #undef FIX_PRINT_aA_SMALL_PREC
  #undef FIX_WPRINT_aA_SMALL_PREC

/*
 * printf using %a and %A has wrong number of leading zeros.
 * %020a in t30703* is one such case.
 */
  #undef FIX_aA_LEADING_ZEROS

/*
 * Conversion from internal FP to decimal of infinity should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_INF
  #undef FIX_WPRINT_INF
  #undef FIX_PRINT10_INF
  #undef FIX_WPRINT10_INF

/*
 * Conversion from internal FP to decimal of NaN should work.
 * Symbols with '10' are for Decimal FP.
 */
  #undef FIX_PRINT_NAN
  #undef FIX_WPRINT_NAN
  #undef FIX_PRINT10_NAN
  #undef FIX_WPRINT10_NAN

/*
 * Conversion from internal FP to decimal of -0.0 should work.
 */
  #undef FIX_PRINT_mZERO
  #undef FIX_WPRINT_mZERO
  #undef FIX_PRINT10_mZERO
  #undef FIX_WPRINT10_mZERO

/*
 * Conversion from internal FP to hexadecimal of denormal should work.
 */
  #undef FIX_PRINT_HEX_DEN
  #undef FIX_WPRINT_HEX_DEN

/*
 * FP evaluation format is supposed to be the wider of semantic type
 * and min eval format.
 */
  #undef FIX_EVAL_AT_LEAST_MIN
  #undef FIX_EVAL10_AT_LEAST_MIN

/*
 * FP constant's evaluation format is wider of semantic type and min
 * eval format (IMPL_FLT_EVAL_CONST).  That is, if FLT_EVAL_METHOD is
 * 1, then 0.1F is done as if 0.1; and if FLT_EVAL_METHOD is 2, then
 * 0.1F and 0.1 are done as if 0.1L.
 */
  #undef FIX_EVAL_CONST_AT_LEAST_MIN
  #undef FIX_EVAL10_CONST_AT_LEAST_MIN

/*
 * FP constant expression (Translation time precision and range) must
 * have evaluation format be wider of semantic type and min eval
 * format (IMPL_FLT_EVAL_CONST_EXP).
 */
  #undef FIX_EVAL_CONST_EXP_AT_LEAST_MIN
  #undef FIX_EVAL10_CONST_EXP_AT_LEAST_MIN

/*
 * FP evaluation format of float is wider of semantic type and min eval format.
 */
  #undef FIX_EVAL_FLT_AT_LEAST_MIN
  #undef FIX_EVAL10_F10_AT_LEAST_MIN

/*
 * For systems with LD_PREC < LD_REG_PREC, is the extra precision always used?
 * Needed for Watcom in t0310200.
 */
  #undef FIX_ALWAYS_EXTRA_PRECISION

/*
 * FP evaluation format is at most long double.  Registers cannot be wider
 * than long double in memory.
 */
  #undef FIX_EVAL_AT_MOST_LDBL
  #undef FIX_EVAL10_AT_MOST_LD10

/*
 * Precision of LDBL should be correct.  On one system, LDBL is stored as
 * LDBL, but is used as DBL.
 */
  #undef FIX_LDBL_PREC_IS_OK
  #undef FIX_LD10_PREC_IS_OK

/*
 * Precision and range of FLT should be correct.  On one system, FLT is
 * stored as FLT, but is used as DBL.
 */
  #undef FIX_FLT_IS_OK

/*
 * When expression values are pushed/popped to the stack, they should not
 * lose any information (precision or exponent range).
 */
  #undef FIX_STACK_PRECISION

/*
 * Are -0.0 and +0.0 converted to randomly signed zeros?
 * One compiler appears to use the first signed zero it sees as the value
 * for all following signed zeros.
 */
  #undef FIX_RANDOM_SIGNED_ZERO

/*
 * Does -y flip the sign bit of y?  It matters for signed zeros and NaNs.
 * The expression -y != 0.0-y if y is +0.  -y != -1*y if y is NaN.
 */
  #undef FIX_NEG_FLIP_SIGN

/*
 * 1/(-INFINITY) should produce -0.  But, if it produces +0, this attempts
 * to get around that bug.
 */
  #undef FIX_1_OVER_mINF

/*
 * Contracted operations, aka, fused multiply-add (FMA), aka
 * multiply-accumulate (MAC) should honor signed zeros.
 */
  #undef FIX_FMA_NEG_ZERO

/*
 * The expression INF + -INF should not be optimized to 0.0.
 */
  #undef FIX_OPT_INF_SUB_INF_TO_0

/*
 * The expression y / y cannot be optimized to 1.0 if y can be an
 * +/- infinity, +/- NaN, or +/-0.0.
 */
  #undef FIX_OPT_Y_DIV_Y_TO_1

/*
 * The expression y / 1.0 cannot be optimized to y for Decimal FP.
 * y / 1.0 should remove a trailing zero (change quantum exponent).
 */
  #undef FIX_OPT_Y_DIV_1_TO_Y

/*
 * The expression 0.0 * y cannot be optimized to 0.0 if y can be an
 * +/- infinity or +/- NaN or -0.0.
 */
  #undef FIX_OPT_0_TIMES_Y_TO_0

/*
 * The expression 1.0 * y cannot be optimized to y for Decimal FP.
 * y * 1.0 should add a trailing zero (change quantum exponent).
 */
  #undef FIX_OPT_1_TIMES_Y_TO_Y

/*
 * The expression 0.0 * -1.0 cannot be optimized to +0.0
 */
  #undef FIX_OPT_0_TIMES_m1_TO_p0

/*
 * The expression 0.0 / y cannot be optimized to 0.0 if y can be a
 * +/- NaN or +/-0.0.
 */
  #undef FIX_OPT_0_DIV_Y_TO_0

/*
 * The expression 0.0 / -1.0 cannot be optimized to +0.0
 */
  #undef FIX_OPT_0_DIV_m1_TO_p0

/*
 * The expression 0.0 + y cannot be optimized to y if y can be a -0.0
 */
  #undef FIX_OPT_0_PLUS_Y_TO_Y

/*
 * The expression 0.0 - y cannot be optimized to -y if y can be a +/-0.0
 */
  #undef FIX_OPT_0_MINUS_Y_TO_mY

/*
 * The expression y - 0.0 cannot be optimized to y if y can be a +0.0
 * and the rounding mode is towards -infinity.
 */
  #undef FIX_OPT_Y_MINUS_0_TO_Y

/*
 * The expression y - y cannot be optimized to 0.0 if y can be an
 * +/- infinity or +/- NaN.
 */
  #undef FIX_OPT_Y_MINUS_Y_TO_0

/*
 * The expression x+x*y cannot be optimized to x*(1+y) if y is -2
 * and x is max or inf.
 */
  #undef FIX_OPT_COMMON_FACTOR

/*
 * The expression y / 5.0 cannot be optimized to y * 0.2
 */
  #undef FIX_OPT_DIV_TO_MUL

/*
 * Statements like 0.0/0.0; must be done for their side effects.
 * They cannot be optimized away.
 */
  #undef FIX_OPT_SIDE_EFFECTS

/*
 * The statement FLT_MAX * FLT_MAX; must be done for its side effects.
 * It cannot be optimized away.
 */
  #undef FIX_OPT_MAX_x_MAX

/*
 * The statement FLT_MIN * FLT_MIN; must be done for its side effects.
 * It cannot be optimized away.
 */
  #undef FIX_OPT_MIN_x_MIN

/*
 * Any comparison involving non-NaN must be done correctly.  This
 * includes comparisons involving a variable and/or a constant.
 * Example: res = ( var0 < 1.0 ) ? 1 : 0; For tests t030*
 * Example: res = ( var0 < var1) ? 1 : 0; For tests t030*
 * Example: res = ( 0.0  < var1) ? 1 : 0; For tests t030*
 */
  #undef FIX_BAD_COMP_VAR_CON
  #undef FIX_BAD_COMP_VAR_VAR
  #undef FIX_BAD_COMP_CON_VAR

/*
 * Any comparison (<, <=, >=, >) involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL
  #undef FIX_BAD_NAN_COMP10_BOOL

/*
 * Any '<' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_LT
  #undef FIX_BAD_NAN_COMP10_BOOL_LT

/*
 * Any '<=' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_LE
  #undef FIX_BAD_NAN_COMP10_BOOL_LE

/*
 * Any '>=' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_GE
  #undef FIX_BAD_NAN_COMP10_BOOL_GE

/*
 * Any '>' comparison involving a NaN must be false.
 */
  #undef FIX_BAD_NAN_COMP_BOOL_GT
  #undef FIX_BAD_NAN_COMP10_BOOL_GT

/*
 * Any comparison involving a NaN must be false.  Some compilers generate
 * different code depending upon the type of either the left or the right
 * operand.  So, ld_nan < d_nan might be false and d_nan < f_nan might be
 * true.  The LDBL here really means type dependent.
 */
  #undef FIX_BAD_NAN_COMP_LDBL
  #undef FIX_BAD_NAN_COMP10_LD10

/*
 * Any comparison (<, <=, >=, >) involving a NaN must raise invalid.
 */
  #undef FIX_BAD_NAN_COMP_FLAG
  #undef FIX_BAD_NAN_COMP10_FLAG

/*
 * Any comparison involving a NaN must raise invalid.  This includes
 * comparisons involving just constants.  The compiler folded the operation
 * at compile time into true or false, but did not generate code to raise
 * invalid.  Example:  if( NAN < NAN ) must raise invalid.
 */
  #undef FIX_BAD_NAN_COMP_FLAG_CONST
  #undef FIX_BAD_NAN_COMP10_FLAG_CONST

/*
 * Any comparison involving a NaN must raise invalid.  This includes
 * comparisons involving a variable and a constant.  The compiler
 * folded the operation at compile time into true or false, but
 * did not generate code to raise invalid.  Example:  if( var < NAN )
 * must raise invalid.
 */
  #undef FIX_BAD_NAN_COMP_FLAG_VARCON
  #undef FIX_BAD_NAN_COMP10_FLAG_VARCON

/*
 * Any comparison involving a NaN must be false and raise invalid,
 * including those that have the same variable on both sides of the operator,
 * eg, if( ld_nan < ld_nan )
 */
  #undef FIX_BAD_NAN_COMP_SAME
  #undef FIX_BAD_NAN_COMP10_SAME

/*
 * Some compares involving a NaN is failing for unknown reason.
 * None of the preceding seem to cover it (no obvious pattern).
 */
  #undef FIX_BAD_NAN_COMP_UNKNOWN
  #undef FIX_BAD_NAN_COMP10_UNKNOWN

/*
 * Any equality (==, !=) involving a NaN must be quiet (no invalid).
 */
  #undef FIX_BAD_NAN_EQEQ_FLAG

/*
 * NAN is supposed to be of type float.
 */
  #undef FIX_NAN_FLOAT

/*
 * INFINITY is supposed to be of type float.
 */
  #undef FIX_INF_FLOAT

/*
 * Status flags must be clear at program startup and after static init.
 */
  #undef FIX_FLAGS_CLEAR

/*
 * sizeof float_t and double_t should work.
 */
  #undef FIX_SIZEOF_FLOAT_T
  #undef FIX_SIZEOF_DOUBLE_T

/*
 * Contracted (fused) multiply-add should be consistent with IEEE-754 intent.
 */
  #undef FIX_FMA_BAD

/*
 * Parameters are passed in format wider than declared type.
 */
  #undef FIX_WIDE_PARMS

/*
 * INF_type shall be quiet, that is, not raise any exceptions.
 * 1e9999999 should be a valid infinity that raises no exceptions, but is
 * not always supported.  1.0/0.0 and MAX_type*MAX_type are two other ways
 * to get infinity, but they raise exceptions.  The symbol IMPL_INF_FLAGS
 * should be defined in your *.flt file to the flags raised by those
 * INF_type definitions.
 */
  #undef FIX_QUIET_INF

/*
 * NAN should be quiet, that is, not raise any exceptions.
 * This is a should, not a shall, so is optional.
 */
  #undef FIX_NOISY_NAN

/*
 * HUGE_VAL* shall be quiet, that is, not raise any exceptions.
 */
  #undef FIX_NOISY_HUGE_VAL

/*
 * HUGE_VAL* shall be infinity (for IEEE-754 FP)
 */
  #undef FIX_HUGE_VAL_IS_INF
  #undef FIX_HUGE_VALF_IS_INF
  #undef FIX_HUGE_VALL_IS_INF

/*
 * Array initialized with NANs should be done correctly.
 * One compiler puts the wrong value into memory.
 */
  #undef FIX_NAN_INIT

/*
 * int ary[(int)(11.*0.9)]; is a variable length array with
 * expression using floating-point constants.  The value
 * depends upon the current rounding mode at runtime.
 * If the compiler does the constant expression at compile time,
 * define this to bypass the tests that fail.
 */
  #undef FIX_VLA_CONST_EXP

/*
 * typedef int ary[(int)(x*y)]; is a typedef with a VLA.
 * It is supposed to be evaluated once when encountered,
 * not reevaluated each time used.
 */
  #undef FIX_TYPEDEF_VLA_ONCE

/*
 * A call to an inline function must convert the arguments as if by
 * assignment.  If the conversions are not done, define this symbol.
 */
  #undef FIX_BAD_INLINE_CALL

/*
 * Some code does the wrong thing and we have not been able to figure
 * out why.  It is unknown why the test fails.  This allows it to be
 * removed for a 'clean' run.
 */
  #undef FIX_UNKNOWN

/*
 * The LCC compiler fails for some code similar to: var = 1uL op 1uLL;
 * mainly in the t016* files.  But, it is not consistent in the failures.
 */
  #undef FIX_UNKNOWN_LCC

/*
 * Some code, that involves bool, does the wrong thing and we have not
 * been able to figure out why.  It is unknown why the test fails.
 * This allows it to be removed for a 'clean' run.
 */
  #undef FIX_UNKNOWN_BOOL

/*
 * Conversion from (at least) unsigned long int to (at least) long double
 * alters the rounding direction control.  It should not.  The rounding
 * direction control should remain constant unless altered by fesetround()
 */
  #undef FIX_ROUNDING_CONSTANT

/*** Run time: C99: input/output library function problems ***/
/*
 * Many of these are above in the C89/C90/C95 section;
 * see *_SCAN2BIN_ULPS, ...
 */

/*
 * If the error in binary (internal) to decimal/hex (external) to
 * binary (internal) roundtrip conversion is so large that it cannot
 * be represented as a long int (used during pre-processor), then
 * define this symbol as a double value, e.g.,
 * #define FIX_BIN2HEX2BIN_LARGE 2.0e9
 * This is useful if most conversions have a small error (bypassed by
 * *_BIN2DEC2BIN_ULPS) and a few conversions with large error (bypassed
 * by this symbol).  This ignores errors LARGER than the macro's
 * value.
 */
  #undef FIX_BIN2HEX2BIN_LARGE

/*
 * Binary (internal) to decimal/hex (external) to binary (internal)
 * roundtrip conversions by runtime (printf and scanf) of some numbers
 * is off by a factor of two (either too high or too low).
 * Symbols with 'DFP' are for Decimal FP.
 */
  #undef FIX_BIN2DEC2BIN_TWICE
  #undef FIX_BIN2HEX2BIN_TWICE
  #undef FIX_DFP2DEC2DFP_TWICE

/*
 * %a and/or %A have an exponent of the wrong form, so bypass them.
 * Most common cause is minimum exponent is 2 digits (should be 1 digit),
 * or has hexadecimal digits in exponent.
 */
  #undef FIX_PRINTF_aA_HAS_EXPONENT
  #undef FIX_WPRINTF_aA_HAS_EXPONENT

/*
 * %a and/or %A have an exponent that is missing the required sign.
 */
  #undef FIX_PRINTF_aA_HAS_EXP_SIGN
  #undef FIX_WPRINTF_aA_HAS_EXP_SIGN

/*
 * The first hex digit of %a and/or %A has a value bigger than allowed
 * based upon IMPL_aA_BITS or IMPL_LaA_BITS.
 */
  #undef FIX_PRINTF_aA_HAS_BIG_HEX_DIG
  #undef FIX_WPRINTF_aA_HAS_BIG_HEX_DIG

/*
 * The first nonzero hex digit of %a and/or %A has a non-hex value.
 */
  #undef FIX_PRINTF_aA_HAS_BAD_HEX_DIG
  #undef FIX_WPRINTF_aA_HAS_BAD_HEX_DIG

/*
 * %a and/or %A, even for subnormals, need to have one hex digit
 * before the '.'
 */
  #undef FIX_PRINTF_aA_HEX_DOT
  #undef FIX_WPRINTF_aA_HEX_DOT

/*** Run time: C99: math library function problems ***/

/*
 * Math library function raises underflow for non-underflow results.
 * This is a spurious underflow (which is prohibited by 7.12.1p1,
 * F.7.6p1, and F.9p9).
 */
  #undef FIX_BAD_UF_GOT_acos
/* ... thru ... */
  #undef FIX_BAD_UF_GOT_trunc
  #undef FIX_BAD_UF_GOT10_acos
/* ... thru ... */
  #undef FIX_BAD_UF_GOT10_trunc

/*
 * errno should be consistent with FP exception flags
 */
  #undef FIX_ERRNO_MATH_acos
/* ... thru ... */
  #undef FIX_ERRNO_MATH_trunc
  #undef FIX_ERRNO_MATH10_acos
/* ... thru ... */
  #undef FIX_ERRNO_MATH_trunc

/*
 * nan("") should be same as NAN
 * nand64("") should be same as DEC_NAN
 */
  #undef FIX_FUNCS_nan_NAN
  #undef FIX_FUNCS10_nan_NAN

/*
 * nan*("chars") shall be same as strto*("NAN(chars)",0)
 */
  #undef FIX_FUNCS_nan_strto
  #undef FIX_FUNCS10_nan_strto

/*
 * Numbers near 1.0 cause problems, eg, pow(1.+ulp,large), pow(1.-ulp,large)
 */
  #undef FIX_ARG1_NEAR_1_pow

/*
 * pow(+/-0.0,-INF) raises flags (should be quiet)
 */
  #undef FIX_POW_0_MINF		/* pow(+/-0.0,-INF) wrong */

/*
 * The math library functions are not supposed to alter the FPU
 * control modes.  If a function does, this bypasses those tests.
 * Only a few functions have needed this so far.
 */
  #undef FIX_MODES_lrint
  #undef FIX_MODES_llrint
  #undef FIX_MODES_tan
  #undef FIX_MODES10_tan

/*** Run time: C99: other library function problems ***/

/*
 * Pseudo-denormals on x87 are mis-classified as denormals (they are
 * really normals as far as the value is concerned).  Or, cause core dump.
 */
  #undef FIX_CLASS_PSEUDO_DEN

/*
 * Pseudo-INF on x87 are mis-classified as INF (really a signaling NaN),
 * or, cause core dump.
 */
  #undef FIX_CLASS_PSEUDO_INF

/*
 * Pseudo-NaNs on x87 are mis-classified as quiet NaN, or, cause core dump.
 */
  #undef FIX_CLASS_PSEUDO_NAN

/*
 * Signaling NaNs on x87 are mis-classified as quiet NaN, or, cause core dump.
 */
  #undef FIX_CLASS_SIGNAL_NAN

/*
 * Unnormals on x87 are mis-classified as normal (really signaling NaN),
 * or, cause core dump.
 */
  #undef FIX_CLASS_UNNORMALS

/*
 * Normals in smallest binade are mis-classified as subnormals
 */
  #undef FIX_CLASS_MIN_NORMALS

/*
 * Function is supposed to alter the rounding direction or indicate the
 * current rounding direction.
 */
  #undef FIX_RND_fesetround
  #undef FIX_RND_fegetround
  #undef FIX_RND_fe_dec_setround
  #undef FIX_RND_fe_dec_getround

/*
 * Function is supposed to return a success/failure value.  That value
 * has changed as C9X evolved.  Use this if the function does the
 * correct action, but returns the wrong success/failure value.
 */
  #undef FIX_BAD_RET_fesetround
  #undef FIX_BAD_RET_feupdateenv
  #undef FIX_BAD_RET_feraiseexcept
  #undef FIX_BAD_RET_fe_dec_setround

/*
 * Library function not raise any flags as expected.
 */
  #undef FIX_FLAGS_feraiseexcept

/*
 * feraiseexcept() first clears all the flags,
 * then raises the requested ones.
 */
  #undef FIX_CLEAR_THAN_RAISE

/*** Run time: DFP ***/
/*** Run time: DFP: value of constant problems ***/

/*
 * Unsuffixed decimal (not hexadecimal) double constants
 * should be treated as per #pragma STDC FLOAT_CONST_DECIMAL64.
 * gcc 4.3.2 treats them as DFP (perhaps like TTDT).
 */
  #undef FIX_UNSUFFIX_AS_DFP
  #undef FIX_UNSUFFIX_AS_BFP

/*** Run time: DFP: code generation problems ***/

/*
 * Units Last Place error allowed for decimal FP to binary FP conversion
 * done at runtime.
 * Should be a binary FP number (such as FP_D(0.) or FP_F(1.)).
 * The leading type is the converted TO type.
 */
  #undef LDBL_DFP2BFP_ULPS
  #undef  DBL_DFP2BFP_ULPS
  #undef  FLT_DFP2BFP_ULPS

/*
 * Units Last Place error allowed for binary FP to decimal FP conversion
 * done at runtime.
 * Should be a decimal FP number (such as FP_D10(0.) or FP_F10(1.)).
 * The leading type is the converted TO type.
 * Implementations with perfect conversion should have these be 0. (not .5).
 */
  #undef LD10_BFP2DFP_ULPS
  #undef  D10_BFP2DFP_ULPS
  #undef  F10_BFP2DFP_ULPS

/*
 * Simulating decimal FP on a binary FP system produces poor results.
 * This bypasses the worst of the tests.  Mainly used by Tydeman to
 * develope decimal FP tests on his binary FP systems.
 */
  #undef FIX_BAD_FAKE_DECFP
  #undef FIX_D10_ADD
  #undef FIX_D10_MULT
  #undef FIX_F10_ADD
  #undef FIX_F10_MULT
  #undef FIX_LD10_ADD
  #undef FIX_LD10_MULT

/*
 * This determines if F10 promotes to F10 or D10 in function call with
 * var args.  If you get a core dump from t6160322, try this symbol.
 */
  #undef FIX_F10_PROMOTE2_D10

/*
 * if( ZERO_* ) should be false.  gcc thinks it is true.
 */
  #undef FIX_ZERO_DFP_IS_TRUE

/*
 * if( ONE_* - ONE_* ) should be false.  gcc thinks it is true.
 * ( false - ZERO_* ) should be false.  gcc thinks it is true.
 */
  #undef FIX_ZERO_DFP_EXP_IS_TRUE

/*
 * DFP operations should raise FP exception flags that same as BFP.
 * fetestexcept(), feclearexcept() do exist and work (for BFP operations).
 * gcc's DFP emulation mostly leaves the flags alone.
 */
  #undef FIX_DFP_FLAGS

/*** Run time: DFP: input/output library function problems ***/
/*
 * [w]printf should support DFP of the three types.
 */
  #undef FIX_PRINT_F10
  #undef FIX_WPRINT_F10
  #undef FIX_PRINT_D10
  #undef FIX_WPRINT_D10
  #undef FIX_PRINT_LD10
  #undef FIX_WPRINT_LD10

/*** Run time: DFP: math library function problems ***/

/*
 * IEEE-754-2008 specifies the preferred quantum exponent of the result for
 * some algebraic functions (but no transcendental functions).
 * Some of us are extending that to other functions.
 * These symbols are for functions that get it wrong.
 */
  #undef FIX_QUANTEXP_cbrt
  #undef FIX_QUANTEXP_sqrt

/*** Run time: DFP: other library function problems ***/

/*
 * Rounding modes for binary and decimal are supposed to be independent
 * of each other.  If changing one affects the other, define this symbol.
 */
  #undef FIX_BIN_DEC_RND_DEPENDS

  #if (defined PERENNIAL)
    #include "tsthd.h"
  extern int locflg;
  #endif

/****************************************************************/
/* Lint/compile (but not link/run) non-standard data formats	*/
/* used on machines other than the x86 development system.	*/
/* This is used to find obvious typos before we ship the code.	*/
/* Can be used with hex or dec via compiler name in makefile.	*/
/****************************************************************/
  #if (defined DO_106_113)
    #include "do106113.bug"	/* Compile time workarounds */

/****************************************************************/
/* For compilers that never heard of <fenv.h>.			*/
/****************************************************************/
  #elif (defined FENV_MISSING)
    #include "sample3.bug"

/****************************************************************/
/* Quick and dirty setup for sample tests.			*/
/****************************************************************/
  #elif (defined FPCE_SAMPLE)
    #include "sample.bug"

/**********************************************************************/
/* LCC: 32-bit Windows						      */
/**********************************************************************/
  #elif (defined __LCC__)
    #include "lcc.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Watcom: DOS, Win*, OS/2					      */
/**********************************************************************/
  #elif (defined __WATCOMC__)
    #include "watcom.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Metrowerks; Both Mac and Intel				      */
/**********************************************************************/
  #elif (defined __MWERKS__)
    #include "metrowks.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Diab Data C cross compiler					      */
/**********************************************************************/
  #elif (defined __DCC__)
    #include "diab.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Sun: Sparc (32-bit & 64-bit), 32-bit x86, 64-bit ia64	      */
/**********************************************************************/
  #elif (defined __sun) && (defined __unix)
    #include "sun.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* Tandem							      */
/**********************************************************************/
  #elif (defined __TANDEM)
    #include "tandem.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* CRAY; UNICOS; Cray Standard C/C++ from Programming Environment 2.0 */
/**********************************************************************/
  #elif (defined _CRAYIEEE) /* && (defined ?? ) // need compiler name */
    #include "cray0200.bug"	/* defines to bypass known C/C++ bugs */

/**********************************************************************/
/* IBM S/390; MVS; IBM C/C++					      */
/**********************************************************************/
  #elif (defined __HOS_MVS__) || (defined __TOS_MVS__)
    #include "ibm390.bug"	/* defines to bypass known bugs */

/*******************************************************************/
/* Apple Mac == PowerPC; Mac OS X; gcc in C or C++ mode		   */
/*******************************************************************/
  #elif (defined __POWERPC__) && (defined __MACH__) && (defined __GNUC__)
    #include "macgcc.bug"

/****************************************************************/
/* Apple Mac == PowerPC; Mac OS X; IBM VA in either C or C++ mode		*/
/****************************************************************/
  #elif (defined __PPC__) && (defined __MACH__) && (defined __IBMC__ || defined __IBMCPP__)
    #include "macibm.bug"

/**********************************************************************/
/* Lund MultiProcessor Compiler: PowerPC			      */
/**********************************************************************/
  #elif (defined __LMPCC__)
    #include "lmpcc.bug"

/*******************************************************************/
/* POWER or PowerPC; AIX; Taligent CompTech C/C++ in C or C++ mode */
/*******************************************************************/
  #elif (defined __PPC__) && ((defined __TaligentC__) || (defined __TaligentCPlusPlus__))
    #include "taligent.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* POWER; AIX; IBM xlC C/C++ in either C or C++ mode		*/
/* POWER; AIX; IBM xlc C in C mode				*/
/****************************************************************/
  #elif (defined _IBMR2) && ((defined __xlc) || (defined __XLCPP))
    #include "ibm6xlc.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* PA, Itanium; HP UX; HP C/C++ in either C or C++ mode		*/
/****************************************************************/
  #elif (defined __hppa)
    #include "hppa.bug"		/* defines to bypass known bugs */
  #elif (defined __ia64) && (defined __hpux)
    #include "hpux.bug"		/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; OS/2; IBM C Set++ in either C or C++ mode		*/
/****************************************************************/
  #elif (defined _M_I386) && (defined __IBMC__ || defined __IBMCPP__)
    #include "ibm2cset.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; Linux; Intel icc in C or C++				*/
/****************************************************************/
  #elif (defined __i386__) && (defined __linux__) && (defined __ICC)
    #include "intel.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; Linux; GNU gcc in C or C++				*/
/****************************************************************/
  #elif (defined __i386__) && (defined __linux__) && (defined __GNUC__)
    #include "gcclinux.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; OS/2; GNU gcc 2.7.2.1 + emx 0.9c + fix02 in C or C++	*/
/* 80x86; OS/2; GNU gcc 2.5.7 + emx 0.8h in C or C++ mode	*/
/****************************************************************/
  #elif (defined __i386__) && (defined __EMX__)
    #include "gcc_emx.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; DOS or WinXX; Microsoft C/C++ 4.0 in C or C++ mode	*/
/****************************************************************/
  #elif (defined _MSC_VER)
    #include "microsft.bug"

/****************************************************************/
/* 80x86; WinXX; Digital Mars C/C++ 8.0 in either C or C++ mode	*/
/* Must come before Symantec (since compiler defines __SC__)	*/
/****************************************************************/
  #elif (defined __I86__) && (defined __DMC__)
    #include "digmars.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; DOS; Symantec C/C++ 7.0 in either C or C++ mode	*/
/****************************************************************/
  #elif (defined __I86__) && (defined __SC__)
    #include "symantec.bug"	/* defines to bypass known bugs */

/****************************************************************/
/* 80x86; DOS; Borland C/C++ 4.01 in C or C++ mode; 1993 version*/
/* 80x86; DOS; Borland Turbo C 2.01 (1988 version)		*/
/****************************************************************/
  #elif (defined __X86__) && ((defined __TURBOC__) || (defined __BORLANDC__))
    #include "borland.bug"	/* defines to bypass known bugs */

/**********************************************************************/
/* Comeau Computing						      */
/**********************************************************************/
  #elif (defined __COMO__)
    #include "comeau.bug"

/**********************************************************************/
/* Edison Design Group; must be near end as others build upon it      */
/**********************************************************************/
  #elif (defined __EDG__)
    #include "edg.bug"

/**********************************************************************/
/* ARM								      */
/**********************************************************************/
  #elif (defined __arm__)
    #include "arm.bug"

  #else	/*==================ERROR===============================*/

    #error Unknown hardware + software combination.
    #error Add a pair of #elif and #include lines similar to above pairs.
    #error The file to include needs lines like the sample*.bug files.
    #include "yourfile.bug"	/* defines to bypass known bugs */

  #endif

/*
 * Work around for fetestexcept() or feclearexcept() missing or very bad.
 */
  #if (defined FIX_FUNC_fetestexcept)	\
   || (defined FIX_FUNC_feclearexcept)	\
   || (defined FIX_FLAG_fetestexcept)	\
   || (defined FIX_FLAG_feclearexcept)
    #define FIX_FE_FLAGS
  #endif

/*
 * What needs to be done at program startup to match FPCE document?
 * Most likely, will need to disable trapping.
 * This defines the default macros (if not already defined)
 * to be used by SETUP2 in main().
 */

  #ifdef NEED_FLAGS_CLEARED
    #ifndef   FPU_CLEAR_FLAGS
      #define FPU_CLEAR_FLAGS	CLEAR_ALL;
    #endif
  #else
    #define FPU_CLEAR_FLAGS
  #endif

  #ifdef NEED_ROUND_SET
    #ifndef   FPU_SET_ROUNDING
      #define FPU_SET_ROUNDING (void)fesetround(FE_TONEAREST);
    #endif
  #else
    #define FPU_SET_ROUNDING
  #endif

  #ifdef NEED_PREC_SET	/* May depend upon FLT_EVAL_METHOD of <float.h> */
    #ifndef   FPU_SET_PRECISION
      #define FPU_SET_PRECISION (void)fesetprec(FE_LDBLPREC);
    #endif
  #else
    #define FPU_SET_PRECISION
  #endif

  #ifdef NEED_TRAPS_DISABLED
    #ifndef   FPU_DISABLE_TRAPS /* could also be: (void)feholdexcept( &current_fenv ); */
      #define FPU_DISABLE_TRAPS (void)fedisabletrap(FE_TRAP_ALL);
    #endif
  #else
    #define FPU_DISABLE_TRAPS
  #endif

/*
 * For those machines that only have two 'hardware' floating point types,
 * the existing compiler has two mappings.  Either float and double are
 * the smaller type or double and long double are the larger type.  Also,
 * some systems do not yet have the long double versions of the math
 * functions, isnan(long double var) in particular, or allocate the wrong
 * number of bytes for long double vars or literals.  These defines allow
 * you to tailor the mapping of the 3 floating point types in C to the
 * 2 or 3 compiler/hardware supported floating point types.  They also
 * allow partial testing until the compiler supports more of FPCE.
 * REMAP_* affects types, literal constants, and function names.
 *
 * For long double, there are three choices (from best to worst):
 * 1) long double is fully supported and has more precision than double:
 *	#undef  REMAP_LDBL
 *	#undef  IMPL_LDBL_EQ_DBL
 * 2) long double is fully supported, but has same precision as double:
 *	#undef  REMAP_LDBL
 *	#define IMPL_LDBL_EQ_DBL
 * 3) long double is not supported or support is very bad (=> do not use):
 *	#define REMAP_LDBL
 *	#define IMPL_LDBL_EQ_DBL
 *	#define FIX_LDBL
 *	#define FIX_FUNCS_L
 */

  #ifdef REMAP_LDBL
    #define LDBL	double		/* get rid of long double type */
    #define IMPL_LDBL_EQ_DBL
    #define FIX_LDBL
    #define FIX_FUNCS_L		/* get rid of long double functions */
  #else
    #define LDBL	long double
  #endif

  #ifdef REMAP_DBL			/* not supported yet */
    #define DBL		long double
    #define IMPL_LDBL_EQ_DBL
  #else
    #define DBL		double
  #endif

  #define FLT		float

/*
 * FPCE Technical Report (TR) used #pragma's as a means for the programmer
 * to control the compiler's code generation.  Tests were written for each
 * of these pragmas.  Those tests need to not invoke the pragmas in some
 * cases, so there are means to do that here (most tests take the values
 * shown here, so the default action is to invoke all pragmas). When the
 * FPCE TR got adopted into C99, the three fp_wide_* pragmas went away (an
 * implementation may optionally support them, but they are not required).
 * fenv_access pragma became FENV_ACCESS_* macros in <fenv.h> and
 * fp_contract pragma became FP_CONTRACT_* macros in <math.h>.
 * The default invocation of these macros is now done in myfloat.h
 * Then with WG14/N631, they were changed back to pragmas, but of a new form.
 */
  #include "fenvon.h"
  #include "fpconoff.h"

/*
 * <math.h> translation directives are supposed to be defined.
 * No longer test these as they have been replaced with pragmas.
 */
  #if (19970207uL <= FPCE_TEST_LVL)
    #define FIX_SYM_FP_CONTRACT_ON
    #define FIX_SYM_FP_CONTRACT_OFF
    #define FIX_SYM_FP_CONTRACT_DEFAULT
  #endif

/*
 * <fenv.h> translation directives are supposed to be defined.
 * No longer test these as they have been replaced with pragmas.
 */
  #if (19970207uL <= FPCE_TEST_LVL)
    #define FIX_SYM_FENV_ACCESS_ON
    #define FIX_SYM_FENV_ACCESS_OFF
    #define FIX_SYM_FENV_ACCESS_DEFAULT
  #endif

/*
 * These next three are in the Technical Report only.  Not part of C99.
 */
  #if (!defined FIX_PRAGMAS) \
   && (!defined FIX_PRAGMA_WIDE_RETURNS) \
   && (defined TEST_WIDE_RETURNS)
    #pragma fp_wide_function_returns off
  #endif
  #if (!defined FIX_PRAGMAS) \
   && (!defined FIX_PRAGMA_WIDE_PARMS) \
   && (defined TEST_WIDE_PARMS)
    #pragma fp_wide_function_parameters off
  #endif
  #if (!defined FIX_PRAGMAS) \
   && (!defined FIX_PRAGMA_WIDE_VARS) \
   && (defined TEST_WIDE_VARS)
    #pragma fp_wide_variables off
  #endif

/*
 * In the FPCE Technical Report (TR), many new macros and functions were
 * added in a new header <fp.h>.  When the TR got adopted into C99, those
 * were moved into <math.h>.  To allow testing of compilers during the
 * transition from fp.h to math.h, which header is included is defined here.
 * FP_H can be defined in the compiler specific sections above if needed.
 */
  #ifndef FP_H
    #if FPCE_TEST_LVL >= 19960226uL
      #define FP_H <math.h>
    #else
      #define FP_H <fp.h>
    #endif
  #endif

/*
 * For users testing compilers that do not yet support <fenv.h> as a
 * standard header (in a standard directory), this allows then to do:
 * #define FENV_H "fenv.h"
 * in their bug definition file.  This then uses the fenv.h in the
 * local directory.
 */
  #ifndef FENV_H
    #define FENV_H <fenv.h>
  #endif

/*
 * At the February, 1997, meeting of WG14 / X3J11, Type-Generic Math
 * Functions, WG14/N639, X3J11/97-002, was voted to be included into
 * C99 subject to a review committee and final wording to be voted on
 * by the full committee at the June, 1997 meeting.
 *
 * For users testing compilers that do not yet support <tgmath.h> as a
 * standard header (in a standard directory), this allows then to do:
 * #define TG_MATH_H "tgmath.h"
 * in their bug definition file.  This then uses the tgmath.h in the
 * local directory.
 *
 * tgmath.h will only be used if FIX_OVERLOAD is not defined.
 */
  #ifndef TG_MATH_H
    #define TG_MATH_H <tgmath.h>
  #endif

/*
 * Is now part of C99.  This header defines typedefs and macros useful for
 * exact size integers.  This test suite uses it for unions of floating-
 * point types with specific sized integers to create specific bit patterns
 * in the floating-point numbers.  Since not all vendors define this header,
 * the compiler specific sections above can define INTTYPES_H to map to
 * whatever header file is needed.
 */
  #ifndef   INTTYPES_H
    #define INTTYPES_H <inttypes.h>
  #endif

  #if FPCE_TEST_LVL >= 19960226uL

    #if	(!defined FIX_SYM___STDC_IEC_559__)	\
     && (!defined FIX_SYM_FLT_EVAL_METHOD)
      #define TESTSYMS "testsyms.h"
    #endif

  #else /* FPCE_TEST_LVL < 19960226uL */

    #if	(!defined FIX_SYM___FPCE__)		\
     && (!defined FIX_SYM___FPCE_IEEE__)		\
     && (!defined FIX_SYM__MIN_EVAL_FORMAT)	\
     && (!defined FIX_SYM__WIDEST_NEED_EVAL)
      #define TESTSYMS "testsyms.h"
    #endif

  #endif

  #ifdef STANDALONE_TEST	/* Standalone C/C++ main() program */

    #define RETTYP int
    #define RETVAL (0)	/* EXIT_SUCCESS */

  #else			/* C++ function called by test environment */

    #define RETTYP void
    #define RETVAL /* void */

  #endif

/*
 * Certain tests require that the header (and therefore the code) used
 * to defined these bypasses be gone.  Those tests are checking the
 * contents of headers.  They should not care if traps are enabled as
 * the actual executable code is minimal and trivial.  Those tests will
 * #define ALLOW_NON_STD_STARTUP before including any header.  If the
 * sample FPCE tests are being compiled together, then need these.
 */
  #if (defined ALLOW_NON_STD_STARTUP) && (!defined FPCE_SAMPLE)
    #undef  FPU_CLEAR_FLAGS
    #define FPU_CLEAR_FLAGS
    #undef  FPU_SET_ROUNDING
    #define FPU_SET_ROUNDING
    #undef  FPU_SET_PRECISION
    #define FPU_SET_PRECISION
    #undef  FPU_DISABLE_TRAPS
    #define FPU_DISABLE_TRAPS
  #endif

/*
 * Default file mode macros (if not defined in your *.bug file).
 */
  #ifndef   R_MODE
    #define R_MODE "r"
  #endif

  #ifndef   W_MODE
    #define W_MODE "w"
  #endif

  #ifndef   A_MODE
    #define A_MODE "a"
  #endif

/*
 * Default setup macros (if not defined above).
 */
  #if defined(PERENNIAL)

    #if !defined(SETUP1)
      #define SETUP1(fil) const char prgnam[] = fil ".c";
    #endif
    #if !defined(SETUP2)
      #define SETUP2(fil) setup();\
	FPU_CLEAR_FLAGS		\
	FPU_SET_ROUNDING	\
	FPU_SET_PRECISION	\
	FPU_DISABLE_TRAPS
    #endif

  #elif (defined REDIRECT)	/* If redirecting stdout */

    #ifndef   SUFFIX
      #define SUFFIX ".res"	/* Suffix to add to results' file name */
    #endif
    #ifndef   MODE
      #define MODE "w"		/* Write Text file mode when reopen stdout */
    #endif
    #ifndef   SETUP1
      #define SETUP1(fil) FILE *_file_ptr;
    #endif
    #ifndef   SETUP2
      #define SETUP2(fil) \
	_file_ptr = freopen(fil SUFFIX, MODE, stdout);/* Redirect stdout */\
	if( NULL == _file_ptr ){\
          (void)fprintf(stderr, "Cannot reopen stdout in %s.c\n", fil);\
          exit(EXIT_FAILURE);\
	}\
	FPU_CLEAR_FLAGS		\
	FPU_SET_ROUNDING	\
	FPU_SET_PRECISION	\
	FPU_DISABLE_TRAPS
    #endif

  #else				/* Not redirecting stdout */

    #ifndef   SETUP1
      #define SETUP1(fil)
    #endif
    #ifndef   SETUP2
      #define SETUP2(fil) 	\
	FPU_CLEAR_FLAGS		\
	FPU_SET_ROUNDING	\
	FPU_SET_PRECISION	\
	FPU_DISABLE_TRAPS
    #endif

  #endif /* REDIRECT */

/*
 * Some compilers support   signed long long, but spell it as __int64.
 * Some compilers support unsigned long long, but spell it as unsigned __int64.
 * Some compilers support   signed long long constants as mi64 instead of mLL.
 * Some compilers support unsigned long long constants as mui64 instead of muLL.
 * You can define your own versions of these next four macros in your
 * *.bug file to map to whatever your compiler uses. You may also
 * need to define LLONG_MIN, LLONG_MAX, and ULLONG_MAX in your *.bug.
 * These are needed by t0000000, t0120*, t178*, and t179* tests.
 * Since these might be needed by FP_H for the return type of llrint
 * and llround, they have to go here (not myfloat.h which is included
 * after FP_H).
 */
  #ifndef   LONGLONG
    #define LONGLONG long long int
  #endif

  #ifndef   ULONGLONG
    #define ULONGLONG unsigned long long int
  #endif

  #ifndef   SLL_C
    #define SLL_C(n) (n ## LL)
  #endif

  #ifndef   ULL_C
    #define ULL_C(n) (n ## uLL)
  #endif

/*
 * The following take a un-suffixed floating-point constant and produce a
 * floating-point constant with the appropriate suffix.  If these macros
 * are not good enough for your needs, then you can define your versions
 * in the *.bug file included above.  Other choices might add a cast
 *  (float), (double), (long double)
 *  (FLT), (DBL), (LDBL)
 * before the value (of either the right type or of long double type).
 *
 * The Tnnn000m tests map FPK(), for floating-point constant, to one of
 * these three macros to convert plain floating-point constants into the
 * correct typed constant.
 */

  #ifndef FP_F
    #define FP_F(v) v##f
  #endif

  #ifndef FP_D
    #ifndef REMAP_DBL
      #if (defined __STDC_WANT_DEC_FP__) && (!defined FIX_D_SUFFIX)
	/* explicit double suffix */
        #define FP_D(v) v##D
      #else
	/* implicit double suffix */
        #define FP_D(v) v
      #endif
    #else
      #define FP_D(v) v##L
    #endif
  #endif

  #ifndef FP_LD
    #ifndef REMAP_LDBL
      #define FP_LD(v) v##L
    #else			/* Some compilers do not support long double */
      #if (defined __STDC_WANT_DEC_FP__) && (!defined FIX_D_SUFFIX)
        #define FP_LD(v) v##D
      #else
        #define FP_LD(v) v
      #endif
    #endif
  #endif

  #ifdef __STDC_WANT_DEC_FP__	/* Decimal FP addon */

    #ifndef FP_F10
      #define FP_F10(v) v##DF
    #endif

    #ifndef FP_D10
      #ifndef REMAP_D10
        #define FP_D10(v) v##DD
      #else
        #define FP_D10(v) v##DL
      #endif
    #endif

    #ifndef FP_LD10
      #ifndef REMAP_LD10
        #define FP_LD10(v) v##DL
      #else				/* Some compilers do not support long double */
        #define FP_LD10(v) v##DD
      #endif
    #endif

  #endif

/*
 * Default modes used by fopen and freopen for binary files in t304*.
 */
  #ifndef   IMPL_fopen_wb
    #define IMPL_fopen_wb "wb"
  #endif
  #ifndef   IMPL_freopen_wb
    #define IMPL_freopen_wb "wb"
  #endif

  #ifndef   IMPL_freopen_rb
    #define IMPL_freopen_rb "rb"
  #endif

/*
 * If wchar_t is missing, simulate it.
 */
  #if (defined FIX_wchar_t) && (!defined wchar_t)
    #define wchar_t unsigned int
  #endif

/*
 * If <stdbool.h> is missing, simulate it.
 */
  #if (defined FIX_STDBOOL_H)
    #define bool _Bool
    #define true 1u
    #define false 0u
  #endif

/*
 * Some compilers support _Bool as a builtin type (required in C99).
 * If it is missing, simulate it with unsigned int.  It canNOT be
 * unsigned char, as that is not valid for bit-fields (but is allowed
 * as an extension).
 */
  #ifdef FIX_BOOL
    #if (!defined _lint) || (_lint < 800) || (defined __cplusplus) /* lint 8.00 knows about _Bool for C99 */
  typedef unsigned int _Bool;	/* so can use as bit-field */
    #endif
    #ifndef   FIX_TRUE_BOOL
      #define FIX_TRUE_BOOL	/* has problems with _Bool = 0.25; */
    #endif
  #endif

/*
 * If bool bit-fields are not supported.
 */
  #ifdef FIX_BOOL_BITFIELD
    #define BOOL_BIT unsigned int
  #else
    #define BOOL_BIT bool
  #endif

/*
 * If cast to bool is not supported or has wrong semantics.
 */
  #if (defined FIX_BOOL_CAST) || (defined FIX_TRUE_BOOL)
    #define BOOL_CAST(x) ((0==(x)) ? false : true)
  #else
    #define BOOL_CAST(x) ((bool)(x))
  #endif

/*
 * How are pole or singularity or divide-by-zero errors done for errno?
 * C99 requires ERANGE, but this allows an implementation to use EDOM,
 * or even some other errno symbol, eg, ESING.  An example is log(0.0)
 */
  #ifndef FIX_ePOLE_IS_ERANGE
    #define ePOLE ERANGE
  #endif

/*
 * Complex binary FP types and constant creators
 */
  #ifndef   FLT_CMPLX
    #define FLT_CMPLX FLT _Complex
  #endif
  #ifndef   FLT_CMPLX_C
    #define FLT_CMPLX_C(r,i) ((FLT_CMPLX)((r)+(i)*I))
  #endif

  #ifndef   DBL_CMPLX
    #define DBL_CMPLX DBL _Complex
  #endif
  #ifndef   DBL_CMPLX_C
    #define DBL_CMPLX_C(r,i) ((DBL_CMPLX)((r)+(i)*I))
  #endif

  #ifdef REMAP_LDBL
    #ifndef   LDBL_CMPLX
      #define LDBL_CMPLX DBL_CMPLX
    #endif
    #ifndef   LDBL_CMPLX_C
      #define LDBL_CMPLX_C(r,i) ((DBL_CMPLX)((r)+(i)*I))
    #endif
  #else
    #ifndef   LDBL_CMPLX
      #define LDBL_CMPLX LDBL _Complex
    #endif
    #ifndef   LDBL_CMPLX_C
      #define LDBL_CMPLX_C(r,i) ((LDBL_CMPLX)((r)+(i)*I))
    #endif
  #endif

/*
 * Imaginary binary FP types and constant creators
 */
  #ifndef   FLT_IMAG
    #define FLT_IMAG FLT _Imaginary
  #endif
  #ifndef   FLT_IMAG_C
    #define FLT_IMAG_C(i) ((FLT_IMAG)((i)*I))
  #endif

  #ifndef   DBL_IMAG
    #define DBL_IMAG DBL _Imaginary
  #endif
  #ifndef   DBL_IMAG_C
    #define DBL_IMAG_C(i) ((DBL_IMAG)((i)*I))
  #endif

  #ifdef REMAP_LDBL
    #ifndef   LDBL_IMAG
      #define LDBL_IMAG DBL _Imaginary
    #endif
    #ifndef   LDBL_IMAG_C
      #define LDBL_IMAG_C(i) ((DBL_IMAG)((i)*I))
    #endif
  #else
    #ifndef   LDBL_IMAG
      #define LDBL_IMAG LDBL _Imaginary
    #endif
    #ifndef   LDBL_IMAG_C
      #define LDBL_IMAG_C(i) ((LDBL_IMAG)((i)*I))
    #endif
  #endif

  #ifdef __STDC_WANT_DEC_FP__	/* Decimal FP addon */

/*
 * IEEE-754R decimal FP is in the process of being added to C99
 * via the Technical Report method.  For those implementations
 * that support this feature, may need some new headers.
 *   DECFENV_H = decimal functions of fenv.h
 *   DECFLOAT_H = decimal version of float.h
 *   DECMATH_H = decimal functions of math.h
 *   DECSTDLIB_H = decimal functions of stdlib.h
 * Also, my tests need to define __STDC_WANT_DEC_FP__ to indicate that
 * they are testing this new feature.
 */
    #ifndef   DECFENV_H
      #define DECFENV_H <fenv.h>
    #endif

    #ifndef   DECFLOAT_H
      #define DECFLOAT_H <float.h>
    #endif

    #ifndef   DECMATH_H
      #define DECMATH_H <math.h>
    #endif

    #ifndef   DECSTDLIB_H
      #define DECSTDLIB_H <stdlib.h>
    #endif

/*
 * Real decimal types
 * (may add base 2 or 16 if some customer needs it)
 * These are:  type_base_precision
 */
    #ifndef   Flt_10_7
      #define Flt_10_7 _Decimal32
    #endif

    #ifndef   Flt_10_16
      #define Flt_10_16 _Decimal64
    #endif

    #ifdef REMAP_LD10
      #ifndef   Flt_10_34
        #define Flt_10_34 Flt_10_16
      #endif
      #define IMPL_LD10_EQ_D10
      #define FIX_LD10
      #define FIX_FUNCS10_L	/* get rid of decimal long double functs */
    #else
      #ifndef   Flt_10_34
        #define Flt_10_34 _Decimal128
      #endif
    #endif

    #define  F10 Flt_10_7
    #define  D10 Flt_10_16
    #define LD10 Flt_10_34

/*
 * Complex decimal FP types and constant creators
 * (may add base 2 or 16 if some customer needs it)
 * These are:  type_base_precision
 */
    #ifndef   I10
      #define I10 ((Imag_10_7)I)
    #endif
    #ifndef   Cmplx_10_7
      #define Cmplx_10_7 Flt_10_7 _Complex
    #endif
    #ifndef   Cmplx_10_7_C
      #define Cmplx_10_7_C(r,i) ((Cmplx_10_7)((r)+(i)*I10))
    #endif

    #ifndef   Cmplx_10_16
      #define Cmplx_10_16 Flt_10_16 _Complex
    #endif
    #ifndef   Cmplx_10_16_C
      #define Cmplx_10_16_C(r,i) ((Cmplx_10_16)((r)+(i)*I10))
    #endif

    #ifdef REMAP_LD10
      #ifndef   Cmplx_10_34
        #define Cmplx_10_34 Flt_10_16 _Complex
      #endif
      #ifndef   Cmplx_10_34_C
        #define Cmplx_10_34_C(r,i) ((Cmplx_10_16)((r)+(i)*I10))
      #endif
    #else
      #ifndef   Cmplx_10_34
        #define Cmplx_10_34 Flt_10_34 _Complex
      #endif
      #ifndef   Cmplx_10_34_C
        #define Cmplx_10_34_C(r,i) ((Cmplx_10_34)((r)+(i)*I10))
      #endif
    #endif

/*
 * Imaginary decimal FP types and constant creators
 * (may add base 2 or 16 if some customer needs it)
 * These are:  type_base_precision
 */
    #ifndef   Imag_10_7
      #define Imag_10_7 Flt_10_7 _Imaginary
    #endif
    #ifndef   Imag_10_7_C
      #define Imag_10_7_C(i) ((Imag_10_7)((i)*I10))
    #endif

    #ifndef   Imag_10_16
      #define Imag_10_16 Flt_10_16 _Imaginary
    #endif
    #ifndef   Imag_10_16_C
      #define Imag_10_16_C(i) ((Imag_10_16)((i)*I10))
    #endif

    #ifdef REMAP_LD10
      #ifndef   Imag_10_34
        #define Imag_10_34 Flt_10_16 _Imaginary
      #endif
      #ifndef   Imag_10_34_C
        #define Imag_10_34_C(i) ((Imag_10_16)((i)*I10))
      #endif
    #else
      #ifndef   Imag_10_34
        #define Imag_10_34 Flt_10_34 _Imaginary
      #endif
      #ifndef   Imag_10_34_C
        #define Imag_10_34_C(i) ((Imag_10_34)((i)*I10))
      #endif
    #endif

/*
 * Length modifiers used in printf/scanf conversion specifications.
 * Default scanf conversion specifications.
 *
 */
    #ifndef   SCAN_F10_LENMOD
      #define SCAN_F10_LENMOD "H"
    #endif
    #ifndef   PRT_F10_LENMOD
      #define PRT_F10_LENMOD "H"
    #endif

    #ifndef   SCAN_D10_LENMOD
      #define SCAN_D10_LENMOD "D"
    #endif
    #ifndef   PRT_D10_LENMOD
      #define PRT_D10_LENMOD "D"
    #endif

    #ifndef   SCAN_LD10_LENMOD
      #define SCAN_LD10_LENMOD "DD"
    #endif
    #ifndef   PRT_LD10_LENMOD
      #define PRT_LD10_LENMOD "DD"
    #endif

    #ifndef   FMT_F10_SCAN
      #define FMT_F10_SCAN "%Hg"
    #endif
    #ifndef   FMT_D10_SCAN
      #define FMT_D10_SCAN "%Dg"
    #endif
    #ifdef REMAP_LD10
      #ifndef   FMT_LD10_SCAN
        #define FMT_LD10_SCAN "%Dg"
      #endif
    #else
      #ifndef   FMT_LD10_SCAN
        #define FMT_LD10_SCAN "%DDg"
      #endif
    #endif

  #endif	/* __STDC_WANT_DEC_FP__	// Decimal FP addon */

  #ifndef   FMT_F_SCAN
    #define FMT_F_SCAN "%g"
  #endif
  #ifndef   FMT_D_SCAN
    #define FMT_D_SCAN "%lg"
  #endif
  #ifdef REMAP_LDBL
    #ifndef   FMT_LD_SCAN
      #define FMT_LD_SCAN "%lg"
    #endif
  #else
    #ifndef   FMT_LD_SCAN
      #define FMT_LD_SCAN "%Lg"
    #endif
  #endif

/*
 * What FP radix are we testing?
 * Many tests need the radix as either an integer or a FP constant.
 * Many of the "integer" rounding tests need radix +/- 1.
 */
  #ifdef __STDC_WANT_DEC_FP__
    #define FP_RADIX 10
    #define RXm1 FPK( 9.)
    #define RX   FPK(10.)
    #define RXp1 FPK(11.)
    #define Rf   FP_F10(10.)
    #define Rd   FP_D10(10.)
    #define Rld  FP_LD10(10.)
  #else
    #define FP_RADIX 2
    #define RXm1 FPK(1.)
    #define RX   FPK(2.)
    #define RXp1 FPK(3.)
    #define Rf   FP_F(2.)
    #define Rd   FP_D(2.)
    #define Rld  FP_LD(2.)
  #endif

/*
 * Conversions between any pointer type and any floating type is
 * implicitly undefined behaviour in C89/95/99.
 * If you want to explicitly test these conversions in t*160320,
 * then you need to #undef these symbols in your *.flt file.
 */
  #ifndef   FIX_FP_FROM_PTR
    #define FIX_FP_FROM_PTR
  #endif
  #ifndef   FIX_PTR_FROM_FP
    #define FIX_PTR_FROM_FP
  #endif
  #ifndef   FIX_CMPLX_FROM_PTR
    #define FIX_CMPLX_FROM_PTR
  #endif
  #ifndef   FIX_PTR_FROM_CMPLX
    #define FIX_PTR_FROM_CMPLX
  #endif
  #ifndef   FIX_FP10_FROM_PTR
    #define FIX_FP10_FROM_PTR
  #endif
  #ifndef   FIX_PTR_FROM_FP10
    #define FIX_PTR_FROM_FP10
  #endif

  #if (defined NEED_VOLATILE) && (!defined LINT_VOLATILE)
    #define LINT_VOLATILE
  #endif

/*
 * Checking my code and vendor's headers on development system.
 * Bypass nits in my code and their headers; bugs in PC-Lint.
 */
  #ifdef _lint
    #include "E:\fpcets\pclint\pclint.bug"
  #endif

#endif /* MYDEFS_H_ */
